/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.Konqueror.Main.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef KONQ_MAIN_INTERFACE_H
#define KONQ_MAIN_INTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>

/*
 * Proxy class for interface org.kde.Konqueror.Main
 */
class OrgKdeKonquerorMainInterface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.kde.Konqueror.Main"; }

public:
    OrgKdeKonquerorMainInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OrgKdeKonquerorMainInterface();

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<> addToCombo(const QString &url)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(url);
        return asyncCallWithArgumentList(QStringLiteral("addToCombo"), argumentList);
    }

    inline QDBusPendingReply<> comboCleared()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("comboCleared"), argumentList);
    }

    inline QDBusPendingReply<QDBusObjectPath> createNewWindow(const QString &url, const QString &mimetype, const QByteArray &startup_id, bool tempFile)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(url) << QVariant::fromValue(mimetype) << QVariant::fromValue(startup_id) << QVariant::fromValue(tempFile);
        return asyncCallWithArgumentList(QStringLiteral("createNewWindow"), argumentList);
    }

    inline QDBusPendingReply<QDBusObjectPath> createNewWindowWithSelection(const QString &url, const QStringList &filesToSelect, const QByteArray &startup_id)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(url) << QVariant::fromValue(filesToSelect) << QVariant::fromValue(startup_id);
        return asyncCallWithArgumentList(QStringLiteral("createNewWindowWithSelection"), argumentList);
    }

    inline QDBusPendingReply<QDBusObjectPath> openBrowserWindow(const QString &url, const QByteArray &startup_id)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(url) << QVariant::fromValue(startup_id);
        return asyncCallWithArgumentList(QStringLiteral("openBrowserWindow"), argumentList);
    }

    inline QDBusPendingReply<> removeFromCombo(const QString &url)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(url);
        return asyncCallWithArgumentList(QStringLiteral("removeFromCombo"), argumentList);
    }

    inline QDBusPendingReply<QDBusObjectPath> windowForTab()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("windowForTab"), argumentList);
    }

Q_SIGNALS: // SIGNALS
    void reparseConfiguration();
};

namespace org {
  namespace kde {
    namespace Konqueror {
      using Main = ::OrgKdeKonquerorMainInterface;
    }
  }
}

#endif
