/****************************************************************************
** Meta object code from reading C++ file 'konqviewmanager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../konqueror-26.04.0/src/konqviewmanager.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'konqviewmanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15KonqViewManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto KonqViewManager::qt_create_metaobjectdata<qt_meta_tag_ZN15KonqViewManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KonqViewManager",
        "aboutToRemoveTab",
        "",
        "KonqFrameBase*",
        "tab",
        "tabContainerChanged",
        "KonqFrameTabs*",
        "container",
        "viewCreated",
        "KonqView*",
        "newView",
        "openClosedWindow",
        "KonqClosedWindowItem",
        "closedTab",
        "openClosedTab",
        "KonqClosedTabItem",
        "reparseConfiguration",
        "emitActivePartChanged",
        "slotPassiveModePartDeleted",
        "slotActivePartChanged",
        "KParts::Part*",
        "newPart",
        "delayedLoadTab",
        "idx"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'aboutToRemoveTab'
        QtMocHelpers::SignalData<void(KonqFrameBase *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'tabContainerChanged'
        QtMocHelpers::SignalData<void(KonqFrameTabs *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Signal 'viewCreated'
        QtMocHelpers::SignalData<void(KonqView *)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Slot 'openClosedWindow'
        QtMocHelpers::SlotData<void(const KonqClosedWindowItem &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Slot 'openClosedTab'
        QtMocHelpers::SlotData<void(const KonqClosedTabItem &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 13 },
        }}),
        // Slot 'reparseConfiguration'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'emitActivePartChanged'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotPassiveModePartDeleted'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotActivePartChanged'
        QtMocHelpers::SlotData<void(KParts::Part *)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 20, 21 },
        }}),
        // Slot 'delayedLoadTab'
        QtMocHelpers::SlotData<void(int)>(22, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 23 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KonqViewManager, qt_meta_tag_ZN15KonqViewManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KonqViewManager::staticMetaObject = { {
    QMetaObject::SuperData::link<KParts::PartManager::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15KonqViewManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15KonqViewManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15KonqViewManagerE_t>.metaTypes,
    nullptr
} };

void KonqViewManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KonqViewManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->aboutToRemoveTab((*reinterpret_cast<std::add_pointer_t<KonqFrameBase*>>(_a[1]))); break;
        case 1: _t->tabContainerChanged((*reinterpret_cast<std::add_pointer_t<KonqFrameTabs*>>(_a[1]))); break;
        case 2: _t->viewCreated((*reinterpret_cast<std::add_pointer_t<KonqView*>>(_a[1]))); break;
        case 3: _t->openClosedWindow((*reinterpret_cast<std::add_pointer_t<KonqClosedWindowItem>>(_a[1]))); break;
        case 4: _t->openClosedTab((*reinterpret_cast<std::add_pointer_t<KonqClosedTabItem>>(_a[1]))); break;
        case 5: _t->reparseConfiguration(); break;
        case 6: _t->emitActivePartChanged(); break;
        case 7: _t->slotPassiveModePartDeleted(); break;
        case 8: _t->slotActivePartChanged((*reinterpret_cast<std::add_pointer_t<KParts::Part*>>(_a[1]))); break;
        case 9: _t->delayedLoadTab((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KParts::Part* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KonqViewManager::*)(KonqFrameBase * )>(_a, &KonqViewManager::aboutToRemoveTab, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KonqViewManager::*)(KonqFrameTabs * )>(_a, &KonqViewManager::tabContainerChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KonqViewManager::*)(KonqView * )>(_a, &KonqViewManager::viewCreated, 2))
            return;
    }
}

const QMetaObject *KonqViewManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KonqViewManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15KonqViewManagerE_t>.strings))
        return static_cast<void*>(this);
    return KParts::PartManager::qt_metacast(_clname);
}

int KonqViewManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KParts::PartManager::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void KonqViewManager::aboutToRemoveTab(KonqFrameBase * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void KonqViewManager::tabContainerChanged(KonqFrameTabs * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void KonqViewManager::viewCreated(KonqView * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
QT_WARNING_POP
