/********************************************************************************
** Form generated from reading UI file 'speeddialconfig.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SPEEDDIALCONFIG_H
#define UI_SPEEDDIALCONFIG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_SpeedDialConfigModule
{
public:
    QVBoxLayout *verticalLayout_2;
    QLabel *label;
    QHBoxLayout *horizontalLayout;
    QTreeView *entries;
    QVBoxLayout *verticalLayout;
    QSpacerItem *verticalSpacer_2;
    QPushButton *addEntryBtn;
    QPushButton *editEntryBtn;
    QPushButton *removeEntryBtn;
    QSpacerItem *verticalSpacer_3;
    QPushButton *moveUpBtn;
    QPushButton *moveDownBtn;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *SpeedDialConfigModule)
    {
        if (SpeedDialConfigModule->objectName().isEmpty())
            SpeedDialConfigModule->setObjectName("SpeedDialConfigModule");
        SpeedDialConfigModule->resize(405, 357);
        verticalLayout_2 = new QVBoxLayout(SpeedDialConfigModule);
        verticalLayout_2->setObjectName("verticalLayout_2");
        label = new QLabel(SpeedDialConfigModule);
        label->setObjectName("label");

        verticalLayout_2->addWidget(label);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        entries = new QTreeView(SpeedDialConfigModule);
        entries->setObjectName("entries");
        entries->setEditTriggers(QAbstractItemView::EditTrigger::NoEditTriggers);
        entries->setRootIsDecorated(false);
        entries->setItemsExpandable(false);
        entries->setAllColumnsShowFocus(true);

        horizontalLayout->addWidget(entries);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer_2);

        addEntryBtn = new QPushButton(SpeedDialConfigModule);
        addEntryBtn->setObjectName("addEntryBtn");

        verticalLayout->addWidget(addEntryBtn);

        editEntryBtn = new QPushButton(SpeedDialConfigModule);
        editEntryBtn->setObjectName("editEntryBtn");

        verticalLayout->addWidget(editEntryBtn);

        removeEntryBtn = new QPushButton(SpeedDialConfigModule);
        removeEntryBtn->setObjectName("removeEntryBtn");

        verticalLayout->addWidget(removeEntryBtn);

        verticalSpacer_3 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer_3);

        moveUpBtn = new QPushButton(SpeedDialConfigModule);
        moveUpBtn->setObjectName("moveUpBtn");

        verticalLayout->addWidget(moveUpBtn);

        moveDownBtn = new QPushButton(SpeedDialConfigModule);
        moveDownBtn->setObjectName("moveDownBtn");

        verticalLayout->addWidget(moveDownBtn);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        horizontalLayout->addLayout(verticalLayout);


        verticalLayout_2->addLayout(horizontalLayout);


        retranslateUi(SpeedDialConfigModule);

        QMetaObject::connectSlotsByName(SpeedDialConfigModule);
    } // setupUi

    void retranslateUi(QWidget *SpeedDialConfigModule)
    {
        label->setText(tr2i18n("Speed dial entries", nullptr));
        addEntryBtn->setText(tr2i18n("Add entry\342\200\246", nullptr));
        editEntryBtn->setText(tr2i18n("Edit entry\342\200\246", nullptr));
        removeEntryBtn->setText(tr2i18n("Remove entry", nullptr));
        moveUpBtn->setText(tr2i18n("Move up", nullptr));
        moveDownBtn->setText(tr2i18n("Move down", nullptr));
        (void)SpeedDialConfigModule;
    } // retranslateUi

};

namespace Ui {
    class SpeedDialConfigModule: public Ui_SpeedDialConfigModule {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SPEEDDIALCONFIG_H

