/********************************************************************************
** Form generated from reading UI file 'webenginepartcertificateerrordlg.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_WEBENGINEPARTCERTIFICATEERRORDLG_H
#define UI_WEBENGINEPARTCERTIFICATEERRORDLG_H

#include <KSslCertificateBox>
#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_WebEnginePartCertificateErrorDlg
{
public:
    QVBoxLayout *verticalLayout_2;
    QLabel *label;
    QCheckBox *showDetails;
    QDialogButtonBox *buttons;
    QGroupBox *details;
    QVBoxLayout *verticalLayout;
    QComboBox *certificateChain;
    QTabWidget *tabWidget;
    QWidget *subjectTab;
    QVBoxLayout *verticalLayout_3;
    KSslCertificateBox *subjectData;
    QWidget *issuerTab;
    QVBoxLayout *verticalLayout_4;
    KSslCertificateBox *issuerData;

    void setupUi(QDialog *WebEnginePartCertificateErrorDlg)
    {
        if (WebEnginePartCertificateErrorDlg->objectName().isEmpty())
            WebEnginePartCertificateErrorDlg->setObjectName("WebEnginePartCertificateErrorDlg");
        WebEnginePartCertificateErrorDlg->resize(758, 244);
        verticalLayout_2 = new QVBoxLayout(WebEnginePartCertificateErrorDlg);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setSizeConstraint(QLayout::SetFixedSize);
        label = new QLabel(WebEnginePartCertificateErrorDlg);
        label->setObjectName("label");

        verticalLayout_2->addWidget(label);

        showDetails = new QCheckBox(WebEnginePartCertificateErrorDlg);
        showDetails->setObjectName("showDetails");
        showDetails->setChecked(false);

        verticalLayout_2->addWidget(showDetails);

        buttons = new QDialogButtonBox(WebEnginePartCertificateErrorDlg);
        buttons->setObjectName("buttons");
        buttons->setOrientation(Qt::Horizontal);
        buttons->setStandardButtons(QDialogButtonBox::No|QDialogButtonBox::Yes|QDialogButtonBox::YesToAll);

        verticalLayout_2->addWidget(buttons);

        details = new QGroupBox(WebEnginePartCertificateErrorDlg);
        details->setObjectName("details");
        verticalLayout = new QVBoxLayout(details);
        verticalLayout->setObjectName("verticalLayout");
        certificateChain = new QComboBox(details);
        certificateChain->setObjectName("certificateChain");

        verticalLayout->addWidget(certificateChain);

        tabWidget = new QTabWidget(details);
        tabWidget->setObjectName("tabWidget");
        subjectTab = new QWidget();
        subjectTab->setObjectName("subjectTab");
        verticalLayout_3 = new QVBoxLayout(subjectTab);
        verticalLayout_3->setObjectName("verticalLayout_3");
        subjectData = new KSslCertificateBox(subjectTab);
        subjectData->setObjectName("subjectData");

        verticalLayout_3->addWidget(subjectData);

        tabWidget->addTab(subjectTab, QString());
        issuerTab = new QWidget();
        issuerTab->setObjectName("issuerTab");
        verticalLayout_4 = new QVBoxLayout(issuerTab);
        verticalLayout_4->setObjectName("verticalLayout_4");
        issuerData = new KSslCertificateBox(issuerTab);
        issuerData->setObjectName("issuerData");

        verticalLayout_4->addWidget(issuerData);

        tabWidget->addTab(issuerTab, QString());

        verticalLayout->addWidget(tabWidget);


        verticalLayout_2->addWidget(details);


        retranslateUi(WebEnginePartCertificateErrorDlg);
        QObject::connect(buttons, &QDialogButtonBox::accepted, WebEnginePartCertificateErrorDlg, qOverload<>(&QDialog::accept));
        QObject::connect(buttons, &QDialogButtonBox::rejected, WebEnginePartCertificateErrorDlg, qOverload<>(&QDialog::reject));

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(WebEnginePartCertificateErrorDlg);
    } // setupUi

    void retranslateUi(QDialog *WebEnginePartCertificateErrorDlg)
    {
        WebEnginePartCertificateErrorDlg->setWindowTitle(tr2i18n("Dialog", nullptr));
        label->setText(tr2i18n("TextLabel", nullptr));
        showDetails->setText(tr2i18n("&Show details", nullptr));
        details->setTitle(tr2i18n("Certificate details", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(subjectTab), tr2i18n("&Subject", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(issuerTab), tr2i18n("&Issuer", nullptr));
    } // retranslateUi

};

namespace Ui {
    class WebEnginePartCertificateErrorDlg: public Ui_WebEnginePartCertificateErrorDlg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // WEBENGINEPARTCERTIFICATEERRORDLG_H

