/****************************************************************************
** Meta object code from reading C++ file 'kget_interface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "kget_interface.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kget_interface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN23OrgKdeKgetMainInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto OrgKdeKgetMainInterface::qt_create_metaobjectdata<qt_meta_tag_ZN23OrgKdeKgetMainInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OrgKdeKgetMainInterface",
        "transfersAdded",
        "",
        "urls",
        "dBusObjectPaths",
        "transfersRemoved",
        "addTransfer",
        "QDBusPendingReply<QStringList>",
        "src",
        "destDir",
        "start",
        "delTransfer",
        "QDBusPendingReply<bool>",
        "dbusObjectPath",
        "dropTargetVisible",
        "importLinks",
        "QDBusPendingReply<>",
        "links",
        "isSupported",
        "url",
        "offlineMode",
        "setDropTargetVisible",
        "visible",
        "setOfflineMode",
        "in0",
        "showNewTransferDialog",
        "transfers",
        "QDBusPendingReply<QVariantMap>",
        "transfersSpeed",
        "QDBusPendingReply<int>"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'transfersAdded'
        QtMocHelpers::SignalData<void(const QStringList &, const QStringList &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 3 }, { QMetaType::QStringList, 4 },
        }}),
        // Signal 'transfersRemoved'
        QtMocHelpers::SignalData<void(const QStringList &, const QStringList &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 3 }, { QMetaType::QStringList, 4 },
        }}),
        // Slot 'addTransfer'
        QtMocHelpers::SlotData<QDBusPendingReply<QStringList>(const QString &, const QString &, bool)>(6, 2, QMC::AccessPublic, 0x80000000 | 7, {{
            { QMetaType::QString, 8 }, { QMetaType::QString, 9 }, { QMetaType::Bool, 10 },
        }}),
        // Slot 'delTransfer'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(const QString &)>(11, 2, QMC::AccessPublic, 0x80000000 | 12, {{
            { QMetaType::QString, 13 },
        }}),
        // Slot 'dropTargetVisible'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>()>(14, 2, QMC::AccessPublic, 0x80000000 | 12),
        // Slot 'importLinks'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QStringList &)>(15, 2, QMC::AccessPublic, 0x80000000 | 16, {{
            { QMetaType::QStringList, 17 },
        }}),
        // Slot 'isSupported'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(const QString &)>(18, 2, QMC::AccessPublic, 0x80000000 | 12, {{
            { QMetaType::QString, 19 },
        }}),
        // Slot 'offlineMode'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>()>(20, 2, QMC::AccessPublic, 0x80000000 | 12),
        // Slot 'setDropTargetVisible'
        QtMocHelpers::SlotData<QDBusPendingReply<>(bool)>(21, 2, QMC::AccessPublic, 0x80000000 | 16, {{
            { QMetaType::Bool, 22 },
        }}),
        // Slot 'setOfflineMode'
        QtMocHelpers::SlotData<QDBusPendingReply<>(bool)>(23, 2, QMC::AccessPublic, 0x80000000 | 16, {{
            { QMetaType::Bool, 24 },
        }}),
        // Slot 'showNewTransferDialog'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QStringList &)>(25, 2, QMC::AccessPublic, 0x80000000 | 16, {{
            { QMetaType::QStringList, 3 },
        }}),
        // Slot 'transfers'
        QtMocHelpers::SlotData<QDBusPendingReply<QVariantMap>()>(26, 2, QMC::AccessPublic, 0x80000000 | 27),
        // Slot 'transfersSpeed'
        QtMocHelpers::SlotData<QDBusPendingReply<int>()>(28, 2, QMC::AccessPublic, 0x80000000 | 29),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OrgKdeKgetMainInterface, qt_meta_tag_ZN23OrgKdeKgetMainInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OrgKdeKgetMainInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23OrgKdeKgetMainInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23OrgKdeKgetMainInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN23OrgKdeKgetMainInterfaceE_t>.metaTypes,
    nullptr
} };

void OrgKdeKgetMainInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OrgKdeKgetMainInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->transfersAdded((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2]))); break;
        case 1: _t->transfersRemoved((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2]))); break;
        case 2: { QDBusPendingReply<QStringList> _r = _t->addTransfer((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QStringList>*>(_a[0]) = std::move(_r); }  break;
        case 3: { QDBusPendingReply<bool> _r = _t->delTransfer((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 4: { QDBusPendingReply<bool> _r = _t->dropTargetVisible();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 5: { QDBusPendingReply<> _r = _t->importLinks((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 6: { QDBusPendingReply<bool> _r = _t->isSupported((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 7: { QDBusPendingReply<bool> _r = _t->offlineMode();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 8: { QDBusPendingReply<> _r = _t->setDropTargetVisible((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 9: { QDBusPendingReply<> _r = _t->setOfflineMode((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 10: { QDBusPendingReply<> _r = _t->showNewTransferDialog((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 11: { QDBusPendingReply<QVariantMap> _r = _t->transfers();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QVariantMap>*>(_a[0]) = std::move(_r); }  break;
        case 12: { QDBusPendingReply<int> _r = _t->transfersSpeed();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<int>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKgetMainInterface::*)(const QStringList & , const QStringList & )>(_a, &OrgKdeKgetMainInterface::transfersAdded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKgetMainInterface::*)(const QStringList & , const QStringList & )>(_a, &OrgKdeKgetMainInterface::transfersRemoved, 1))
            return;
    }
}

const QMetaObject *OrgKdeKgetMainInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OrgKdeKgetMainInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23OrgKdeKgetMainInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int OrgKdeKgetMainInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void OrgKdeKgetMainInterface::transfersAdded(const QStringList & _t1, const QStringList & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void OrgKdeKgetMainInterface::transfersRemoved(const QStringList & _t1, const QStringList & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}
QT_WARNING_POP
