/****************************************************************************
** Meta object code from reading C++ file 'webenginepart_ext.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../konqueror-26.04.0/webenginepart/src/webenginepart_ext.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'webenginepart_ext.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN28WebEngineNavigationExtensionE_t {};
} // unnamed namespace

template <> constexpr inline auto WebEngineNavigationExtension::qt_create_metaobjectdata<qt_meta_tag_ZN28WebEngineNavigationExtensionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "WebEngineNavigationExtension",
        "saveUrl",
        "",
        "QUrl",
        "saveHistory",
        "cut",
        "copy",
        "paste",
        "print",
        "slotSaveDocument",
        "slotSaveFullHTMLPage",
        "searchProvider",
        "reparseConfiguration",
        "disableScrolling",
        "zoomIn",
        "zoomOut",
        "zoomNormal",
        "toogleZoomTextOnly",
        "toogleZoomToDPI",
        "slotSelectAll",
        "slotSaveImageAs",
        "slotSendImage",
        "slotCopyImageURL",
        "slotCopyImage",
        "slotViewImage",
        "slotBlockImage",
        "slotBlockHost",
        "slotCopyLinkURL",
        "slotCopyLinkText",
        "slotSaveLinkAs",
        "url",
        "slotCopyEmailAddress",
        "slotViewDocumentSource",
        "updateEditActions",
        "updateActions",
        "slotPlayMedia",
        "slotMuteMedia",
        "slotLoopMedia",
        "slotShowMediaControls",
        "slotSaveMedia",
        "slotCopyMedia",
        "slotTextDirectionChanged",
        "slotCheckSpelling",
        "slotSpellCheckSelection",
        "slotSpellCheckDone",
        "spellCheckerCorrected",
        "spellCheckerMisspelling",
        "slotPrintPreview",
        "slotOpenSelection",
        "slotLinkInTop",
        "slotHandlePagePrinted",
        "result"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'saveUrl'
        QtMocHelpers::SignalData<void(const QUrl &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'saveHistory'
        QtMocHelpers::SignalData<void(QObject *, const QByteArray &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QObjectStar, 2 }, { QMetaType::QByteArray, 2 },
        }}),
        // Slot 'cut'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'copy'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'paste'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'print'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSaveDocument'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSaveFullHTMLPage'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'searchProvider'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'reparseConfiguration'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'disableScrolling'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'zoomIn'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'zoomOut'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'zoomNormal'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'toogleZoomTextOnly'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'toogleZoomToDPI'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSelectAll'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSaveImageAs'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSendImage'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCopyImageURL'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCopyImage'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotViewImage'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotBlockImage'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotBlockHost'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCopyLinkURL'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCopyLinkText'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSaveLinkAs'
        QtMocHelpers::SlotData<void(const QUrl &)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 30 },
        }}),
        // Slot 'slotCopyEmailAddress'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotViewDocumentSource'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateEditActions'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateActions'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotPlayMedia'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotMuteMedia'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotLoopMedia'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotShowMediaControls'
        QtMocHelpers::SlotData<void()>(38, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSaveMedia'
        QtMocHelpers::SlotData<void()>(39, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCopyMedia'
        QtMocHelpers::SlotData<void()>(40, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotTextDirectionChanged'
        QtMocHelpers::SlotData<void()>(41, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCheckSpelling'
        QtMocHelpers::SlotData<void()>(42, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSpellCheckSelection'
        QtMocHelpers::SlotData<void()>(43, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSpellCheckDone'
        QtMocHelpers::SlotData<void(const QString &)>(44, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'spellCheckerCorrected'
        QtMocHelpers::SlotData<void(const QString &, int, const QString &)>(45, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 }, { QMetaType::Int, 2 }, { QMetaType::QString, 2 },
        }}),
        // Slot 'spellCheckerMisspelling'
        QtMocHelpers::SlotData<void(const QString &, int)>(46, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 }, { QMetaType::Int, 2 },
        }}),
        // Slot 'slotPrintPreview'
        QtMocHelpers::SlotData<void()>(47, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotOpenSelection'
        QtMocHelpers::SlotData<void()>(48, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotLinkInTop'
        QtMocHelpers::SlotData<void()>(49, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotHandlePagePrinted'
        QtMocHelpers::SlotData<void(bool)>(50, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 51 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<WebEngineNavigationExtension, qt_meta_tag_ZN28WebEngineNavigationExtensionE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject WebEngineNavigationExtension::staticMetaObject = { {
    QMetaObject::SuperData::link<BrowserExtension::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN28WebEngineNavigationExtensionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN28WebEngineNavigationExtensionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN28WebEngineNavigationExtensionE_t>.metaTypes,
    nullptr
} };

void WebEngineNavigationExtension::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<WebEngineNavigationExtension *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->saveUrl((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 1: _t->saveHistory((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[2]))); break;
        case 2: _t->cut(); break;
        case 3: _t->copy(); break;
        case 4: _t->paste(); break;
        case 5: _t->print(); break;
        case 6: _t->slotSaveDocument(); break;
        case 7: _t->slotSaveFullHTMLPage(); break;
        case 8: _t->searchProvider(); break;
        case 9: _t->reparseConfiguration(); break;
        case 10: _t->disableScrolling(); break;
        case 11: _t->zoomIn(); break;
        case 12: _t->zoomOut(); break;
        case 13: _t->zoomNormal(); break;
        case 14: _t->toogleZoomTextOnly(); break;
        case 15: _t->toogleZoomToDPI(); break;
        case 16: _t->slotSelectAll(); break;
        case 17: _t->slotSaveImageAs(); break;
        case 18: _t->slotSendImage(); break;
        case 19: _t->slotCopyImageURL(); break;
        case 20: _t->slotCopyImage(); break;
        case 21: _t->slotViewImage(); break;
        case 22: _t->slotBlockImage(); break;
        case 23: _t->slotBlockHost(); break;
        case 24: _t->slotCopyLinkURL(); break;
        case 25: _t->slotCopyLinkText(); break;
        case 26: _t->slotSaveLinkAs((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 27: _t->slotCopyEmailAddress(); break;
        case 28: _t->slotViewDocumentSource(); break;
        case 29: _t->updateEditActions(); break;
        case 30: _t->updateActions(); break;
        case 31: _t->slotPlayMedia(); break;
        case 32: _t->slotMuteMedia(); break;
        case 33: _t->slotLoopMedia(); break;
        case 34: _t->slotShowMediaControls(); break;
        case 35: _t->slotSaveMedia(); break;
        case 36: _t->slotCopyMedia(); break;
        case 37: _t->slotTextDirectionChanged(); break;
        case 38: _t->slotCheckSpelling(); break;
        case 39: _t->slotSpellCheckSelection(); break;
        case 40: _t->slotSpellCheckDone((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 41: _t->spellCheckerCorrected((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 42: _t->spellCheckerMisspelling((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 43: _t->slotPrintPreview(); break;
        case 44: _t->slotOpenSelection(); break;
        case 45: _t->slotLinkInTop(); break;
        case 46: _t->slotHandlePagePrinted((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (WebEngineNavigationExtension::*)(const QUrl & )>(_a, &WebEngineNavigationExtension::saveUrl, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (WebEngineNavigationExtension::*)(QObject * , const QByteArray & )>(_a, &WebEngineNavigationExtension::saveHistory, 1))
            return;
    }
}

const QMetaObject *WebEngineNavigationExtension::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *WebEngineNavigationExtension::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN28WebEngineNavigationExtensionE_t>.strings))
        return static_cast<void*>(this);
    return BrowserExtension::qt_metacast(_clname);
}

int WebEngineNavigationExtension::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = BrowserExtension::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 47)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 47;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 47)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 47;
    }
    return _id;
}

// SIGNAL 0
void WebEngineNavigationExtension::saveUrl(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void WebEngineNavigationExtension::saveHistory(QObject * _t1, const QByteArray & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}
namespace {
struct qt_meta_tag_ZN22WebEngineTextExtensionE_t {};
} // unnamed namespace

template <> constexpr inline auto WebEngineTextExtension::qt_create_metaobjectdata<qt_meta_tag_ZN22WebEngineTextExtensionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "WebEngineTextExtension"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<WebEngineTextExtension, qt_meta_tag_ZN22WebEngineTextExtensionE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject WebEngineTextExtension::staticMetaObject = { {
    QMetaObject::SuperData::link<TextExtension::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22WebEngineTextExtensionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22WebEngineTextExtensionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN22WebEngineTextExtensionE_t>.metaTypes,
    nullptr
} };

void WebEngineTextExtension::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<WebEngineTextExtension *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *WebEngineTextExtension::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *WebEngineTextExtension::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22WebEngineTextExtensionE_t>.strings))
        return static_cast<void*>(this);
    return TextExtension::qt_metacast(_clname);
}

int WebEngineTextExtension::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = TextExtension::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN22WebEngineHtmlExtensionE_t {};
} // unnamed namespace

template <> constexpr inline auto WebEngineHtmlExtension::qt_create_metaobjectdata<qt_meta_tag_ZN22WebEngineHtmlExtensionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "WebEngineHtmlExtension"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<WebEngineHtmlExtension, qt_meta_tag_ZN22WebEngineHtmlExtensionE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject WebEngineHtmlExtension::staticMetaObject = { {
    QMetaObject::SuperData::link<HtmlExtension::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22WebEngineHtmlExtensionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22WebEngineHtmlExtensionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN22WebEngineHtmlExtensionE_t>.metaTypes,
    nullptr
} };

void WebEngineHtmlExtension::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<WebEngineHtmlExtension *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *WebEngineHtmlExtension::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *WebEngineHtmlExtension::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22WebEngineHtmlExtensionE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "KonqInterfaces::SelectorInterface"))
        return static_cast< KonqInterfaces::SelectorInterface*>(this);
    if (!strcmp(_clname, "HtmlSettingsInterface"))
        return static_cast< HtmlSettingsInterface*>(this);
    if (!strcmp(_clname, "org.kde.libkonq.SelectorInterface"))
        return static_cast< KonqInterfaces::SelectorInterface*>(this);
    if (!strcmp(_clname, "org.kde.KParts.HtmlSettingsInterface"))
        return static_cast< HtmlSettingsInterface*>(this);
    return HtmlExtension::qt_metacast(_clname);
}

int WebEngineHtmlExtension::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = HtmlExtension::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
