/********************************************************************************
** Form generated from reading UI file 'capturesourcechooserdlg.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CAPTURESOURCECHOOSERDLG_H
#define UI_CAPTURESOURCECHOOSERDLG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>

namespace WebEngine {

class Ui_CaptureSourceChooserDlg
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *label;
    QVBoxLayout *verticalLayout_2;
    QSpacerItem *verticalSpacer_2;
    QHBoxLayout *horizontalLayout_2;
    QLabel *label_2;
    QComboBox *windowCombo;
    QSpacerItem *verticalSpacer;
    QHBoxLayout *horizontalLayout;
    QLabel *Screen;
    QComboBox *screenCombo;
    QSpacerItem *verticalSpacer_3;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *WebEngine__CaptureSourceChooserDlg)
    {
        if (WebEngine__CaptureSourceChooserDlg->objectName().isEmpty())
            WebEngine__CaptureSourceChooserDlg->setObjectName("WebEngine__CaptureSourceChooserDlg");
        WebEngine__CaptureSourceChooserDlg->resize(383, 217);
        verticalLayout = new QVBoxLayout(WebEngine__CaptureSourceChooserDlg);
        verticalLayout->setObjectName("verticalLayout");
        label = new QLabel(WebEngine__CaptureSourceChooserDlg);
        label->setObjectName("label");

        verticalLayout->addWidget(label);

        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer_2);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        label_2 = new QLabel(WebEngine__CaptureSourceChooserDlg);
        label_2->setObjectName("label_2");

        horizontalLayout_2->addWidget(label_2);

        windowCombo = new QComboBox(WebEngine__CaptureSourceChooserDlg);
        windowCombo->setObjectName("windowCombo");

        horizontalLayout_2->addWidget(windowCombo);


        verticalLayout_2->addLayout(horizontalLayout_2);

        verticalSpacer = new QSpacerItem(20, 5, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        Screen = new QLabel(WebEngine__CaptureSourceChooserDlg);
        Screen->setObjectName("Screen");

        horizontalLayout->addWidget(Screen);

        screenCombo = new QComboBox(WebEngine__CaptureSourceChooserDlg);
        screenCombo->setObjectName("screenCombo");

        horizontalLayout->addWidget(screenCombo);


        verticalLayout_2->addLayout(horizontalLayout);

        verticalSpacer_3 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer_3);


        verticalLayout->addLayout(verticalLayout_2);

        buttonBox = new QDialogButtonBox(WebEngine__CaptureSourceChooserDlg);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Orientation::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::StandardButton::Cancel);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(WebEngine__CaptureSourceChooserDlg);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, WebEngine__CaptureSourceChooserDlg, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, WebEngine__CaptureSourceChooserDlg, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(WebEngine__CaptureSourceChooserDlg);
    } // setupUi

    void retranslateUi(QDialog *WebEngine__CaptureSourceChooserDlg)
    {
        WebEngine__CaptureSourceChooserDlg->setWindowTitle(tr2i18n("Choose Capture Source", nullptr));
        label->setText(tr2i18n("Which part of your screen do you want to share?", nullptr));
        label_2->setText(tr2i18n("Window", nullptr));
        windowCombo->setPlaceholderText(tr2i18n("Choose window", nullptr));
        Screen->setText(tr2i18n("Screen", nullptr));
        screenCombo->setPlaceholderText(tr2i18n("Choose screen", nullptr));
    } // retranslateUi

};

} // namespace WebEngine

namespace WebEngine {
namespace Ui {
    class CaptureSourceChooserDlg: public Ui_CaptureSourceChooserDlg {};
} // namespace Ui
} // namespace WebEngine

#endif // CAPTURESOURCECHOOSERDLG_H

