/****************************************************************************
** Meta object code from reading C++ file 'sidebar_widget.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../konqueror-26.04.0/sidebar/sidebar_widget.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'sidebar_widget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14Sidebar_WidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto Sidebar_Widget::qt_create_metaobjectdata<qt_meta_tag_ZN14Sidebar_WidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Sidebar_Widget",
        "started",
        "",
        "KIO::Job*",
        "completed",
        "fileSelection",
        "KFileItemList",
        "items",
        "fileMouseOver",
        "KFileItem",
        "item",
        "curViewUrlChanged",
        "QUrl",
        "url",
        "panelHasBeenExpanded",
        "addWebSideBar",
        "name",
        "showHidePage",
        "value",
        "createButtons",
        "updateButtons",
        "slotRestoreDeletedButtons",
        "slotRollback",
        "aboutToShowConfigMenu",
        "saveConfig",
        "slotMultipleViews",
        "slotShowTabsLeft",
        "slotShowConfigurationButton",
        "slotSetName",
        "slotSetURL",
        "slotSetIcon",
        "slotToggleShowHiddenFolders",
        "slotRemove",
        "slotUrlsDropped",
        "QList<QUrl>",
        "urls",
        "openUrlRequest",
        "KParts::OpenUrlArguments",
        "args",
        "BrowserArguments",
        "browserArgs",
        "submitFormRequest",
        "const char*",
        "createNewWindow",
        "WindowArgs",
        "windowArgs",
        "slotEnableAction",
        "KonqSidebarModule*",
        "module",
        "enabled",
        "aboutToShowAddMenu",
        "triggeredAddMenu",
        "QAction*",
        "action",
        "slotPopupMenu",
        "QPoint",
        "global",
        "KParts::NavigationExtension::PopupFlags",
        "flags",
        "KParts::NavigationExtension::ActionGroupMap",
        "actionGroups",
        "slotStatResult",
        "KJob*",
        "job"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'started'
        QtMocHelpers::SignalData<void(KIO::Job *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'completed'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fileSelection'
        QtMocHelpers::SignalData<void(const KFileItemList &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Signal 'fileMouseOver'
        QtMocHelpers::SignalData<void(const KFileItem &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Signal 'curViewUrlChanged'
        QtMocHelpers::SignalData<void(const QUrl &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Signal 'panelHasBeenExpanded'
        QtMocHelpers::SignalData<void(bool)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'addWebSideBar'
        QtMocHelpers::SlotData<void(const QUrl &, const QString &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 }, { QMetaType::QString, 16 },
        }}),
        // Slot 'showHidePage'
        QtMocHelpers::SlotData<void(int)>(17, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Int, 18 },
        }}),
        // Slot 'createButtons'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'updateButtons'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotRestoreDeletedButtons'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotRollback'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'aboutToShowConfigMenu'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'saveConfig'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotMultipleViews'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotShowTabsLeft'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotShowConfigurationButton'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotSetName'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotSetURL'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotSetIcon'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotToggleShowHiddenFolders'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotRemove'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotUrlsDropped'
        QtMocHelpers::SlotData<void(const QList<QUrl> &)>(33, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 34, 35 },
        }}),
        // Slot 'openUrlRequest'
        QtMocHelpers::SlotData<void(const QUrl &, const KParts::OpenUrlArguments &, const BrowserArguments &)>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 }, { 0x80000000 | 37, 38 }, { 0x80000000 | 39, 40 },
        }}),
        // Slot 'submitFormRequest'
        QtMocHelpers::SlotData<void(const char *, const QString &, const QByteArray &, const QString &, const QString &, const QString &)>(41, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 42, 2 }, { QMetaType::QString, 2 }, { QMetaType::QByteArray, 2 }, { QMetaType::QString, 2 },
            { QMetaType::QString, 2 }, { QMetaType::QString, 2 },
        }}),
        // Slot 'createNewWindow'
        QtMocHelpers::SlotData<void(const QUrl &, const KParts::OpenUrlArguments &, const BrowserArguments &, const WindowArgs &)>(43, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 }, { 0x80000000 | 37, 38 }, { 0x80000000 | 39, 40 }, { 0x80000000 | 44, 45 },
        }}),
        // Slot 'slotEnableAction'
        QtMocHelpers::SlotData<void(KonqSidebarModule *, const char *, bool)>(46, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 47, 48 }, { 0x80000000 | 42, 16 }, { QMetaType::Bool, 49 },
        }}),
        // Slot 'aboutToShowAddMenu'
        QtMocHelpers::SlotData<void()>(50, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'triggeredAddMenu'
        QtMocHelpers::SlotData<void(QAction *)>(51, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 52, 53 },
        }}),
        // Slot 'slotPopupMenu'
        QtMocHelpers::SlotData<void(KonqSidebarModule *, const QPoint &, const KFileItemList &, const KParts::OpenUrlArguments &, const BrowserArguments &, KParts::NavigationExtension::PopupFlags, const KParts::NavigationExtension::ActionGroupMap &)>(54, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 47, 2 }, { 0x80000000 | 55, 56 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 37, 38 },
            { 0x80000000 | 39, 40 }, { 0x80000000 | 57, 58 }, { 0x80000000 | 59, 60 },
        }}),
        // Slot 'slotPopupMenu'
        QtMocHelpers::SlotData<void(KonqSidebarModule *, const QPoint &, const KFileItemList &, const KParts::OpenUrlArguments &, const BrowserArguments &, KParts::NavigationExtension::PopupFlags)>(54, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 47, 2 }, { 0x80000000 | 55, 56 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 37, 38 },
            { 0x80000000 | 39, 40 }, { 0x80000000 | 57, 58 },
        }}),
        // Slot 'slotPopupMenu'
        QtMocHelpers::SlotData<void(KonqSidebarModule *, const QPoint &, const KFileItemList &, const KParts::OpenUrlArguments &, const BrowserArguments &)>(54, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 47, 2 }, { 0x80000000 | 55, 56 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 37, 38 },
            { 0x80000000 | 39, 40 },
        }}),
        // Slot 'slotPopupMenu'
        QtMocHelpers::SlotData<void(KonqSidebarModule *, const QPoint &, const KFileItemList &, const KParts::OpenUrlArguments &)>(54, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 47, 2 }, { 0x80000000 | 55, 56 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 37, 38 },
        }}),
        // Slot 'slotPopupMenu'
        QtMocHelpers::SlotData<void(KonqSidebarModule *, const QPoint &, const KFileItemList &)>(54, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 47, 2 }, { 0x80000000 | 55, 56 }, { 0x80000000 | 6, 7 },
        }}),
        // Slot 'slotStatResult'
        QtMocHelpers::SlotData<void(KJob *)>(61, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 62, 63 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Sidebar_Widget, qt_meta_tag_ZN14Sidebar_WidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Sidebar_Widget::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14Sidebar_WidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14Sidebar_WidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14Sidebar_WidgetE_t>.metaTypes,
    nullptr
} };

void Sidebar_Widget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Sidebar_Widget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->started((*reinterpret_cast<std::add_pointer_t<KIO::Job*>>(_a[1]))); break;
        case 1: _t->completed(); break;
        case 2: _t->fileSelection((*reinterpret_cast<std::add_pointer_t<KFileItemList>>(_a[1]))); break;
        case 3: _t->fileMouseOver((*reinterpret_cast<std::add_pointer_t<KFileItem>>(_a[1]))); break;
        case 4: _t->curViewUrlChanged((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 5: _t->panelHasBeenExpanded((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->addWebSideBar((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 7: _t->showHidePage((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->createButtons(); break;
        case 9: _t->updateButtons(); break;
        case 10: _t->slotRestoreDeletedButtons(); break;
        case 11: _t->slotRollback(); break;
        case 12: _t->aboutToShowConfigMenu(); break;
        case 13: _t->saveConfig(); break;
        case 14: _t->slotMultipleViews(); break;
        case 15: _t->slotShowTabsLeft(); break;
        case 16: _t->slotShowConfigurationButton(); break;
        case 17: _t->slotSetName(); break;
        case 18: _t->slotSetURL(); break;
        case 19: _t->slotSetIcon(); break;
        case 20: _t->slotToggleShowHiddenFolders(); break;
        case 21: _t->slotRemove(); break;
        case 22: _t->slotUrlsDropped((*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[1]))); break;
        case 23: _t->openUrlRequest((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KParts::OpenUrlArguments>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<BrowserArguments>>(_a[3]))); break;
        case 24: _t->submitFormRequest((*reinterpret_cast<std::add_pointer_t<const char*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6]))); break;
        case 25: _t->createNewWindow((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KParts::OpenUrlArguments>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<BrowserArguments>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<WindowArgs>>(_a[4]))); break;
        case 26: _t->slotEnableAction((*reinterpret_cast<std::add_pointer_t<KonqSidebarModule*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<const char*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 27: _t->aboutToShowAddMenu(); break;
        case 28: _t->triggeredAddMenu((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 29: _t->slotPopupMenu((*reinterpret_cast<std::add_pointer_t<KonqSidebarModule*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<KFileItemList>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<KParts::OpenUrlArguments>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<BrowserArguments>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<KParts::NavigationExtension::PopupFlags>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<KParts::NavigationExtension::ActionGroupMap>>(_a[7]))); break;
        case 30: _t->slotPopupMenu((*reinterpret_cast<std::add_pointer_t<KonqSidebarModule*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<KFileItemList>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<KParts::OpenUrlArguments>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<BrowserArguments>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<KParts::NavigationExtension::PopupFlags>>(_a[6]))); break;
        case 31: _t->slotPopupMenu((*reinterpret_cast<std::add_pointer_t<KonqSidebarModule*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<KFileItemList>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<KParts::OpenUrlArguments>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<BrowserArguments>>(_a[5]))); break;
        case 32: _t->slotPopupMenu((*reinterpret_cast<std::add_pointer_t<KonqSidebarModule*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<KFileItemList>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<KParts::OpenUrlArguments>>(_a[4]))); break;
        case 33: _t->slotPopupMenu((*reinterpret_cast<std::add_pointer_t<KonqSidebarModule*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<KFileItemList>>(_a[3]))); break;
        case 34: _t->slotStatResult((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KIO::Job* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KFileItem >(); break;
            }
            break;
        case 26:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KonqSidebarModule* >(); break;
            }
            break;
        case 28:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 29:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KonqSidebarModule* >(); break;
            }
            break;
        case 30:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KonqSidebarModule* >(); break;
            }
            break;
        case 31:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KonqSidebarModule* >(); break;
            }
            break;
        case 32:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KonqSidebarModule* >(); break;
            }
            break;
        case 33:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KonqSidebarModule* >(); break;
            }
            break;
        case 34:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Sidebar_Widget::*)(KIO::Job * )>(_a, &Sidebar_Widget::started, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Sidebar_Widget::*)()>(_a, &Sidebar_Widget::completed, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Sidebar_Widget::*)(const KFileItemList & )>(_a, &Sidebar_Widget::fileSelection, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Sidebar_Widget::*)(const KFileItem & )>(_a, &Sidebar_Widget::fileMouseOver, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Sidebar_Widget::*)(const QUrl & )>(_a, &Sidebar_Widget::curViewUrlChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Sidebar_Widget::*)(bool )>(_a, &Sidebar_Widget::panelHasBeenExpanded, 5))
            return;
    }
}

const QMetaObject *Sidebar_Widget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Sidebar_Widget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14Sidebar_WidgetE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int Sidebar_Widget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 35)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 35;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 35)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 35;
    }
    return _id;
}

// SIGNAL 0
void Sidebar_Widget::started(KIO::Job * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Sidebar_Widget::completed()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Sidebar_Widget::fileSelection(const KFileItemList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Sidebar_Widget::fileMouseOver(const KFileItem & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Sidebar_Widget::curViewUrlChanged(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Sidebar_Widget::panelHasBeenExpanded(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}
QT_WARNING_POP
