/********************************************************************************
** Form generated from reading UI file 'tabsoptions.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TABSOPTIONS_H
#define UI_TABSOPTIONS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_TabsOptions
{
public:
    QVBoxLayout *verticalLayout_2;
    QGroupBox *groupBox_4;
    QVBoxLayout *verticalLayout_5;
    QCheckBox *m_pDynamicTabbarHide;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QComboBox *tabbarPosition;
    QSpacerItem *horizontalSpacer;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout;
    QCheckBox *m_pShowMMBInTabs;
    QCheckBox *m_pPopupsWithinTabs;
    QCheckBox *m_pKonquerorTabforExternalURL;
    QGroupBox *groupBox_2;
    QVBoxLayout *verticalLayout_3;
    QCheckBox *m_pNewTabsInBackground;
    QCheckBox *m_pOpenAfterCurrentPage;
    QGroupBox *groupBox_3;
    QVBoxLayout *verticalLayout_4;
    QCheckBox *m_pPermanentCloseButton;
    QCheckBox *m_pMiddleClickClose;
    QCheckBox *m_pTabConfirm;
    QCheckBox *m_pTabCloseActivatePrevious;
    QSpacerItem *spacerItem;

    void setupUi(QWidget *TabsOptions)
    {
        if (TabsOptions->objectName().isEmpty())
            TabsOptions->setObjectName("TabsOptions");
        TabsOptions->resize(401, 500);
        verticalLayout_2 = new QVBoxLayout(TabsOptions);
        verticalLayout_2->setObjectName("verticalLayout_2");
        groupBox_4 = new QGroupBox(TabsOptions);
        groupBox_4->setObjectName("groupBox_4");
        verticalLayout_5 = new QVBoxLayout(groupBox_4);
        verticalLayout_5->setObjectName("verticalLayout_5");
        m_pDynamicTabbarHide = new QCheckBox(groupBox_4);
        m_pDynamicTabbarHide->setObjectName("m_pDynamicTabbarHide");

        verticalLayout_5->addWidget(m_pDynamicTabbarHide);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label = new QLabel(groupBox_4);
        label->setObjectName("label");

        horizontalLayout->addWidget(label);

        tabbarPosition = new QComboBox(groupBox_4);
        tabbarPosition->addItem(QString());
        tabbarPosition->addItem(QString());
        tabbarPosition->addItem(QString());
        tabbarPosition->addItem(QString());
        tabbarPosition->setObjectName("tabbarPosition");

        horizontalLayout->addWidget(tabbarPosition);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        verticalLayout_5->addLayout(horizontalLayout);


        verticalLayout_2->addWidget(groupBox_4);

        groupBox = new QGroupBox(TabsOptions);
        groupBox->setObjectName("groupBox");
        verticalLayout = new QVBoxLayout(groupBox);
        verticalLayout->setObjectName("verticalLayout");
        m_pShowMMBInTabs = new QCheckBox(groupBox);
        m_pShowMMBInTabs->setObjectName("m_pShowMMBInTabs");

        verticalLayout->addWidget(m_pShowMMBInTabs);

        m_pPopupsWithinTabs = new QCheckBox(groupBox);
        m_pPopupsWithinTabs->setObjectName("m_pPopupsWithinTabs");

        verticalLayout->addWidget(m_pPopupsWithinTabs);

        m_pKonquerorTabforExternalURL = new QCheckBox(groupBox);
        m_pKonquerorTabforExternalURL->setObjectName("m_pKonquerorTabforExternalURL");

        verticalLayout->addWidget(m_pKonquerorTabforExternalURL);


        verticalLayout_2->addWidget(groupBox);

        groupBox_2 = new QGroupBox(TabsOptions);
        groupBox_2->setObjectName("groupBox_2");
        verticalLayout_3 = new QVBoxLayout(groupBox_2);
        verticalLayout_3->setObjectName("verticalLayout_3");
        m_pNewTabsInBackground = new QCheckBox(groupBox_2);
        m_pNewTabsInBackground->setObjectName("m_pNewTabsInBackground");

        verticalLayout_3->addWidget(m_pNewTabsInBackground);

        m_pOpenAfterCurrentPage = new QCheckBox(groupBox_2);
        m_pOpenAfterCurrentPage->setObjectName("m_pOpenAfterCurrentPage");

        verticalLayout_3->addWidget(m_pOpenAfterCurrentPage);


        verticalLayout_2->addWidget(groupBox_2);

        groupBox_3 = new QGroupBox(TabsOptions);
        groupBox_3->setObjectName("groupBox_3");
        verticalLayout_4 = new QVBoxLayout(groupBox_3);
        verticalLayout_4->setObjectName("verticalLayout_4");
        m_pPermanentCloseButton = new QCheckBox(groupBox_3);
        m_pPermanentCloseButton->setObjectName("m_pPermanentCloseButton");

        verticalLayout_4->addWidget(m_pPermanentCloseButton);

        m_pMiddleClickClose = new QCheckBox(groupBox_3);
        m_pMiddleClickClose->setObjectName("m_pMiddleClickClose");

        verticalLayout_4->addWidget(m_pMiddleClickClose);

        m_pTabConfirm = new QCheckBox(groupBox_3);
        m_pTabConfirm->setObjectName("m_pTabConfirm");

        verticalLayout_4->addWidget(m_pTabConfirm);

        m_pTabCloseActivatePrevious = new QCheckBox(groupBox_3);
        m_pTabCloseActivatePrevious->setObjectName("m_pTabCloseActivatePrevious");

        verticalLayout_4->addWidget(m_pTabCloseActivatePrevious);


        verticalLayout_2->addWidget(groupBox_3);

        spacerItem = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(spacerItem);

#if QT_CONFIG(shortcut)
        label->setBuddy(tabbarPosition);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(m_pDynamicTabbarHide, tabbarPosition);
        QWidget::setTabOrder(tabbarPosition, m_pShowMMBInTabs);
        QWidget::setTabOrder(m_pShowMMBInTabs, m_pPopupsWithinTabs);
        QWidget::setTabOrder(m_pPopupsWithinTabs, m_pKonquerorTabforExternalURL);
        QWidget::setTabOrder(m_pKonquerorTabforExternalURL, m_pNewTabsInBackground);
        QWidget::setTabOrder(m_pNewTabsInBackground, m_pOpenAfterCurrentPage);
        QWidget::setTabOrder(m_pOpenAfterCurrentPage, m_pPermanentCloseButton);
        QWidget::setTabOrder(m_pPermanentCloseButton, m_pMiddleClickClose);
        QWidget::setTabOrder(m_pMiddleClickClose, m_pTabConfirm);
        QWidget::setTabOrder(m_pTabConfirm, m_pTabCloseActivatePrevious);

        retranslateUi(TabsOptions);

        QMetaObject::connectSlotsByName(TabsOptions);
    } // setupUi

    void retranslateUi(QWidget *TabsOptions)
    {
        TabsOptions->setWindowTitle(tr2i18n("Tabs Behavior", nullptr));
        groupBox_4->setTitle(tr2i18n("Aspect", nullptr));
#if QT_CONFIG(whatsthis)
        m_pDynamicTabbarHide->setWhatsThis(tr2i18n("This will display the tab bar only if there are two or more tabs. Otherwise it will always be displayed.", nullptr));
#endif // QT_CONFIG(whatsthis)
        m_pDynamicTabbarHide->setText(tr2i18n("Hide the tab bar when only one tab is open", nullptr));
        label->setText(tr2i18n("Tab bar position", nullptr));
        tabbarPosition->setItemText(0, tr2i18n("Above contents", nullptr));
        tabbarPosition->setItemText(1, tr2i18n("Below contents", nullptr));
        tabbarPosition->setItemText(2, tr2i18n("Left of contents", nullptr));
        tabbarPosition->setItemText(3, tr2i18n("Right of contents", nullptr));

#if QT_CONFIG(whatsthis)
        tabbarPosition->setWhatsThis(tr2i18n("Choose where to display the tabs bar", nullptr));
#endif // QT_CONFIG(whatsthis)
        groupBox->setTitle(tr2i18n("Usage", nullptr));
#if QT_CONFIG(whatsthis)
        m_pShowMMBInTabs->setWhatsThis(tr2i18n("This will open a new tab instead of a new window in various situations, such as choosing a link or a folder with the middle mouse button.", nullptr));
#endif // QT_CONFIG(whatsthis)
        m_pShowMMBInTabs->setText(tr2i18n("Open &links in new tab instead of in new window", nullptr));
#if QT_CONFIG(whatsthis)
        m_pPopupsWithinTabs->setWhatsThis(tr2i18n("Whether or not JavaScript popups if allowed shall open in a new tab or in a new window.", nullptr));
#endif // QT_CONFIG(whatsthis)
        m_pPopupsWithinTabs->setText(tr2i18n("Open pop&ups in new tab instead of in new window", nullptr));
#if QT_CONFIG(whatsthis)
        m_pKonquerorTabforExternalURL->setWhatsThis(tr2i18n("When you click a URL in another KDE program or call kfmclient to open a URL, the current desktop will be searched for a non-minimized Konqueror and, if found, the URL opened as a new tab within it. Otherwise a new Konqueror window will be opened with the required URL.", nullptr));
#endif // QT_CONFIG(whatsthis)
        m_pKonquerorTabforExternalURL->setText(tr2i18n("Open as tab in existing Konqueror when URL is called externally", nullptr));
        groupBox_2->setTitle(tr2i18n("New Tab Behavior", nullptr));
#if QT_CONFIG(whatsthis)
        m_pNewTabsInBackground->setWhatsThis(tr2i18n("<html><head/><body><p>This will open a new tab in the background, instead of in the foreground.</p><p>Press <span style=\" font-family:'Fira Code';\">shift</span> when opening a new tab to reverse this behavior</p></body></html>", nullptr));
#endif // QT_CONFIG(whatsthis)
        m_pNewTabsInBackground->setText(tr2i18n("O&pen new tabs in the background", nullptr));
#if QT_CONFIG(whatsthis)
        m_pOpenAfterCurrentPage->setWhatsThis(tr2i18n("This will open a new tab opened from a page after the current tab, instead of after the last tab.", nullptr));
#endif // QT_CONFIG(whatsthis)
        m_pOpenAfterCurrentPage->setText(tr2i18n("Open &new tab after current tab", nullptr));
        groupBox_3->setTitle(tr2i18n("Closing", nullptr));
#if QT_CONFIG(whatsthis)
        m_pPermanentCloseButton->setWhatsThis(tr2i18n("This will display close buttons inside each tab.", nullptr));
#endif // QT_CONFIG(whatsthis)
        m_pPermanentCloseButton->setText(tr2i18n("&Show close button on tabs", nullptr));
#if QT_CONFIG(whatsthis)
        m_pMiddleClickClose->setWhatsThis(tr2i18n("When you click on a tab using the middle mouse button or mouse wheel, it will close that tab.", nullptr));
#endif // QT_CONFIG(whatsthis)
        m_pMiddleClickClose->setText(tr2i18n("Middle-click on a tab to close it", nullptr));
#if QT_CONFIG(whatsthis)
        m_pTabConfirm->setWhatsThis(tr2i18n("This will ask you whether you are sure you want to close a window when it has multiple tabs opened in it.", nullptr));
#endif // QT_CONFIG(whatsthis)
        m_pTabConfirm->setText(tr2i18n("Confirm &when closing windows with multiple tabs", nullptr));
#if QT_CONFIG(whatsthis)
        m_pTabCloseActivatePrevious->setWhatsThis(tr2i18n("When checking this the previous used or opened tab will be activated when you close the current active tab instead of the one right to the current tab.", nullptr));
#endif // QT_CONFIG(whatsthis)
        m_pTabCloseActivatePrevious->setText(tr2i18n("Activate previously used tab when closing the current tab", nullptr));
    } // retranslateUi

};

namespace Ui {
    class TabsOptions: public Ui_TabsOptions {};
} // namespace Ui

QT_END_NAMESPACE

#endif // TABSOPTIONS_H

