/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.Konqueror.UndoManager.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef KONQCLOSEDWINDOWSMANAGERADAPTOR_H
#define KONQCLOSEDWINDOWSMANAGERADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "konqclosedwindowsmanager.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.Konqueror.UndoManager
 */
class KonqClosedWindowsManagerAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.Konqueror.UndoManager")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.Konqueror.UndoManager\">\n"
"    <signal name=\"notifyClosedWindowItem\">\n"
"      <arg direction=\"out\" type=\"s\" name=\"title\"/>\n"
"      <arg direction=\"out\" type=\"i\" name=\"numTabs\"/>\n"
"      <arg direction=\"out\" type=\"s\" name=\"configFileName\"/>\n"
"      <arg direction=\"out\" type=\"s\" name=\"configGroup\"/>\n"
"    </signal>\n"
"    <signal name=\"notifyRemove\">\n"
"      <arg direction=\"out\" type=\"s\" name=\"configFileName\"/>\n"
"      <arg direction=\"out\" type=\"s\" name=\"configGroup\"/>\n"
"    </signal>\n"
"  </interface>\n"
        "")
public:
    KonqClosedWindowsManagerAdaptor(KonqClosedWindowsManager *parent);
    ~KonqClosedWindowsManagerAdaptor() override;

    inline KonqClosedWindowsManager *parent() const
    { return static_cast<KonqClosedWindowsManager *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
Q_SIGNALS: // SIGNALS
    void notifyClosedWindowItem(const QString &title, int numTabs, const QString &configFileName, const QString &configGroup);
    void notifyRemove(const QString &configFileName, const QString &configGroup);
};

#endif
