/********************************************************************************
** Form generated from reading UI file 'choosepagesaveformatdlg.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CHOOSEPAGESAVEFORMATDLG_H
#define UI_CHOOSEPAGESAVEFORMATDLG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ChoosePageSaveFormatDlg
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *label;
    QRadioButton *m_singleHTMLPage;
    QRadioButton *m_asDirectory;
    QRadioButton *m_asMHTMLPage;
    QLabel *m_info;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *ChoosePageSaveFormatDlg)
    {
        if (ChoosePageSaveFormatDlg->objectName().isEmpty())
            ChoosePageSaveFormatDlg->setObjectName("ChoosePageSaveFormatDlg");
        ChoosePageSaveFormatDlg->resize(520, 186);
        verticalLayout = new QVBoxLayout(ChoosePageSaveFormatDlg);
        verticalLayout->setObjectName("verticalLayout");
        label = new QLabel(ChoosePageSaveFormatDlg);
        label->setObjectName("label");

        verticalLayout->addWidget(label);

        m_singleHTMLPage = new QRadioButton(ChoosePageSaveFormatDlg);
        m_singleHTMLPage->setObjectName("m_singleHTMLPage");
        m_singleHTMLPage->setChecked(true);

        verticalLayout->addWidget(m_singleHTMLPage);

        m_asDirectory = new QRadioButton(ChoosePageSaveFormatDlg);
        m_asDirectory->setObjectName("m_asDirectory");

        verticalLayout->addWidget(m_asDirectory);

        m_asMHTMLPage = new QRadioButton(ChoosePageSaveFormatDlg);
        m_asMHTMLPage->setObjectName("m_asMHTMLPage");

        verticalLayout->addWidget(m_asMHTMLPage);

        m_info = new QLabel(ChoosePageSaveFormatDlg);
        m_info->setObjectName("m_info");
        m_info->setFrameShape(QFrame::StyledPanel);
        m_info->setFrameShadow(QFrame::Sunken);

        verticalLayout->addWidget(m_info);

        buttonBox = new QDialogButtonBox(ChoosePageSaveFormatDlg);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(ChoosePageSaveFormatDlg);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, ChoosePageSaveFormatDlg, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, ChoosePageSaveFormatDlg, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(ChoosePageSaveFormatDlg);
    } // setupUi

    void retranslateUi(QDialog *ChoosePageSaveFormatDlg)
    {
        ChoosePageSaveFormatDlg->setWindowTitle(tr2i18n("Choose Save Format", nullptr));
        label->setText(tr2i18n("How would you like to save the page?", nullptr));
        m_singleHTMLPage->setText(tr2i18n("As an HTML file &without external resources", nullptr));
        m_asDirectory->setText(tr2i18n("As a &complete HTML page", nullptr));
        m_asMHTMLPage->setText(tr2i18n("As a &MHTML file", nullptr));
        m_info->setText(tr2i18n("TextLabel", nullptr));
    } // retranslateUi

};

namespace Ui {
    class ChoosePageSaveFormatDlg: public Ui_ChoosePageSaveFormatDlg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CHOOSEPAGESAVEFORMATDLG_H

