/********************************************************************************
** Form generated from reading UI file 'konqueror_ui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_KONQUEROR_UI_H
#define UI_KONQUEROR_UI_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

namespace KCMPerformance {

class Ui_Konqueror_ui
{
public:
    QVBoxLayout *vboxLayout;
    QGroupBox *groupBox1;
    QVBoxLayout *vboxLayout1;
    QCheckBox *cb_preload_on_startup;
    QCheckBox *cb_always_have_preloaded;
    QSpacerItem *spacer1;

    void setupUi(QWidget *KCMPerformance__Konqueror_ui)
    {
        if (KCMPerformance__Konqueror_ui->objectName().isEmpty())
            KCMPerformance__Konqueror_ui->setObjectName("KCMPerformance__Konqueror_ui");
        KCMPerformance__Konqueror_ui->resize(600, 480);
        vboxLayout = new QVBoxLayout(KCMPerformance__Konqueror_ui);
        vboxLayout->setObjectName("vboxLayout");
        groupBox1 = new QGroupBox(KCMPerformance__Konqueror_ui);
        groupBox1->setObjectName("groupBox1");
        vboxLayout1 = new QVBoxLayout(groupBox1);
        vboxLayout1->setObjectName("vboxLayout1");
        cb_preload_on_startup = new QCheckBox(groupBox1);
        cb_preload_on_startup->setObjectName("cb_preload_on_startup");

        vboxLayout1->addWidget(cb_preload_on_startup);

        cb_always_have_preloaded = new QCheckBox(groupBox1);
        cb_always_have_preloaded->setObjectName("cb_always_have_preloaded");

        vboxLayout1->addWidget(cb_always_have_preloaded);


        vboxLayout->addWidget(groupBox1);

        spacer1 = new QSpacerItem(20, 160, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(spacer1);


        retranslateUi(KCMPerformance__Konqueror_ui);

        QMetaObject::connectSlotsByName(KCMPerformance__Konqueror_ui);
    } // setupUi

    void retranslateUi(QWidget *KCMPerformance__Konqueror_ui)
    {
        groupBox1->setTitle(tr2i18n("Preloading", nullptr));
        cb_preload_on_startup->setText(tr2i18n("Preload an instance after desktop startup", nullptr));
        cb_always_have_preloaded->setText(tr2i18n("Always try to have one preloaded instance", nullptr));
        (void)KCMPerformance__Konqueror_ui;
    } // retranslateUi

};

} // namespace KCMPerformance

namespace KCMPerformance {
namespace Ui {
    class Konqueror_ui: public Ui_Konqueror_ui {};
} // namespace Ui
} // namespace KCMPerformance

#endif // KONQUEROR_UI_H

