/********************************************************************************
** Form generated from reading UI file 'bookmarks.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_BOOKMARKS_H
#define UI_BOOKMARKS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_BookmarksConfigUI
{
public:
    QGridLayout *gridLayout;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout;
    QCheckBox *cbShowRoot;
    QCheckBox *cbFlattenTree;
    QCheckBox *cbShowPlaces;
    QGroupBox *groupBox_2;
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QSpinBox *sbColumns;
    QSpacerItem *horizontalSpacer;
    QCheckBox *cbShowBackgrounds;
    QSpacerItem *verticalSpacer;
    QGroupBox *groupBox_3;
    QHBoxLayout *horizontalLayout_2;
    QLabel *lbMaxCacheSize;
    QSpinBox *sbCacheSize;
    QPushButton *clearCacheButton;
    QSpacerItem *horizontalSpacer_2;

    void setupUi(QWidget *BookmarksConfigUI)
    {
        if (BookmarksConfigUI->objectName().isEmpty())
            BookmarksConfigUI->setObjectName("BookmarksConfigUI");
        BookmarksConfigUI->resize(704, 636);
        gridLayout = new QGridLayout(BookmarksConfigUI);
        gridLayout->setObjectName("gridLayout");
        groupBox = new QGroupBox(BookmarksConfigUI);
        groupBox->setObjectName("groupBox");
        verticalLayout = new QVBoxLayout(groupBox);
        verticalLayout->setObjectName("verticalLayout");
        cbShowRoot = new QCheckBox(groupBox);
        cbShowRoot->setObjectName("cbShowRoot");
        cbShowRoot->setChecked(true);

        verticalLayout->addWidget(cbShowRoot);

        cbFlattenTree = new QCheckBox(groupBox);
        cbFlattenTree->setObjectName("cbFlattenTree");

        verticalLayout->addWidget(cbFlattenTree);

        cbShowPlaces = new QCheckBox(groupBox);
        cbShowPlaces->setObjectName("cbShowPlaces");
        cbShowPlaces->setChecked(true);

        verticalLayout->addWidget(cbShowPlaces);


        gridLayout->addWidget(groupBox, 1, 0, 1, 1);

        groupBox_2 = new QGroupBox(BookmarksConfigUI);
        groupBox_2->setObjectName("groupBox_2");
        verticalLayout_2 = new QVBoxLayout(groupBox_2);
        verticalLayout_2->setObjectName("verticalLayout_2");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label = new QLabel(groupBox_2);
        label->setObjectName("label");

        horizontalLayout->addWidget(label);

        sbColumns = new QSpinBox(groupBox_2);
        sbColumns->setObjectName("sbColumns");
        sbColumns->setMinimum(1);
        sbColumns->setValue(4);

        horizontalLayout->addWidget(sbColumns);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        verticalLayout_2->addLayout(horizontalLayout);

        cbShowBackgrounds = new QCheckBox(groupBox_2);
        cbShowBackgrounds->setObjectName("cbShowBackgrounds");
        cbShowBackgrounds->setChecked(true);

        verticalLayout_2->addWidget(cbShowBackgrounds);


        gridLayout->addWidget(groupBox_2, 0, 0, 1, 1);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 3, 0, 1, 1);

        groupBox_3 = new QGroupBox(BookmarksConfigUI);
        groupBox_3->setObjectName("groupBox_3");
        horizontalLayout_2 = new QHBoxLayout(groupBox_3);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        lbMaxCacheSize = new QLabel(groupBox_3);
        lbMaxCacheSize->setObjectName("lbMaxCacheSize");
        lbMaxCacheSize->setEnabled(true);

        horizontalLayout_2->addWidget(lbMaxCacheSize);

        sbCacheSize = new QSpinBox(groupBox_3);
        sbCacheSize->setObjectName("sbCacheSize");
        sbCacheSize->setEnabled(true);

        horizontalLayout_2->addWidget(sbCacheSize);

        clearCacheButton = new QPushButton(groupBox_3);
        clearCacheButton->setObjectName("clearCacheButton");
        clearCacheButton->setEnabled(true);

        horizontalLayout_2->addWidget(clearCacheButton);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_2);


        gridLayout->addWidget(groupBox_3, 2, 0, 1, 1);

#if QT_CONFIG(shortcut)
        lbMaxCacheSize->setBuddy(sbCacheSize);
#endif // QT_CONFIG(shortcut)

        retranslateUi(BookmarksConfigUI);

        QMetaObject::connectSlotsByName(BookmarksConfigUI);
    } // setupUi

    void retranslateUi(QWidget *BookmarksConfigUI)
    {
        groupBox->setTitle(tr2i18n("Bookmarks", nullptr));
#if QT_CONFIG(whatsthis)
        cbShowRoot->setWhatsThis(tr2i18n("If this option is unchecked, bookmarks at the root of the hierarchy (not in a folder) are not displayed.\n"
"If checked, they are gathered in a \"root\" folder.", nullptr));
#endif // QT_CONFIG(whatsthis)
        cbShowRoot->setText(tr2i18n("&Show bookmarks without folder", nullptr));
#if QT_CONFIG(whatsthis)
        cbFlattenTree->setWhatsThis(tr2i18n("Sub-folders are shown within their parent by default. If you activate this option, sub-folders are displayed on their own.\n"
"It looks less nice but it may help if you have a very big folder you want to spread in two columns.", nullptr));
#endif // QT_CONFIG(whatsthis)
        cbFlattenTree->setText(tr2i18n("&Flatten bookmarks tree", nullptr));
#if QT_CONFIG(whatsthis)
        cbShowPlaces->setWhatsThis(tr2i18n("Show a box with KDE places (Home, Network, ...). Useful if you use konqueror as a file manager.", nullptr));
#endif // QT_CONFIG(whatsthis)
        cbShowPlaces->setText(tr2i18n("Show system &places", nullptr));
        groupBox_2->setTitle(tr2i18n("General Settings", nullptr));
#if QT_CONFIG(whatsthis)
        label->setWhatsThis(tr2i18n("Folders are automatically distributed in several columns. The optimal number of columns depends on the width of the konqueror window and the number of bookmarks you have.", nullptr));
#endif // QT_CONFIG(whatsthis)
        label->setText(tr2i18n("Number of columns to show:", nullptr));
#if QT_CONFIG(whatsthis)
        sbColumns->setWhatsThis(QString());
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(whatsthis)
        cbShowBackgrounds->setWhatsThis(tr2i18n("Disable it on slow system to disable background images.", nullptr));
#endif // QT_CONFIG(whatsthis)
        cbShowBackgrounds->setText(tr2i18n("Show folder &backgrounds", nullptr));
#if QT_CONFIG(whatsthis)
        groupBox_3->setWhatsThis(tr2i18n("How much disk space is used to cache the pixmaps", nullptr));
#endif // QT_CONFIG(whatsthis)
        groupBox_3->setTitle(tr2i18n("Pixmap Cache", nullptr));
        lbMaxCacheSize->setText(tr2i18n("Disk cache size:", nullptr));
        sbCacheSize->setSuffix(tr2i18n(" kB", nullptr));
#if QT_CONFIG(whatsthis)
        clearCacheButton->setWhatsThis(tr2i18n("Clear the pixmap cache", nullptr));
#endif // QT_CONFIG(whatsthis)
        clearCacheButton->setText(tr2i18n("&Clear Cache", nullptr));
        (void)BookmarksConfigUI;
    } // retranslateUi

};

namespace Ui {
    class BookmarksConfigUI: public Ui_BookmarksConfigUI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // BOOKMARKS_H

