/********************************************************************************
** Form generated from reading UI file 'konqsessiondlg_base.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_KONQSESSIONDLG_BASE_H
#define UI_KONQSESSIONDLG_BASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QListView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_KonqSessionDlgBase
{
public:
    QGridLayout *gridLayout;
    QHBoxLayout *horizontalLayout;
    QListView *m_pListView;
    QVBoxLayout *verticalLayout_2;
    QVBoxLayout *verticalLayout;
    QPushButton *m_pNewButton;
    QPushButton *m_pSaveCurrentButton;
    QPushButton *m_pRenameButton;
    QPushButton *m_pDeleteButton;
    QSpacerItem *verticalSpacer;
    QCheckBox *m_pOpenTabsInsideCurrentWindow;

    void setupUi(QWidget *KonqSessionDlgBase)
    {
        if (KonqSessionDlgBase->objectName().isEmpty())
            KonqSessionDlgBase->setObjectName("KonqSessionDlgBase");
        KonqSessionDlgBase->resize(335, 195);
        gridLayout = new QGridLayout(KonqSessionDlgBase);
        gridLayout->setObjectName("gridLayout");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        m_pListView = new QListView(KonqSessionDlgBase);
        m_pListView->setObjectName("m_pListView");

        horizontalLayout->addWidget(m_pListView);

        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        m_pNewButton = new QPushButton(KonqSessionDlgBase);
        m_pNewButton->setObjectName("m_pNewButton");

        verticalLayout->addWidget(m_pNewButton);

        m_pSaveCurrentButton = new QPushButton(KonqSessionDlgBase);
        m_pSaveCurrentButton->setObjectName("m_pSaveCurrentButton");

        verticalLayout->addWidget(m_pSaveCurrentButton);

        m_pRenameButton = new QPushButton(KonqSessionDlgBase);
        m_pRenameButton->setObjectName("m_pRenameButton");

        verticalLayout->addWidget(m_pRenameButton);

        m_pDeleteButton = new QPushButton(KonqSessionDlgBase);
        m_pDeleteButton->setObjectName("m_pDeleteButton");

        verticalLayout->addWidget(m_pDeleteButton);


        verticalLayout_2->addLayout(verticalLayout);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer);


        horizontalLayout->addLayout(verticalLayout_2);


        gridLayout->addLayout(horizontalLayout, 0, 0, 1, 1);

        m_pOpenTabsInsideCurrentWindow = new QCheckBox(KonqSessionDlgBase);
        m_pOpenTabsInsideCurrentWindow->setObjectName("m_pOpenTabsInsideCurrentWindow");

        gridLayout->addWidget(m_pOpenTabsInsideCurrentWindow, 1, 0, 1, 1);


        retranslateUi(KonqSessionDlgBase);

        QMetaObject::connectSlotsByName(KonqSessionDlgBase);
    } // setupUi

    void retranslateUi(QWidget *KonqSessionDlgBase)
    {
        m_pNewButton->setText(tr2i18n("New...", "@action:button New session"));
        m_pSaveCurrentButton->setText(tr2i18n("Save Current...", "@action:button Save current session"));
        m_pRenameButton->setText(tr2i18n("Rename...", "@action:button Rename session"));
        m_pDeleteButton->setText(tr2i18n("Delete", "@action:button Delete session"));
        m_pOpenTabsInsideCurrentWindow->setText(tr2i18n("Open tabs inside current window", nullptr));
        (void)KonqSessionDlgBase;
    } // retranslateUi

};

namespace Ui {
    class KonqSessionDlgBase: public Ui_KonqSessionDlgBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // KONQSESSIONDLG_BASE_H

