// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "akregatorplugindebug.h"


Q_LOGGING_CATEGORY(AKREGATORPLUGIN_LOG, "org.kde.konqueror.akregatorplugin", QtInfoMsg)

