/********************************************************************************
** Form generated from reading UI file 'credentialsdetailswidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CREDENTIALSDETAILSWIDGET_H
#define UI_CREDENTIALSDETAILSWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "webfieldsdataview.h"

QT_BEGIN_NAMESPACE

class Ui_CredentialsDetailsWidget
{
public:
    QHBoxLayout *horizontalLayout_2;
    QVBoxLayout *verticalLayout;
    WebFieldsDataView *fields;
    QHBoxLayout *horizontalLayout;
    QCheckBox *showPasswords;

    void setupUi(QWidget *CredentialsDetailsWidget)
    {
        if (CredentialsDetailsWidget->objectName().isEmpty())
            CredentialsDetailsWidget->setObjectName("CredentialsDetailsWidget");
        CredentialsDetailsWidget->resize(304, 236);
        CredentialsDetailsWidget->setAutoFillBackground(true);
        horizontalLayout_2 = new QHBoxLayout(CredentialsDetailsWidget);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        fields = new WebFieldsDataView(CredentialsDetailsWidget);
        fields->setObjectName("fields");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Minimum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(fields->sizePolicy().hasHeightForWidth());
        fields->setSizePolicy(sizePolicy);

        verticalLayout->addWidget(fields);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        showPasswords = new QCheckBox(CredentialsDetailsWidget);
        showPasswords->setObjectName("showPasswords");

        horizontalLayout->addWidget(showPasswords);


        verticalLayout->addLayout(horizontalLayout);


        horizontalLayout_2->addLayout(verticalLayout);


        retranslateUi(CredentialsDetailsWidget);

        QMetaObject::connectSlotsByName(CredentialsDetailsWidget);
    } // setupUi

    void retranslateUi(QWidget *CredentialsDetailsWidget)
    {
        showPasswords->setText(tr2i18n("&Show passwords", nullptr));
        (void)CredentialsDetailsWidget;
    } // retranslateUi

};

namespace Ui {
    class CredentialsDetailsWidget: public Ui_CredentialsDetailsWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CREDENTIALSDETAILSWIDGET_H

