/****************************************************************************
** Meta object code from reading C++ file 'KonquerorAdaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../konqueror-26.04.0/src/KonquerorAdaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'KonquerorAdaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16KonquerorAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto KonquerorAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN16KonquerorAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KonquerorAdaptor",
        "D-Bus Interface",
        "org.kde.Konqueror.Main",
        "reparseConfiguration",
        "",
        "addToCombo",
        "url",
        "QDBusMessage",
        "msg",
        "removeFromCombo",
        "comboCleared",
        "openBrowserWindow",
        "QDBusObjectPath",
        "startup_id",
        "createNewWindow",
        "mimetype",
        "tempFile",
        "createNewWindowWithSelection",
        "filesToSelect",
        "getWindows",
        "QList<QDBusObjectPath>",
        "urls",
        "windowForTab"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'reparseConfiguration'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'addToCombo'
        QtMocHelpers::SignalData<void(const QString &, const QDBusMessage &)>(5, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 }, { 0x80000000 | 7, 8 },
        }}),
        // Signal 'removeFromCombo'
        QtMocHelpers::SignalData<void(const QString &, const QDBusMessage &)>(9, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 }, { 0x80000000 | 7, 8 },
        }}),
        // Signal 'comboCleared'
        QtMocHelpers::SignalData<void(const QDBusMessage &)>(10, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Slot 'openBrowserWindow'
        QtMocHelpers::SlotData<QDBusObjectPath(const QString &, const QByteArray &)>(11, 4, QMC::AccessPublic, 0x80000000 | 12, {{
            { QMetaType::QString, 6 }, { QMetaType::QByteArray, 13 },
        }}),
        // Slot 'createNewWindow'
        QtMocHelpers::SlotData<QDBusObjectPath(const QString &, const QString &, const QByteArray &, bool)>(14, 4, QMC::AccessPublic, 0x80000000 | 12, {{
            { QMetaType::QString, 6 }, { QMetaType::QString, 15 }, { QMetaType::QByteArray, 13 }, { QMetaType::Bool, 16 },
        }}),
        // Slot 'createNewWindowWithSelection'
        QtMocHelpers::SlotData<QDBusObjectPath(const QString &, const QStringList &, const QByteArray &)>(17, 4, QMC::AccessPublic, 0x80000000 | 12, {{
            { QMetaType::QString, 6 }, { QMetaType::QStringList, 18 }, { QMetaType::QByteArray, 13 },
        }}),
        // Slot 'getWindows'
        QtMocHelpers::SlotData<QList<QDBusObjectPath>()>(19, 4, QMC::AccessPublic, 0x80000000 | 20),
        // Slot 'urls'
        QtMocHelpers::SlotData<QStringList() const>(21, 4, QMC::AccessPublic, QMetaType::QStringList),
        // Slot 'windowForTab'
        QtMocHelpers::SlotData<QDBusObjectPath()>(22, 4, QMC::AccessPublic, 0x80000000 | 12),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<KonquerorAdaptor, qt_meta_tag_ZN16KonquerorAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject KonquerorAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KonquerorAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KonquerorAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16KonquerorAdaptorE_t>.metaTypes,
    nullptr
} };

void KonquerorAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KonquerorAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->reparseConfiguration(); break;
        case 1: _t->addToCombo((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusMessage>>(_a[2]))); break;
        case 2: _t->removeFromCombo((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusMessage>>(_a[2]))); break;
        case 3: _t->comboCleared((*reinterpret_cast<std::add_pointer_t<QDBusMessage>>(_a[1]))); break;
        case 4: { QDBusObjectPath _r = _t->openBrowserWindow((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusObjectPath*>(_a[0]) = std::move(_r); }  break;
        case 5: { QDBusObjectPath _r = _t->createNewWindow((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QDBusObjectPath*>(_a[0]) = std::move(_r); }  break;
        case 6: { QDBusObjectPath _r = _t->createNewWindowWithSelection((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusObjectPath*>(_a[0]) = std::move(_r); }  break;
        case 7: { QList<QDBusObjectPath> _r = _t->getWindows();
            if (_a[0]) *reinterpret_cast<QList<QDBusObjectPath>*>(_a[0]) = std::move(_r); }  break;
        case 8: { QStringList _r = _t->urls();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 9: { QDBusObjectPath _r = _t->windowForTab();
            if (_a[0]) *reinterpret_cast<QDBusObjectPath*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusMessage >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusMessage >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusMessage >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KonquerorAdaptor::*)()>(_a, &KonquerorAdaptor::reparseConfiguration, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KonquerorAdaptor::*)(const QString & , const QDBusMessage & )>(_a, &KonquerorAdaptor::addToCombo, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KonquerorAdaptor::*)(const QString & , const QDBusMessage & )>(_a, &KonquerorAdaptor::removeFromCombo, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (KonquerorAdaptor::*)(const QDBusMessage & )>(_a, &KonquerorAdaptor::comboCleared, 3))
            return;
    }
}

const QMetaObject *KonquerorAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KonquerorAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KonquerorAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KonquerorAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void KonquerorAdaptor::reparseConfiguration()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KonquerorAdaptor::addToCombo(const QString & _t1, const QDBusMessage & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void KonquerorAdaptor::removeFromCombo(const QString & _t1, const QDBusMessage & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void KonquerorAdaptor::comboCleared(const QDBusMessage & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}
QT_WARNING_POP
