/****************************************************************************
** Meta object code from reading C++ file 'konqundomanager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../konqueror-26.04.0/src/konqundomanager.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'konqundomanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15KonqUndoManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto KonqUndoManager::qt_create_metaobjectdata<qt_meta_tag_ZN15KonqUndoManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KonqUndoManager",
        "undoAvailable",
        "",
        "canUndo",
        "undoTextChanged",
        "text",
        "openClosedTab",
        "KonqClosedTabItem",
        "openClosedWindow",
        "KonqClosedWindowItem",
        "closedItemsListChanged",
        "removeWindowInOtherInstances",
        "KonqUndoManager*",
        "real_sender",
        "const KonqClosedWindowItem*",
        "closedWindowItem",
        "addWindowInOtherInstances",
        "KonqClosedWindowItem*",
        "undo",
        "clearClosedItemsList",
        "onlyInthisWindow",
        "undoLastClosedItem",
        "slotClosedItemsActivated",
        "QAction*",
        "action",
        "slotAddClosedWindowItem",
        "slotFileUndoAvailable",
        "slotFileUndoTextChanged",
        "slotRemoveClosedWindowItem"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'undoAvailable'
        QtMocHelpers::SignalData<void(bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'undoTextChanged'
        QtMocHelpers::SignalData<void(const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'openClosedTab'
        QtMocHelpers::SignalData<void(const KonqClosedTabItem &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 2 },
        }}),
        // Signal 'openClosedWindow'
        QtMocHelpers::SignalData<void(const KonqClosedWindowItem &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 2 },
        }}),
        // Signal 'closedItemsListChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'removeWindowInOtherInstances'
        QtMocHelpers::SignalData<void(KonqUndoManager *, const KonqClosedWindowItem *)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 }, { 0x80000000 | 14, 15 },
        }}),
        // Signal 'addWindowInOtherInstances'
        QtMocHelpers::SignalData<void(KonqUndoManager *, KonqClosedWindowItem *)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 }, { 0x80000000 | 17, 15 },
        }}),
        // Slot 'undo'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'clearClosedItemsList'
        QtMocHelpers::SlotData<void(bool)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 20 },
        }}),
        // Slot 'clearClosedItemsList'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'undoLastClosedItem'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotClosedItemsActivated'
        QtMocHelpers::SlotData<void(QAction *)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 23, 24 },
        }}),
        // Slot 'slotAddClosedWindowItem'
        QtMocHelpers::SlotData<void(KonqUndoManager *, KonqClosedWindowItem *)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 }, { 0x80000000 | 17, 15 },
        }}),
        // Slot 'slotFileUndoAvailable'
        QtMocHelpers::SlotData<void(bool)>(26, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'slotFileUndoTextChanged'
        QtMocHelpers::SlotData<void(const QString &)>(27, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Slot 'slotRemoveClosedWindowItem'
        QtMocHelpers::SlotData<void(KonqUndoManager *, const KonqClosedWindowItem *)>(28, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 12, 13 }, { 0x80000000 | 14, 15 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KonqUndoManager, qt_meta_tag_ZN15KonqUndoManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KonqUndoManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15KonqUndoManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15KonqUndoManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15KonqUndoManagerE_t>.metaTypes,
    nullptr
} };

void KonqUndoManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KonqUndoManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->undoAvailable((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->undoTextChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->openClosedTab((*reinterpret_cast<std::add_pointer_t<KonqClosedTabItem>>(_a[1]))); break;
        case 3: _t->openClosedWindow((*reinterpret_cast<std::add_pointer_t<KonqClosedWindowItem>>(_a[1]))); break;
        case 4: _t->closedItemsListChanged(); break;
        case 5: _t->removeWindowInOtherInstances((*reinterpret_cast<std::add_pointer_t<KonqUndoManager*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<const KonqClosedWindowItem*>>(_a[2]))); break;
        case 6: _t->addWindowInOtherInstances((*reinterpret_cast<std::add_pointer_t<KonqUndoManager*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KonqClosedWindowItem*>>(_a[2]))); break;
        case 7: _t->undo(); break;
        case 8: _t->clearClosedItemsList((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->clearClosedItemsList(); break;
        case 10: _t->undoLastClosedItem(); break;
        case 11: _t->slotClosedItemsActivated((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 12: _t->slotAddClosedWindowItem((*reinterpret_cast<std::add_pointer_t<KonqUndoManager*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KonqClosedWindowItem*>>(_a[2]))); break;
        case 13: _t->slotFileUndoAvailable((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 14: _t->slotFileUndoTextChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 15: _t->slotRemoveClosedWindowItem((*reinterpret_cast<std::add_pointer_t<KonqUndoManager*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<const KonqClosedWindowItem*>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KonqUndoManager* >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KonqUndoManager* >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KonqUndoManager* >(); break;
            }
            break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KonqUndoManager* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KonqUndoManager::*)(bool )>(_a, &KonqUndoManager::undoAvailable, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KonqUndoManager::*)(const QString & )>(_a, &KonqUndoManager::undoTextChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KonqUndoManager::*)(const KonqClosedTabItem & )>(_a, &KonqUndoManager::openClosedTab, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (KonqUndoManager::*)(const KonqClosedWindowItem & )>(_a, &KonqUndoManager::openClosedWindow, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (KonqUndoManager::*)()>(_a, &KonqUndoManager::closedItemsListChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (KonqUndoManager::*)(KonqUndoManager * , const KonqClosedWindowItem * )>(_a, &KonqUndoManager::removeWindowInOtherInstances, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (KonqUndoManager::*)(KonqUndoManager * , KonqClosedWindowItem * )>(_a, &KonqUndoManager::addWindowInOtherInstances, 6))
            return;
    }
}

const QMetaObject *KonqUndoManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KonqUndoManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15KonqUndoManagerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KonqUndoManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    return _id;
}

// SIGNAL 0
void KonqUndoManager::undoAvailable(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void KonqUndoManager::undoTextChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void KonqUndoManager::openClosedTab(const KonqClosedTabItem & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void KonqUndoManager::openClosedWindow(const KonqClosedWindowItem & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void KonqUndoManager::closedItemsListChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void KonqUndoManager::removeWindowInOtherInstances(KonqUndoManager * _t1, const KonqClosedWindowItem * _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}

// SIGNAL 6
void KonqUndoManager::addWindowInOtherInstances(KonqUndoManager * _t1, KonqClosedWindowItem * _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
}
QT_WARNING_POP
