/****************************************************************************
** Meta object code from reading C++ file 'konqmainwindow.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../konqueror-26.04.0/src/konqmainwindow.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'konqmainwindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14KonqMainWindowE_t {};
} // unnamed namespace

template <> constexpr inline auto KonqMainWindow::qt_create_metaobjectdata<qt_meta_tag_ZN14KonqMainWindowE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KonqMainWindow",
        "viewAdded",
        "",
        "KonqView*",
        "view",
        "viewRemoved",
        "popupItemsDisturbed",
        "aboutToConfigure",
        "closing",
        "KonqMainWindow*",
        "window",
        "openUrl",
        "QUrl",
        "url",
        "serviceType",
        "KonqOpenURLRequest",
        "req",
        "trustedSource",
        "updateViewModeActions",
        "activateTab",
        "index",
        "slotInternalViewModeChanged",
        "slotCtrlTabPressed",
        "slotPopupMenu",
        "QPoint",
        "global",
        "KFileItemList",
        "items",
        "KParts::OpenUrlArguments",
        "args",
        "BrowserArguments",
        "browserArgs",
        "KParts::NavigationExtension::PopupFlags",
        "flags",
        "KParts::NavigationExtension::ActionGroupMap",
        "mode_t",
        "mode",
        "f",
        "slotOpenURLRequest",
        "KonqOpenURLRequest&",
        "childView",
        "slotCreateNewWindow",
        "WindowArgs",
        "windowArgs",
        "KParts::ReadOnlyPart**",
        "part",
        "slotNewWindow",
        "slotDuplicateWindow",
        "slotSendURL",
        "slotSendFile",
        "slotCopyFiles",
        "slotMoveFiles",
        "slotOpenLocation",
        "slotOpenFile",
        "slotViewModeTriggered",
        "QAction*",
        "action",
        "slotLockView",
        "slotLinkView",
        "slotReload",
        "slotForceReload",
        "slotStop",
        "slotUp",
        "slotBack",
        "slotForward",
        "slotHome",
        "slotGoHistory",
        "slotAddClosedUrl",
        "KonqFrameBase*",
        "tab",
        "slotConfigure",
        "Konq::ConfigDialog::Module",
        "module",
        "slotConfigureDone",
        "slotConfigureToolbars",
        "slotConfigureExtensions",
        "slotConfigureSpellChecking",
        "slotNewToolbarConfig",
        "slotUndoAvailable",
        "avail",
        "slotPartChanged",
        "KParts::ReadOnlyPart*",
        "oldPart",
        "newPart",
        "urlLoaderFinished",
        "UrlLoader*",
        "loader",
        "slotClearLocationBar",
        "slotSetStatusBarText",
        "text",
        "slotPartActivated",
        "KParts::Part*",
        "slotGoHistoryActivated",
        "steps",
        "slotAddTab",
        "slotSplitViewHorizontal",
        "slotSplitViewVertical",
        "slotRemoveOtherTabs",
        "slotRemoveTabPopup",
        "slotReloadAllTabs",
        "slotRemoveOtherTabsPopup",
        "forceSaveMainWindowSettings",
        "slotDuplicateTabPopup",
        "slotReloadPopup",
        "slotBreakOffTabPopup",
        "slotViewCompleted",
        "slotURLEntered",
        "Qt::KeyboardModifiers",
        "slotLocationLabelActivated",
        "slotDuplicateTab",
        "slotBreakOffTab",
        "breakOffTab",
        "slotPopupNewWindow",
        "slotPopupThisWindow",
        "slotPopupNewTab",
        "slotPopupPasteTo",
        "slotRemoveView",
        "slotRemoveTab",
        "removeTab",
        "tabIndex",
        "removeOtherTabs",
        "slotActivateNextTab",
        "slotActivatePrevTab",
        "slotActivateTab",
        "slotDumpDebugInfo",
        "slotOpenEmbedded",
        "KPluginMetaData",
        "slotReconfigure",
        "slotOpenWith",
        "updateProxyForWebEngine",
        "updateProtocolManager",
        "slotUpAboutToShow",
        "slotBackAboutToShow",
        "slotForwardAboutToShow",
        "slotClosedItemsListAboutToShow",
        "updateClosedItemsAction",
        "slotSessionsListAboutToShow",
        "saveCurrentSession",
        "manageSessions",
        "slotSessionActivated",
        "slotUpActivated",
        "slotBackActivated",
        "slotForwardActivated",
        "slotHomePopupActivated",
        "slotGoHistoryDelayed",
        "slotCompletionModeChanged",
        "KCompletion::CompletionMode",
        "slotMakeCompletion",
        "slotSubstringcompletion",
        "slotRotation",
        "KCompletionBase::KeyBindingType",
        "slotMatch",
        "slotClearHistory",
        "slotClearComboHistory",
        "slotClipboardDataChanged",
        "slotCheckComboSelection",
        "slotShowMenuBar",
        "slotShowStatusBar",
        "slotOpenURL",
        "slotIconsChanged",
        "event",
        "QEvent*",
        "slotMoveTabLeft",
        "slotMoveTabRight",
        "slotAddWebSideBar",
        "name",
        "slotUpdateFullScreen",
        "set",
        "slotUndoTextChanged",
        "newText",
        "slotIntro",
        "slotItemsRemoved",
        "goURL",
        "bookmarksIntoCompletion",
        "initBookmarkBar",
        "showPageSecurity",
        "toggleCompleteFullScreen",
        "on",
        "updateSpellCheckConfiguration",
        "inspectCurrentPage",
        "viewCount",
        "linkableViewsCount",
        "locationBarURL",
        "fullScreenMode",
        "currentTitle",
        "currentURL"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'viewAdded'
        QtMocHelpers::SignalData<void(KonqView *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'viewRemoved'
        QtMocHelpers::SignalData<void(KonqView *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'popupItemsDisturbed'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'aboutToConfigure'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'closing'
        QtMocHelpers::SignalData<void(KonqMainWindow *)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Slot 'openUrl'
        QtMocHelpers::SlotData<void(KonqView *, const QUrl &, const QString &, const KonqOpenURLRequest &, bool)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 12, 13 }, { QMetaType::QString, 14 }, { 0x80000000 | 15, 16 },
            { QMetaType::Bool, 17 },
        }}),
        // Slot 'openUrl'
        QtMocHelpers::SlotData<void(KonqView *, const QUrl &, const QString &, const KonqOpenURLRequest &)>(11, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 12, 13 }, { QMetaType::QString, 14 }, { 0x80000000 | 15, 16 },
        }}),
        // Slot 'openUrl'
        QtMocHelpers::SlotData<void(KonqView *, const QUrl &, const QString &)>(11, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 12, 13 }, { QMetaType::QString, 14 },
        }}),
        // Slot 'openUrl'
        QtMocHelpers::SlotData<void(KonqView *, const QUrl &)>(11, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 12, 13 },
        }}),
        // Slot 'updateViewModeActions'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'activateTab'
        QtMocHelpers::SlotData<void(int)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 20 },
        }}),
        // Slot 'slotInternalViewModeChanged'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCtrlTabPressed'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotPopupMenu'
        QtMocHelpers::SlotData<void(const QPoint &, const KFileItemList &, const KParts::OpenUrlArguments &, const BrowserArguments &, KParts::NavigationExtension::PopupFlags, const KParts::NavigationExtension::ActionGroupMap &, KonqView *)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 24, 25 }, { 0x80000000 | 26, 27 }, { 0x80000000 | 28, 29 }, { 0x80000000 | 30, 31 },
            { 0x80000000 | 32, 33 }, { 0x80000000 | 34, 2 }, { 0x80000000 | 3, 2 },
        }}),
        // Slot 'slotPopupMenu'
        QtMocHelpers::SlotData<void(const QPoint &, const QUrl &, mode_t, const KParts::OpenUrlArguments &, const BrowserArguments &, KParts::NavigationExtension::PopupFlags, const KParts::NavigationExtension::ActionGroupMap &, KonqView *)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 24, 25 }, { 0x80000000 | 12, 13 }, { 0x80000000 | 35, 36 }, { 0x80000000 | 28, 29 },
            { 0x80000000 | 30, 31 }, { 0x80000000 | 32, 37 }, { 0x80000000 | 34, 2 }, { 0x80000000 | 3, 2 },
        }}),
        // Slot 'slotOpenURLRequest'
        QtMocHelpers::SlotData<void(const QUrl &, KonqOpenURLRequest &)>(38, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 }, { 0x80000000 | 39, 16 },
        }}),
        // Slot 'openUrl'
        QtMocHelpers::SlotData<void(KonqView *, const QUrl &, KonqOpenURLRequest &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 40 }, { 0x80000000 | 12, 13 }, { 0x80000000 | 39, 16 },
        }}),
        // Slot 'slotCreateNewWindow'
        QtMocHelpers::SlotData<void(const QUrl &, KonqOpenURLRequest &, const WindowArgs &, KParts::ReadOnlyPart * *)>(41, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 }, { 0x80000000 | 39, 16 }, { 0x80000000 | 42, 43 }, { 0x80000000 | 44, 45 },
        }}),
        // Slot 'slotCreateNewWindow'
        QtMocHelpers::SlotData<void(const QUrl &, KonqOpenURLRequest &, const WindowArgs &)>(41, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 12, 13 }, { 0x80000000 | 39, 16 }, { 0x80000000 | 42, 43 },
        }}),
        // Slot 'slotCreateNewWindow'
        QtMocHelpers::SlotData<void(const QUrl &, KonqOpenURLRequest &)>(41, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 12, 13 }, { 0x80000000 | 39, 16 },
        }}),
        // Slot 'slotNewWindow'
        QtMocHelpers::SlotData<void()>(46, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotDuplicateWindow'
        QtMocHelpers::SlotData<void()>(47, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSendURL'
        QtMocHelpers::SlotData<void()>(48, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSendFile'
        QtMocHelpers::SlotData<void()>(49, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCopyFiles'
        QtMocHelpers::SlotData<void()>(50, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotMoveFiles'
        QtMocHelpers::SlotData<void()>(51, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotOpenLocation'
        QtMocHelpers::SlotData<void()>(52, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotOpenFile'
        QtMocHelpers::SlotData<void()>(53, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotViewModeTriggered'
        QtMocHelpers::SlotData<void(QAction *)>(54, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 55, 56 },
        }}),
        // Slot 'slotLockView'
        QtMocHelpers::SlotData<void()>(57, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotLinkView'
        QtMocHelpers::SlotData<void()>(58, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotReload'
        QtMocHelpers::SlotData<void(KonqView *)>(59, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'slotReload'
        QtMocHelpers::SlotData<void()>(59, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'slotForceReload'
        QtMocHelpers::SlotData<void()>(60, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotStop'
        QtMocHelpers::SlotData<void()>(61, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotUp'
        QtMocHelpers::SlotData<void()>(62, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotBack'
        QtMocHelpers::SlotData<void()>(63, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotForward'
        QtMocHelpers::SlotData<void()>(64, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotHome'
        QtMocHelpers::SlotData<void()>(65, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotGoHistory'
        QtMocHelpers::SlotData<void()>(66, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotAddClosedUrl'
        QtMocHelpers::SlotData<void(KonqFrameBase *)>(67, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 68, 69 },
        }}),
        // Slot 'slotConfigure'
        QtMocHelpers::SlotData<void()>(70, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotConfigure'
        QtMocHelpers::SlotData<void(Konq::ConfigDialog::Module)>(70, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 71, 72 },
        }}),
        // Slot 'slotConfigureDone'
        QtMocHelpers::SlotData<void()>(73, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotConfigureToolbars'
        QtMocHelpers::SlotData<void()>(74, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotConfigureExtensions'
        QtMocHelpers::SlotData<void()>(75, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotConfigureSpellChecking'
        QtMocHelpers::SlotData<void()>(76, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotNewToolbarConfig'
        QtMocHelpers::SlotData<void()>(77, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotUndoAvailable'
        QtMocHelpers::SlotData<void(bool)>(78, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 79 },
        }}),
        // Slot 'slotPartChanged'
        QtMocHelpers::SlotData<void(KonqView *, KParts::ReadOnlyPart *, KParts::ReadOnlyPart *)>(80, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 40 }, { 0x80000000 | 81, 82 }, { 0x80000000 | 81, 83 },
        }}),
        // Slot 'urlLoaderFinished'
        QtMocHelpers::SlotData<void(UrlLoader *)>(84, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 85, 86 },
        }}),
        // Slot 'slotClearLocationBar'
        QtMocHelpers::SlotData<void()>(87, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSetStatusBarText'
        QtMocHelpers::SlotData<void(const QString &)>(88, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 89 },
        }}),
        // Slot 'slotPartActivated'
        QtMocHelpers::SlotData<void(KParts::Part *)>(90, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 91, 45 },
        }}),
        // Slot 'slotGoHistoryActivated'
        QtMocHelpers::SlotData<void(int)>(92, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 93 },
        }}),
        // Slot 'slotAddTab'
        QtMocHelpers::SlotData<void()>(94, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSplitViewHorizontal'
        QtMocHelpers::SlotData<void()>(95, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSplitViewVertical'
        QtMocHelpers::SlotData<void()>(96, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotRemoveOtherTabs'
        QtMocHelpers::SlotData<void()>(97, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotRemoveTabPopup'
        QtMocHelpers::SlotData<void()>(98, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotReloadAllTabs'
        QtMocHelpers::SlotData<void()>(99, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotRemoveOtherTabsPopup'
        QtMocHelpers::SlotData<void()>(100, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'forceSaveMainWindowSettings'
        QtMocHelpers::SlotData<void()>(101, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotDuplicateTabPopup'
        QtMocHelpers::SlotData<void()>(102, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotReloadPopup'
        QtMocHelpers::SlotData<void()>(103, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotBreakOffTabPopup'
        QtMocHelpers::SlotData<void()>(104, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotViewCompleted'
        QtMocHelpers::SlotData<void(KonqView *)>(105, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'slotURLEntered'
        QtMocHelpers::SlotData<void(const QString &, Qt::KeyboardModifiers)>(106, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 89 }, { 0x80000000 | 107, 2 },
        }}),
        // Slot 'slotLocationLabelActivated'
        QtMocHelpers::SlotData<void()>(108, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotDuplicateTab'
        QtMocHelpers::SlotData<void()>(109, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotBreakOffTab'
        QtMocHelpers::SlotData<void()>(110, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'breakOffTab'
        QtMocHelpers::SlotData<void(int)>(111, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'slotPopupNewWindow'
        QtMocHelpers::SlotData<void()>(112, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotPopupThisWindow'
        QtMocHelpers::SlotData<void()>(113, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotPopupNewTab'
        QtMocHelpers::SlotData<void()>(114, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotPopupPasteTo'
        QtMocHelpers::SlotData<void()>(115, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotRemoveView'
        QtMocHelpers::SlotData<void()>(116, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotRemoveTab'
        QtMocHelpers::SlotData<void()>(117, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'removeTab'
        QtMocHelpers::SlotData<void(int)>(118, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 119 },
        }}),
        // Slot 'removeOtherTabs'
        QtMocHelpers::SlotData<void(int)>(120, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 119 },
        }}),
        // Slot 'slotActivateNextTab'
        QtMocHelpers::SlotData<void()>(121, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotActivatePrevTab'
        QtMocHelpers::SlotData<void()>(122, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotActivateTab'
        QtMocHelpers::SlotData<void()>(123, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotDumpDebugInfo'
        QtMocHelpers::SlotData<void()>(124, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotOpenEmbedded'
        QtMocHelpers::SlotData<void(const KPluginMetaData &)>(125, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 126, 45 },
        }}),
        // Slot 'slotReconfigure'
        QtMocHelpers::SlotData<void()>(127, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotOpenWith'
        QtMocHelpers::SlotData<void()>(128, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateProxyForWebEngine'
        QtMocHelpers::SlotData<void(bool)>(129, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 130 },
        }}),
        // Slot 'updateProxyForWebEngine'
        QtMocHelpers::SlotData<void()>(129, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Slot 'slotUpAboutToShow'
        QtMocHelpers::SlotData<void()>(131, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotBackAboutToShow'
        QtMocHelpers::SlotData<void()>(132, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotForwardAboutToShow'
        QtMocHelpers::SlotData<void()>(133, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotClosedItemsListAboutToShow'
        QtMocHelpers::SlotData<void()>(134, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateClosedItemsAction'
        QtMocHelpers::SlotData<void()>(135, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSessionsListAboutToShow'
        QtMocHelpers::SlotData<void()>(136, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'saveCurrentSession'
        QtMocHelpers::SlotData<void()>(137, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'manageSessions'
        QtMocHelpers::SlotData<void()>(138, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSessionActivated'
        QtMocHelpers::SlotData<void(QAction *)>(139, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 55, 56 },
        }}),
        // Slot 'slotUpActivated'
        QtMocHelpers::SlotData<void(QAction *)>(140, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 55, 56 },
        }}),
        // Slot 'slotBackActivated'
        QtMocHelpers::SlotData<void(QAction *)>(141, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 55, 56 },
        }}),
        // Slot 'slotForwardActivated'
        QtMocHelpers::SlotData<void(QAction *)>(142, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 55, 56 },
        }}),
        // Slot 'slotHomePopupActivated'
        QtMocHelpers::SlotData<void(QAction *)>(143, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 55, 56 },
        }}),
        // Slot 'slotGoHistoryDelayed'
        QtMocHelpers::SlotData<void()>(144, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotCompletionModeChanged'
        QtMocHelpers::SlotData<void(KCompletion::CompletionMode)>(145, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 146, 2 },
        }}),
        // Slot 'slotMakeCompletion'
        QtMocHelpers::SlotData<void(const QString &)>(147, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'slotSubstringcompletion'
        QtMocHelpers::SlotData<void(const QString &)>(148, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'slotRotation'
        QtMocHelpers::SlotData<void(KCompletionBase::KeyBindingType)>(149, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 150, 2 },
        }}),
        // Slot 'slotMatch'
        QtMocHelpers::SlotData<void(const QString &)>(151, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'slotClearHistory'
        QtMocHelpers::SlotData<void()>(152, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotClearComboHistory'
        QtMocHelpers::SlotData<void()>(153, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotClipboardDataChanged'
        QtMocHelpers::SlotData<void()>(154, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotCheckComboSelection'
        QtMocHelpers::SlotData<void()>(155, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotShowMenuBar'
        QtMocHelpers::SlotData<void()>(156, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotShowStatusBar'
        QtMocHelpers::SlotData<void()>(157, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotOpenURL'
        QtMocHelpers::SlotData<void(const QUrl &)>(158, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 12, 2 },
        }}),
        // Slot 'slotIconsChanged'
        QtMocHelpers::SlotData<void()>(159, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'event'
        QtMocHelpers::SlotData<bool(QEvent *)>(160, 2, QMC::AccessPrivate, QMetaType::Bool, {{
            { 0x80000000 | 161, 2 },
        }}),
        // Slot 'slotMoveTabLeft'
        QtMocHelpers::SlotData<void()>(162, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotMoveTabRight'
        QtMocHelpers::SlotData<void()>(163, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotAddWebSideBar'
        QtMocHelpers::SlotData<void(const QUrl &, const QString &)>(164, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 12, 13 }, { QMetaType::QString, 165 },
        }}),
        // Slot 'slotUpdateFullScreen'
        QtMocHelpers::SlotData<void(bool)>(166, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 167 },
        }}),
        // Slot 'slotUndoTextChanged'
        QtMocHelpers::SlotData<void(const QString &)>(168, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 169 },
        }}),
        // Slot 'slotIntro'
        QtMocHelpers::SlotData<void()>(170, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotItemsRemoved'
        QtMocHelpers::SlotData<void(const KFileItemList &)>(171, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 26, 2 },
        }}),
        // Slot 'goURL'
        QtMocHelpers::SlotData<void()>(172, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'bookmarksIntoCompletion'
        QtMocHelpers::SlotData<void()>(173, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'initBookmarkBar'
        QtMocHelpers::SlotData<void()>(174, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'showPageSecurity'
        QtMocHelpers::SlotData<void()>(175, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toggleCompleteFullScreen'
        QtMocHelpers::SlotData<void(bool)>(176, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 177 },
        }}),
        // Slot 'updateSpellCheckConfiguration'
        QtMocHelpers::SlotData<void()>(178, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'inspectCurrentPage'
        QtMocHelpers::SlotData<void()>(179, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'viewCount'
        QtMocHelpers::PropertyData<int>(180, QMetaType::Int, QMC::DefaultPropertyFlags),
        // property 'linkableViewsCount'
        QtMocHelpers::PropertyData<int>(181, QMetaType::Int, QMC::DefaultPropertyFlags),
        // property 'locationBarURL'
        QtMocHelpers::PropertyData<QString>(182, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'fullScreenMode'
        QtMocHelpers::PropertyData<bool>(183, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'currentTitle'
        QtMocHelpers::PropertyData<QString>(184, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'currentURL'
        QtMocHelpers::PropertyData<QString>(185, QMetaType::QString, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KonqMainWindow, qt_meta_tag_ZN14KonqMainWindowE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KonqMainWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<KParts::MainWindow::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14KonqMainWindowE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14KonqMainWindowE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14KonqMainWindowE_t>.metaTypes,
    nullptr
} };

void KonqMainWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KonqMainWindow *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->viewAdded((*reinterpret_cast<std::add_pointer_t<KonqView*>>(_a[1]))); break;
        case 1: _t->viewRemoved((*reinterpret_cast<std::add_pointer_t<KonqView*>>(_a[1]))); break;
        case 2: _t->popupItemsDisturbed(); break;
        case 3: _t->aboutToConfigure(); break;
        case 4: _t->closing((*reinterpret_cast<std::add_pointer_t<KonqMainWindow*>>(_a[1]))); break;
        case 5: _t->openUrl((*reinterpret_cast<std::add_pointer_t<KonqView*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<KonqOpenURLRequest>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5]))); break;
        case 6: _t->openUrl((*reinterpret_cast<std::add_pointer_t<KonqView*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<KonqOpenURLRequest>>(_a[4]))); break;
        case 7: _t->openUrl((*reinterpret_cast<std::add_pointer_t<KonqView*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 8: _t->openUrl((*reinterpret_cast<std::add_pointer_t<KonqView*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        case 9: _t->updateViewModeActions(); break;
        case 10: _t->activateTab((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 11: _t->slotInternalViewModeChanged(); break;
        case 12: _t->slotCtrlTabPressed(); break;
        case 13: _t->slotPopupMenu((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KFileItemList>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<KParts::OpenUrlArguments>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<BrowserArguments>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<KParts::NavigationExtension::PopupFlags>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<KParts::NavigationExtension::ActionGroupMap>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<KonqView*>>(_a[7]))); break;
        case 14: _t->slotPopupMenu((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<mode_t>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<KParts::OpenUrlArguments>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<BrowserArguments>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<KParts::NavigationExtension::PopupFlags>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<KParts::NavigationExtension::ActionGroupMap>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<KonqView*>>(_a[8]))); break;
        case 15: _t->slotOpenURLRequest((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KonqOpenURLRequest&>>(_a[2]))); break;
        case 16: _t->openUrl((*reinterpret_cast<std::add_pointer_t<KonqView*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<KonqOpenURLRequest&>>(_a[3]))); break;
        case 17: _t->slotCreateNewWindow((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KonqOpenURLRequest&>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<WindowArgs>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<KParts::ReadOnlyPart**>>(_a[4]))); break;
        case 18: _t->slotCreateNewWindow((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KonqOpenURLRequest&>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<WindowArgs>>(_a[3]))); break;
        case 19: _t->slotCreateNewWindow((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KonqOpenURLRequest&>>(_a[2]))); break;
        case 20: _t->slotNewWindow(); break;
        case 21: _t->slotDuplicateWindow(); break;
        case 22: _t->slotSendURL(); break;
        case 23: _t->slotSendFile(); break;
        case 24: _t->slotCopyFiles(); break;
        case 25: _t->slotMoveFiles(); break;
        case 26: _t->slotOpenLocation(); break;
        case 27: _t->slotOpenFile(); break;
        case 28: _t->slotViewModeTriggered((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 29: _t->slotLockView(); break;
        case 30: _t->slotLinkView(); break;
        case 31: _t->slotReload((*reinterpret_cast<std::add_pointer_t<KonqView*>>(_a[1]))); break;
        case 32: _t->slotReload(); break;
        case 33: _t->slotForceReload(); break;
        case 34: _t->slotStop(); break;
        case 35: _t->slotUp(); break;
        case 36: _t->slotBack(); break;
        case 37: _t->slotForward(); break;
        case 38: _t->slotHome(); break;
        case 39: _t->slotGoHistory(); break;
        case 40: _t->slotAddClosedUrl((*reinterpret_cast<std::add_pointer_t<KonqFrameBase*>>(_a[1]))); break;
        case 41: _t->slotConfigure(); break;
        case 42: _t->slotConfigure((*reinterpret_cast<std::add_pointer_t<Konq::ConfigDialog::Module>>(_a[1]))); break;
        case 43: _t->slotConfigureDone(); break;
        case 44: _t->slotConfigureToolbars(); break;
        case 45: _t->slotConfigureExtensions(); break;
        case 46: _t->slotConfigureSpellChecking(); break;
        case 47: _t->slotNewToolbarConfig(); break;
        case 48: _t->slotUndoAvailable((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 49: _t->slotPartChanged((*reinterpret_cast<std::add_pointer_t<KonqView*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KParts::ReadOnlyPart*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<KParts::ReadOnlyPart*>>(_a[3]))); break;
        case 50: _t->urlLoaderFinished((*reinterpret_cast<std::add_pointer_t<UrlLoader*>>(_a[1]))); break;
        case 51: _t->slotClearLocationBar(); break;
        case 52: _t->slotSetStatusBarText((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 53: _t->slotPartActivated((*reinterpret_cast<std::add_pointer_t<KParts::Part*>>(_a[1]))); break;
        case 54: _t->slotGoHistoryActivated((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 55: _t->slotAddTab(); break;
        case 56: _t->slotSplitViewHorizontal(); break;
        case 57: _t->slotSplitViewVertical(); break;
        case 58: _t->slotRemoveOtherTabs(); break;
        case 59: _t->slotRemoveTabPopup(); break;
        case 60: _t->slotReloadAllTabs(); break;
        case 61: _t->slotRemoveOtherTabsPopup(); break;
        case 62: _t->forceSaveMainWindowSettings(); break;
        case 63: _t->slotDuplicateTabPopup(); break;
        case 64: _t->slotReloadPopup(); break;
        case 65: _t->slotBreakOffTabPopup(); break;
        case 66: _t->slotViewCompleted((*reinterpret_cast<std::add_pointer_t<KonqView*>>(_a[1]))); break;
        case 67: _t->slotURLEntered((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Qt::KeyboardModifiers>>(_a[2]))); break;
        case 68: _t->slotLocationLabelActivated(); break;
        case 69: _t->slotDuplicateTab(); break;
        case 70: _t->slotBreakOffTab(); break;
        case 71: _t->breakOffTab((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 72: _t->slotPopupNewWindow(); break;
        case 73: _t->slotPopupThisWindow(); break;
        case 74: _t->slotPopupNewTab(); break;
        case 75: _t->slotPopupPasteTo(); break;
        case 76: _t->slotRemoveView(); break;
        case 77: _t->slotRemoveTab(); break;
        case 78: _t->removeTab((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 79: _t->removeOtherTabs((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 80: _t->slotActivateNextTab(); break;
        case 81: _t->slotActivatePrevTab(); break;
        case 82: _t->slotActivateTab(); break;
        case 83: _t->slotDumpDebugInfo(); break;
        case 84: _t->slotOpenEmbedded((*reinterpret_cast<std::add_pointer_t<KPluginMetaData>>(_a[1]))); break;
        case 85: _t->slotReconfigure(); break;
        case 86: _t->slotOpenWith(); break;
        case 87: _t->updateProxyForWebEngine((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 88: _t->updateProxyForWebEngine(); break;
        case 89: _t->slotUpAboutToShow(); break;
        case 90: _t->slotBackAboutToShow(); break;
        case 91: _t->slotForwardAboutToShow(); break;
        case 92: _t->slotClosedItemsListAboutToShow(); break;
        case 93: _t->updateClosedItemsAction(); break;
        case 94: _t->slotSessionsListAboutToShow(); break;
        case 95: _t->saveCurrentSession(); break;
        case 96: _t->manageSessions(); break;
        case 97: _t->slotSessionActivated((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 98: _t->slotUpActivated((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 99: _t->slotBackActivated((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 100: _t->slotForwardActivated((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 101: _t->slotHomePopupActivated((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 102: _t->slotGoHistoryDelayed(); break;
        case 103: _t->slotCompletionModeChanged((*reinterpret_cast<std::add_pointer_t<KCompletion::CompletionMode>>(_a[1]))); break;
        case 104: _t->slotMakeCompletion((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 105: _t->slotSubstringcompletion((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 106: _t->slotRotation((*reinterpret_cast<std::add_pointer_t<KCompletionBase::KeyBindingType>>(_a[1]))); break;
        case 107: _t->slotMatch((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 108: _t->slotClearHistory(); break;
        case 109: _t->slotClearComboHistory(); break;
        case 110: _t->slotClipboardDataChanged(); break;
        case 111: _t->slotCheckComboSelection(); break;
        case 112: _t->slotShowMenuBar(); break;
        case 113: _t->slotShowStatusBar(); break;
        case 114: _t->slotOpenURL((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 115: _t->slotIconsChanged(); break;
        case 116: { bool _r = _t->event((*reinterpret_cast<std::add_pointer_t<QEvent*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 117: _t->slotMoveTabLeft(); break;
        case 118: _t->slotMoveTabRight(); break;
        case 119: _t->slotAddWebSideBar((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 120: _t->slotUpdateFullScreen((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 121: _t->slotUndoTextChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 122: _t->slotIntro(); break;
        case 123: _t->slotItemsRemoved((*reinterpret_cast<std::add_pointer_t<KFileItemList>>(_a[1]))); break;
        case 124: _t->goURL(); break;
        case 125: _t->bookmarksIntoCompletion(); break;
        case 126: _t->initBookmarkBar(); break;
        case 127: _t->showPageSecurity(); break;
        case 128: _t->toggleCompleteFullScreen((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 129: _t->updateSpellCheckConfiguration(); break;
        case 130: _t->inspectCurrentPage(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KonqMainWindow* >(); break;
            }
            break;
        case 28:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 49:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KParts::ReadOnlyPart* >(); break;
            }
            break;
        case 53:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KParts::Part* >(); break;
            }
            break;
        case 97:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 98:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 99:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 100:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 101:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KonqMainWindow::*)(KonqView * )>(_a, &KonqMainWindow::viewAdded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KonqMainWindow::*)(KonqView * )>(_a, &KonqMainWindow::viewRemoved, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KonqMainWindow::*)()>(_a, &KonqMainWindow::popupItemsDisturbed, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (KonqMainWindow::*)()>(_a, &KonqMainWindow::aboutToConfigure, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (KonqMainWindow::*)(KonqMainWindow * )>(_a, &KonqMainWindow::closing, 4))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->viewCount(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->linkableViewsCount(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->locationBarURL(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->fullScreenMode(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->currentTitle(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->currentURL(); break;
        default: break;
        }
    }
}

const QMetaObject *KonqMainWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KonqMainWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14KonqMainWindowE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "KonqFrameContainerBase"))
        return static_cast< KonqFrameContainerBase*>(this);
    return KParts::MainWindow::qt_metacast(_clname);
}

int KonqMainWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KParts::MainWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 131)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 131;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 131)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 131;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void KonqMainWindow::viewAdded(KonqView * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void KonqMainWindow::viewRemoved(KonqView * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void KonqMainWindow::popupItemsDisturbed()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KonqMainWindow::aboutToConfigure()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void KonqMainWindow::closing(KonqMainWindow * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}
QT_WARNING_POP
