/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.Konqueror.MainWindow.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef KONQ_MAINWINDOW_INTERFACE_H
#define KONQ_MAINWINDOW_INTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>

/*
 * Proxy class for interface org.kde.Konqueror.MainWindow
 */
class OrgKdeKonquerorMainWindowInterface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.kde.Konqueror.MainWindow"; }

public:
    OrgKdeKonquerorMainWindowInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OrgKdeKonquerorMainWindowInterface();

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<QDBusObjectPath> currentPart()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("currentPart"), argumentList);
    }

    inline QDBusPendingReply<QDBusObjectPath> currentView()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("currentView"), argumentList);
    }

    inline QDBusPendingReply<> newTab(const QString &url, bool tempFile)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(url) << QVariant::fromValue(tempFile);
        return asyncCallWithArgumentList(QStringLiteral("newTab"), argumentList);
    }

    inline QDBusPendingReply<> newTabASN(const QString &url, const QByteArray &startup_id, bool tempFile)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(url) << QVariant::fromValue(startup_id) << QVariant::fromValue(tempFile);
        return asyncCallWithArgumentList(QStringLiteral("newTabASN"), argumentList);
    }

    inline QDBusPendingReply<> newTabASNWithMimeType(const QString &url, const QString &mimetype, const QByteArray &startup_id, bool tempFile)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(url) << QVariant::fromValue(mimetype) << QVariant::fromValue(startup_id) << QVariant::fromValue(tempFile);
        return asyncCallWithArgumentList(QStringLiteral("newTabASNWithMimeType"), argumentList);
    }

    inline QDBusPendingReply<> openUrl(const QString &url, bool tempFile)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(url) << QVariant::fromValue(tempFile);
        return asyncCallWithArgumentList(QStringLiteral("openUrl"), argumentList);
    }

    inline QDBusPendingReply<> reload()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("reload"), argumentList);
    }

Q_SIGNALS: // SIGNALS
};

namespace org {
  namespace kde {
    namespace Konqueror {
      using MainWindow = ::OrgKdeKonquerorMainWindowInterface;
    }
  }
}

#endif
