/****************************************************************************
** Meta object code from reading C++ file 'browserextension.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../konqueror-26.04.0/libkonq/src/browserextension.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'browserextension.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16BrowserExtensionE_t {};
} // unnamed namespace

template <> constexpr inline auto BrowserExtension::qt_create_metaobjectdata<qt_meta_tag_ZN16BrowserExtensionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "BrowserExtension",
        "browserOpenUrlRequest",
        "",
        "QUrl",
        "url",
        "KParts::OpenUrlArguments",
        "arguments",
        "BrowserArguments",
        "browserArguments",
        "temp",
        "browserOpenUrlRequestSync",
        "browserOpenUrlRequestDelayed",
        "browserCreateNewWindow",
        "WindowArgs",
        "windowArgs",
        "KParts::ReadOnlyPart**",
        "part",
        "browserPopupMenuFromFiles",
        "QPoint",
        "global",
        "KFileItemList",
        "items",
        "args",
        "KParts::NavigationExtension::PopupFlags",
        "flags",
        "KParts::NavigationExtension::ActionGroupMap",
        "actionGroups",
        "browserPopupMenuFromUrl",
        "mode_t",
        "mode",
        "slotCompleted",
        "slotEmitOpenUrlRequestDelayed",
        "slotOpenUrlRequest"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'browserOpenUrlRequest'
        QtMocHelpers::SignalData<void(const QUrl &, const KParts::OpenUrlArguments &, const BrowserArguments &, bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 6 }, { 0x80000000 | 7, 8 }, { QMetaType::Bool, 9 },
        }}),
        // Signal 'browserOpenUrlRequest'
        QtMocHelpers::SignalData<void(const QUrl &, const KParts::OpenUrlArguments &, const BrowserArguments &)>(1, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 6 }, { 0x80000000 | 7, 8 },
        }}),
        // Signal 'browserOpenUrlRequest'
        QtMocHelpers::SignalData<void(const QUrl &, const KParts::OpenUrlArguments &)>(1, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 6 },
        }}),
        // Signal 'browserOpenUrlRequest'
        QtMocHelpers::SignalData<void(const QUrl &)>(1, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'browserOpenUrlRequestSync'
        QtMocHelpers::SignalData<void(const QUrl &, const KParts::OpenUrlArguments &, const BrowserArguments &, bool)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 6 }, { 0x80000000 | 7, 8 }, { QMetaType::Bool, 9 },
        }}),
        // Signal 'browserOpenUrlRequestDelayed'
        QtMocHelpers::SignalData<void(const QUrl &, const KParts::OpenUrlArguments &, const BrowserArguments &, bool)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 6 }, { 0x80000000 | 7, 8 }, { QMetaType::Bool, 9 },
        }}),
        // Signal 'browserOpenUrlRequestDelayed'
        QtMocHelpers::SignalData<void(const QUrl &, const KParts::OpenUrlArguments &, const BrowserArguments &)>(11, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 6 }, { 0x80000000 | 7, 8 },
        }}),
        // Signal 'browserCreateNewWindow'
        QtMocHelpers::SignalData<void(const QUrl &, const KParts::OpenUrlArguments &, const BrowserArguments &, const WindowArgs &, KParts::ReadOnlyPart * *)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 6 }, { 0x80000000 | 7, 8 }, { 0x80000000 | 13, 14 },
            { 0x80000000 | 15, 16 },
        }}),
        // Signal 'browserCreateNewWindow'
        QtMocHelpers::SignalData<void(const QUrl &, const KParts::OpenUrlArguments &, const BrowserArguments &, const WindowArgs &)>(12, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 6 }, { 0x80000000 | 7, 8 }, { 0x80000000 | 13, 14 },
        }}),
        // Signal 'browserCreateNewWindow'
        QtMocHelpers::SignalData<void(const QUrl &, const KParts::OpenUrlArguments &, const BrowserArguments &)>(12, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 6 }, { 0x80000000 | 7, 8 },
        }}),
        // Signal 'browserCreateNewWindow'
        QtMocHelpers::SignalData<void(const QUrl &, const KParts::OpenUrlArguments &)>(12, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 6 },
        }}),
        // Signal 'browserCreateNewWindow'
        QtMocHelpers::SignalData<void(const QUrl &)>(12, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'browserPopupMenuFromFiles'
        QtMocHelpers::SignalData<void(const QPoint &, const KFileItemList &, const KParts::OpenUrlArguments &, const BrowserArguments &, KParts::NavigationExtension::PopupFlags, const KParts::NavigationExtension::ActionGroupMap &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 19 }, { 0x80000000 | 20, 21 }, { 0x80000000 | 5, 22 }, { 0x80000000 | 7, 8 },
            { 0x80000000 | 23, 24 }, { 0x80000000 | 25, 26 },
        }}),
        // Signal 'browserPopupMenuFromFiles'
        QtMocHelpers::SignalData<void(const QPoint &, const KFileItemList &, const KParts::OpenUrlArguments &, const BrowserArguments &, KParts::NavigationExtension::PopupFlags)>(17, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 18, 19 }, { 0x80000000 | 20, 21 }, { 0x80000000 | 5, 22 }, { 0x80000000 | 7, 8 },
            { 0x80000000 | 23, 24 },
        }}),
        // Signal 'browserPopupMenuFromFiles'
        QtMocHelpers::SignalData<void(const QPoint &, const KFileItemList &, const KParts::OpenUrlArguments &, const BrowserArguments &)>(17, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 18, 19 }, { 0x80000000 | 20, 21 }, { 0x80000000 | 5, 22 }, { 0x80000000 | 7, 8 },
        }}),
        // Signal 'browserPopupMenuFromFiles'
        QtMocHelpers::SignalData<void(const QPoint &, const KFileItemList &, const KParts::OpenUrlArguments &)>(17, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 18, 19 }, { 0x80000000 | 20, 21 }, { 0x80000000 | 5, 22 },
        }}),
        // Signal 'browserPopupMenuFromFiles'
        QtMocHelpers::SignalData<void(const QPoint &, const KFileItemList &)>(17, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 18, 19 }, { 0x80000000 | 20, 21 },
        }}),
        // Signal 'browserPopupMenuFromUrl'
        QtMocHelpers::SignalData<void(const QPoint &, const QUrl &, mode_t, const KParts::OpenUrlArguments &, const BrowserArguments &, KParts::NavigationExtension::PopupFlags, const KParts::NavigationExtension::ActionGroupMap &)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 19 }, { 0x80000000 | 3, 4 }, { 0x80000000 | 28, 29 }, { 0x80000000 | 5, 22 },
            { 0x80000000 | 7, 8 }, { 0x80000000 | 23, 24 }, { 0x80000000 | 25, 26 },
        }}),
        // Signal 'browserPopupMenuFromUrl'
        QtMocHelpers::SignalData<void(const QPoint &, const QUrl &, mode_t, const KParts::OpenUrlArguments &, const BrowserArguments &, KParts::NavigationExtension::PopupFlags)>(27, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 18, 19 }, { 0x80000000 | 3, 4 }, { 0x80000000 | 28, 29 }, { 0x80000000 | 5, 22 },
            { 0x80000000 | 7, 8 }, { 0x80000000 | 23, 24 },
        }}),
        // Signal 'browserPopupMenuFromUrl'
        QtMocHelpers::SignalData<void(const QPoint &, const QUrl &, mode_t, const KParts::OpenUrlArguments &, const BrowserArguments &)>(27, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 18, 19 }, { 0x80000000 | 3, 4 }, { 0x80000000 | 28, 29 }, { 0x80000000 | 5, 22 },
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'browserPopupMenuFromUrl'
        QtMocHelpers::SignalData<void(const QPoint &, const QUrl &, mode_t, const KParts::OpenUrlArguments &)>(27, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 18, 19 }, { 0x80000000 | 3, 4 }, { 0x80000000 | 28, 29 }, { 0x80000000 | 5, 22 },
        }}),
        // Signal 'browserPopupMenuFromUrl'
        QtMocHelpers::SignalData<void(const QPoint &, const QUrl &, mode_t)>(27, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 18, 19 }, { 0x80000000 | 3, 4 }, { 0x80000000 | 28, 29 },
        }}),
        // Signal 'browserPopupMenuFromUrl'
        QtMocHelpers::SignalData<void(const QPoint &, const QUrl &)>(27, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 18, 19 }, { 0x80000000 | 3, 4 },
        }}),
        // Slot 'slotCompleted'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotEmitOpenUrlRequestDelayed'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotOpenUrlRequest'
        QtMocHelpers::SlotData<void(const QUrl &, const KParts::OpenUrlArguments &, const BrowserArguments &, bool)>(32, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 6 }, { 0x80000000 | 7, 8 }, { QMetaType::Bool, 9 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<BrowserExtension, qt_meta_tag_ZN16BrowserExtensionE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject BrowserExtension::staticMetaObject = { {
    QMetaObject::SuperData::link<KParts::NavigationExtension::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16BrowserExtensionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16BrowserExtensionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16BrowserExtensionE_t>.metaTypes,
    nullptr
} };

void BrowserExtension::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<BrowserExtension *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->browserOpenUrlRequest((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KParts::OpenUrlArguments>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<BrowserArguments>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4]))); break;
        case 1: _t->browserOpenUrlRequest((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KParts::OpenUrlArguments>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<BrowserArguments>>(_a[3]))); break;
        case 2: _t->browserOpenUrlRequest((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KParts::OpenUrlArguments>>(_a[2]))); break;
        case 3: _t->browserOpenUrlRequest((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 4: _t->browserOpenUrlRequestSync((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KParts::OpenUrlArguments>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<BrowserArguments>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4]))); break;
        case 5: _t->browserOpenUrlRequestDelayed((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KParts::OpenUrlArguments>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<BrowserArguments>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4]))); break;
        case 6: _t->browserOpenUrlRequestDelayed((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KParts::OpenUrlArguments>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<BrowserArguments>>(_a[3]))); break;
        case 7: _t->browserCreateNewWindow((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KParts::OpenUrlArguments>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<BrowserArguments>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<WindowArgs>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<KParts::ReadOnlyPart**>>(_a[5]))); break;
        case 8: _t->browserCreateNewWindow((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KParts::OpenUrlArguments>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<BrowserArguments>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<WindowArgs>>(_a[4]))); break;
        case 9: _t->browserCreateNewWindow((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KParts::OpenUrlArguments>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<BrowserArguments>>(_a[3]))); break;
        case 10: _t->browserCreateNewWindow((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KParts::OpenUrlArguments>>(_a[2]))); break;
        case 11: _t->browserCreateNewWindow((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 12: _t->browserPopupMenuFromFiles((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KFileItemList>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<KParts::OpenUrlArguments>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<BrowserArguments>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<KParts::NavigationExtension::PopupFlags>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<KParts::NavigationExtension::ActionGroupMap>>(_a[6]))); break;
        case 13: _t->browserPopupMenuFromFiles((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KFileItemList>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<KParts::OpenUrlArguments>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<BrowserArguments>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<KParts::NavigationExtension::PopupFlags>>(_a[5]))); break;
        case 14: _t->browserPopupMenuFromFiles((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KFileItemList>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<KParts::OpenUrlArguments>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<BrowserArguments>>(_a[4]))); break;
        case 15: _t->browserPopupMenuFromFiles((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KFileItemList>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<KParts::OpenUrlArguments>>(_a[3]))); break;
        case 16: _t->browserPopupMenuFromFiles((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KFileItemList>>(_a[2]))); break;
        case 17: _t->browserPopupMenuFromUrl((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<mode_t>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<KParts::OpenUrlArguments>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<BrowserArguments>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<KParts::NavigationExtension::PopupFlags>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<KParts::NavigationExtension::ActionGroupMap>>(_a[7]))); break;
        case 18: _t->browserPopupMenuFromUrl((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<mode_t>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<KParts::OpenUrlArguments>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<BrowserArguments>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<KParts::NavigationExtension::PopupFlags>>(_a[6]))); break;
        case 19: _t->browserPopupMenuFromUrl((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<mode_t>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<KParts::OpenUrlArguments>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<BrowserArguments>>(_a[5]))); break;
        case 20: _t->browserPopupMenuFromUrl((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<mode_t>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<KParts::OpenUrlArguments>>(_a[4]))); break;
        case 21: _t->browserPopupMenuFromUrl((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<mode_t>>(_a[3]))); break;
        case 22: _t->browserPopupMenuFromUrl((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        case 23: _t->slotCompleted(); break;
        case 24: _t->slotEmitOpenUrlRequestDelayed(); break;
        case 25: _t->slotOpenUrlRequest((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KParts::OpenUrlArguments>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<BrowserArguments>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (BrowserExtension::*)(const QUrl & , const KParts::OpenUrlArguments & , const BrowserArguments & , bool )>(_a, &BrowserExtension::browserOpenUrlRequest, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (BrowserExtension::*)(const QUrl & , const KParts::OpenUrlArguments & , const BrowserArguments & , bool )>(_a, &BrowserExtension::browserOpenUrlRequestSync, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (BrowserExtension::*)(const QUrl & , const KParts::OpenUrlArguments & , const BrowserArguments & , bool )>(_a, &BrowserExtension::browserOpenUrlRequestDelayed, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (BrowserExtension::*)(const QUrl & , const KParts::OpenUrlArguments & , const BrowserArguments & , const WindowArgs & , KParts::ReadOnlyPart * * )>(_a, &BrowserExtension::browserCreateNewWindow, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (BrowserExtension::*)(const QPoint & , const KFileItemList & , const KParts::OpenUrlArguments & , const BrowserArguments & , KParts::NavigationExtension::PopupFlags , const KParts::NavigationExtension::ActionGroupMap & )>(_a, &BrowserExtension::browserPopupMenuFromFiles, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (BrowserExtension::*)(const QPoint & , const QUrl & , mode_t , const KParts::OpenUrlArguments & , const BrowserArguments & , KParts::NavigationExtension::PopupFlags , const KParts::NavigationExtension::ActionGroupMap & )>(_a, &BrowserExtension::browserPopupMenuFromUrl, 17))
            return;
    }
}

const QMetaObject *BrowserExtension::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BrowserExtension::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16BrowserExtensionE_t>.strings))
        return static_cast<void*>(this);
    return KParts::NavigationExtension::qt_metacast(_clname);
}

int BrowserExtension::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KParts::NavigationExtension::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 26)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 26;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 26)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 26;
    }
    return _id;
}

// SIGNAL 0
void BrowserExtension::browserOpenUrlRequest(const QUrl & _t1, const KParts::OpenUrlArguments & _t2, const BrowserArguments & _t3, bool _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 4
void BrowserExtension::browserOpenUrlRequestSync(const QUrl & _t1, const KParts::OpenUrlArguments & _t2, const BrowserArguments & _t3, bool _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 5
void BrowserExtension::browserOpenUrlRequestDelayed(const QUrl & _t1, const KParts::OpenUrlArguments & _t2, const BrowserArguments & _t3, bool _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 7
void BrowserExtension::browserCreateNewWindow(const QUrl & _t1, const KParts::OpenUrlArguments & _t2, const BrowserArguments & _t3, const WindowArgs & _t4, KParts::ReadOnlyPart * * _t5)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2, _t3, _t4, _t5);
}

// SIGNAL 12
void BrowserExtension::browserPopupMenuFromFiles(const QPoint & _t1, const KFileItemList & _t2, const KParts::OpenUrlArguments & _t3, const BrowserArguments & _t4, KParts::NavigationExtension::PopupFlags _t5, const KParts::NavigationExtension::ActionGroupMap & _t6)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1, _t2, _t3, _t4, _t5, _t6);
}

// SIGNAL 17
void BrowserExtension::browserPopupMenuFromUrl(const QPoint & _t1, const QUrl & _t2, mode_t _t3, const KParts::OpenUrlArguments & _t4, const BrowserArguments & _t5, KParts::NavigationExtension::PopupFlags _t6, const KParts::NavigationExtension::ActionGroupMap & _t7)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1, _t2, _t3, _t4, _t5, _t6, _t7);
}
QT_WARNING_POP
