/****************************************************************************
** Meta object code from reading C++ file 'konqwindow.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../konqueror-26.04.0/src/implementations/konqwindow.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'konqwindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19KonqImplementations10KonqWindowE_t {};
} // unnamed namespace

template <> constexpr inline auto KonqImplementations::KonqWindow::qt_create_metaobjectdata<qt_meta_tag_ZN19KonqImplementations10KonqWindowE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KonqImplementations::KonqWindow",
        "activateTab",
        "",
        "idx",
        "moveTab",
        "fromIdx",
        "toIdx",
        "tabsContainerChanged",
        "KonqFrameTabs*",
        "container",
        "slotTabAdded",
        "slotTabRemoved",
        "connectToView",
        "KonqView*",
        "view",
        "viewUrlChanged",
        "QUrl",
        "url",
        "viewCaptionChanged",
        "caption"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'activateTab'
        QtMocHelpers::SlotData<void(int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Slot 'moveTab'
        QtMocHelpers::SlotData<void(int, int)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 }, { QMetaType::Int, 6 },
        }}),
        // Slot 'tabsContainerChanged'
        QtMocHelpers::SlotData<void(KonqFrameTabs *)>(7, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'slotTabAdded'
        QtMocHelpers::SlotData<void(int)>(10, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Slot 'slotTabRemoved'
        QtMocHelpers::SlotData<void(int)>(11, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Slot 'connectToView'
        QtMocHelpers::SlotData<void(KonqView *)>(12, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Slot 'viewUrlChanged'
        QtMocHelpers::SlotData<void(KonqView *, const QUrl &)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 13, 14 }, { 0x80000000 | 16, 17 },
        }}),
        // Slot 'viewCaptionChanged'
        QtMocHelpers::SlotData<void(KonqView *, const QString &)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 13, 14 }, { QMetaType::QString, 19 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KonqWindow, qt_meta_tag_ZN19KonqImplementations10KonqWindowE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KonqImplementations::KonqWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<KonqInterfaces::Window::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19KonqImplementations10KonqWindowE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19KonqImplementations10KonqWindowE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19KonqImplementations10KonqWindowE_t>.metaTypes,
    nullptr
} };

void KonqImplementations::KonqWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KonqWindow *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->activateTab((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->moveTab((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 2: _t->tabsContainerChanged((*reinterpret_cast<std::add_pointer_t<KonqFrameTabs*>>(_a[1]))); break;
        case 3: _t->slotTabAdded((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->slotTabRemoved((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->connectToView((*reinterpret_cast<std::add_pointer_t<KonqView*>>(_a[1]))); break;
        case 6: _t->viewUrlChanged((*reinterpret_cast<std::add_pointer_t<KonqView*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        case 7: _t->viewCaptionChanged((*reinterpret_cast<std::add_pointer_t<KonqView*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        default: ;
        }
    }
}

const QMetaObject *KonqImplementations::KonqWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KonqImplementations::KonqWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19KonqImplementations10KonqWindowE_t>.strings))
        return static_cast<void*>(this);
    return KonqInterfaces::Window::qt_metacast(_clname);
}

int KonqImplementations::KonqWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KonqInterfaces::Window::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    return _id;
}
QT_WARNING_POP
