/****************************************************************************
** Meta object code from reading C++ file 'KonqViewAdaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../konqueror-26.04.0/src/KonqViewAdaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'KonqViewAdaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15KonqViewAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto KonqViewAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN15KonqViewAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KonqViewAdaptor",
        "D-Bus Interface",
        "org.kde.Konqueror.View",
        "openUrl",
        "",
        "url",
        "locationBarURL",
        "nameFilter",
        "reload",
        "changeViewMode",
        "mimeType",
        "serviceName",
        "lockHistory",
        "stop",
        "type",
        "serviceTypes",
        "part",
        "QDBusObjectPath",
        "enablePopupMenu",
        "b",
        "isPopupMenuEnabled",
        "historyLength",
        "goForward",
        "goBack",
        "canGoBack",
        "canGoForward"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'openUrl'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QString &)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::QString, 6 }, { QMetaType::QString, 7 },
        }}),
        // Slot 'reload'
        QtMocHelpers::SlotData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'changeViewMode'
        QtMocHelpers::SlotData<bool(const QString &, const QString &)>(9, 4, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 10 }, { QMetaType::QString, 11 },
        }}),
        // Slot 'lockHistory'
        QtMocHelpers::SlotData<void()>(12, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'stop'
        QtMocHelpers::SlotData<void()>(13, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'url'
        QtMocHelpers::SlotData<QString()>(5, 4, QMC::AccessPublic, QMetaType::QString),
        // Slot 'locationBarURL'
        QtMocHelpers::SlotData<QString()>(6, 4, QMC::AccessPublic, QMetaType::QString),
        // Slot 'type'
        QtMocHelpers::SlotData<QString()>(14, 4, QMC::AccessPublic, QMetaType::QString),
        // Slot 'serviceTypes'
        QtMocHelpers::SlotData<QStringList()>(15, 4, QMC::AccessPublic, QMetaType::QStringList),
        // Slot 'part'
        QtMocHelpers::SlotData<QDBusObjectPath()>(16, 4, QMC::AccessPublic, 0x80000000 | 17),
        // Slot 'enablePopupMenu'
        QtMocHelpers::SlotData<void(bool)>(18, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 19 },
        }}),
        // Slot 'isPopupMenuEnabled'
        QtMocHelpers::SlotData<bool() const>(20, 4, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'historyLength'
        QtMocHelpers::SlotData<uint() const>(21, 4, QMC::AccessPublic, QMetaType::UInt),
        // Slot 'goForward'
        QtMocHelpers::SlotData<void()>(22, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'goBack'
        QtMocHelpers::SlotData<void()>(23, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'canGoBack'
        QtMocHelpers::SlotData<bool() const>(24, 4, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'canGoForward'
        QtMocHelpers::SlotData<bool() const>(25, 4, QMC::AccessPublic, QMetaType::Bool),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<KonqViewAdaptor, qt_meta_tag_ZN15KonqViewAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject KonqViewAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15KonqViewAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15KonqViewAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15KonqViewAdaptorE_t>.metaTypes,
    nullptr
} };

void KonqViewAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KonqViewAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->openUrl((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 1: _t->reload(); break;
        case 2: { bool _r = _t->changeViewMode((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 3: _t->lockHistory(); break;
        case 4: _t->stop(); break;
        case 5: { QString _r = _t->url();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 6: { QString _r = _t->locationBarURL();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 7: { QString _r = _t->type();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 8: { QStringList _r = _t->serviceTypes();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 9: { QDBusObjectPath _r = _t->part();
            if (_a[0]) *reinterpret_cast<QDBusObjectPath*>(_a[0]) = std::move(_r); }  break;
        case 10: _t->enablePopupMenu((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: { bool _r = _t->isPopupMenuEnabled();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 12: { uint _r = _t->historyLength();
            if (_a[0]) *reinterpret_cast<uint*>(_a[0]) = std::move(_r); }  break;
        case 13: _t->goForward(); break;
        case 14: _t->goBack(); break;
        case 15: { bool _r = _t->canGoBack();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 16: { bool _r = _t->canGoForward();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject *KonqViewAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KonqViewAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15KonqViewAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KonqViewAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 17;
    }
    return _id;
}
QT_WARNING_POP
