/********************************************************************************
** Form generated from reading UI file 'cssconfig.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CSSCONFIG_H
#define UI_CSSCONFIG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcolorbutton.h"
#include "klineedit.h"
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_CSSConfigWidget
{
public:
    QVBoxLayout *vboxLayout;
    QGroupBox *ButtonGroup1;
    QVBoxLayout *vboxLayout1;
    QRadioButton *useDefault;
    QRadioButton *useUser;
    QHBoxLayout *hboxLayout;
    QSpacerItem *spacerItem;
    KUrlRequester *urlRequester;
    QRadioButton *useAccess;
    QHBoxLayout *hboxLayout1;
    QSpacerItem *spacerItem1;
    QPushButton *customize;
    QSpacerItem *spacerItem2;
    QGroupBox *customPageBackgroundBox;
    QVBoxLayout *verticalLayout;
    QCheckBox *useCustomBackgroundColor;
    KColorButton *customBackgroundColor;
    QCheckBox *addCustomBackgroundToStyleSheet;
    QSpacerItem *spacerItem3;

    void setupUi(QWidget *CSSConfigWidget)
    {
        if (CSSConfigWidget->objectName().isEmpty())
            CSSConfigWidget->setObjectName("CSSConfigWidget");
        CSSConfigWidget->resize(467, 355);
        vboxLayout = new QVBoxLayout(CSSConfigWidget);
        vboxLayout->setObjectName("vboxLayout");
        ButtonGroup1 = new QGroupBox(CSSConfigWidget);
        ButtonGroup1->setObjectName("ButtonGroup1");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(ButtonGroup1->sizePolicy().hasHeightForWidth());
        ButtonGroup1->setSizePolicy(sizePolicy);
        vboxLayout1 = new QVBoxLayout(ButtonGroup1);
        vboxLayout1->setObjectName("vboxLayout1");
        useDefault = new QRadioButton(ButtonGroup1);
        useDefault->setObjectName("useDefault");
        useDefault->setChecked(true);

        vboxLayout1->addWidget(useDefault);

        useUser = new QRadioButton(ButtonGroup1);
        useUser->setObjectName("useUser");

        vboxLayout1->addWidget(useUser);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        spacerItem = new QSpacerItem(14, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(spacerItem);

        urlRequester = new KUrlRequester(ButtonGroup1);
        urlRequester->setObjectName("urlRequester");
        urlRequester->setEnabled(false);

        hboxLayout->addWidget(urlRequester);


        vboxLayout1->addLayout(hboxLayout);

        useAccess = new QRadioButton(ButtonGroup1);
        useAccess->setObjectName("useAccess");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(useAccess->sizePolicy().hasHeightForWidth());
        useAccess->setSizePolicy(sizePolicy1);

        vboxLayout1->addWidget(useAccess);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setObjectName("hboxLayout1");
        hboxLayout1->setContentsMargins(0, 0, 0, 0);
        spacerItem1 = new QSpacerItem(14, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        hboxLayout1->addItem(spacerItem1);

        customize = new QPushButton(ButtonGroup1);
        customize->setObjectName("customize");
        customize->setEnabled(false);

        hboxLayout1->addWidget(customize);

        spacerItem2 = new QSpacerItem(20, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout1->addItem(spacerItem2);


        vboxLayout1->addLayout(hboxLayout1);


        vboxLayout->addWidget(ButtonGroup1);

        customPageBackgroundBox = new QGroupBox(CSSConfigWidget);
        customPageBackgroundBox->setObjectName("customPageBackgroundBox");
        customPageBackgroundBox->setEnabled(true);
        verticalLayout = new QVBoxLayout(customPageBackgroundBox);
        verticalLayout->setObjectName("verticalLayout");
        useCustomBackgroundColor = new QCheckBox(customPageBackgroundBox);
        useCustomBackgroundColor->setObjectName("useCustomBackgroundColor");

        verticalLayout->addWidget(useCustomBackgroundColor);

        customBackgroundColor = new KColorButton(customPageBackgroundBox);
        customBackgroundColor->setObjectName("customBackgroundColor");
        customBackgroundColor->setEnabled(false);

        verticalLayout->addWidget(customBackgroundColor);

        addCustomBackgroundToStyleSheet = new QCheckBox(customPageBackgroundBox);
        addCustomBackgroundToStyleSheet->setObjectName("addCustomBackgroundToStyleSheet");
        addCustomBackgroundToStyleSheet->setEnabled(false);

        verticalLayout->addWidget(addCustomBackgroundToStyleSheet);


        vboxLayout->addWidget(customPageBackgroundBox);

        spacerItem3 = new QSpacerItem(20, 50, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(spacerItem3);


        retranslateUi(CSSConfigWidget);
        QObject::connect(useAccess, &QRadioButton::toggled, customize, &QPushButton::setEnabled);
        QObject::connect(useUser, SIGNAL(toggled(bool)), urlRequester, SLOT(setEnabled(bool)));

        QMetaObject::connectSlotsByName(CSSConfigWidget);
    } // setupUi

    void retranslateUi(QWidget *CSSConfigWidget)
    {
#if QT_CONFIG(whatsthis)
        CSSConfigWidget->setWhatsThis(tr2i18n("<b>Stylesheets</b><p>See http://www.w3.org/Style/CSS for further information on cascading style sheets.</p>", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(whatsthis)
        ButtonGroup1->setWhatsThis(tr2i18n("<b>Stylesheets</b><p>Use this groupbox to determine how Konqueror will render style sheets.</p>", nullptr));
#endif // QT_CONFIG(whatsthis)
        ButtonGroup1->setTitle(tr2i18n("Stylesheets", nullptr));
#if QT_CONFIG(whatsthis)
        useDefault->setWhatsThis(tr2i18n("<b>Use default stylesheet</b><p>Select this option to use the default stylesheet.</p>", nullptr));
#endif // QT_CONFIG(whatsthis)
        useDefault->setText(tr2i18n("Us&e default stylesheet", nullptr));
#if QT_CONFIG(whatsthis)
        useUser->setWhatsThis(tr2i18n("<b>Use user-defined stylesheet</b><p>If this box is checked, Konqueror will try to load a user-defined style sheet as specified in the location below. The style sheet allows you to completely override the way web pages are rendered in your browser. The file specified should contain a valid style sheet (see http://www.w3.org/Style/CSS for further information on cascading style sheets).</p>", nullptr));
#endif // QT_CONFIG(whatsthis)
        useUser->setText(tr2i18n("Use &user-defined stylesheet", nullptr));
#if QT_CONFIG(whatsthis)
        useAccess->setWhatsThis(tr2i18n("<b>Use accessibility stylesheet</b><p>Selecting this option will allow you to define a default font, font size, and font color with a few simple clicks of the mouse. Simply wander over to the Customize... dialog and pick out your desired options.</p>", nullptr));
#endif // QT_CONFIG(whatsthis)
        useAccess->setText(tr2i18n("U&se accessibility stylesheet", nullptr));
        customize->setText(tr2i18n("Custom&ize...", nullptr));
        customPageBackgroundBox->setTitle(tr2i18n("Custom Page Background", nullptr));
#if QT_CONFIG(tooltip)
        useCustomBackgroundColor->setToolTip(tr2i18n("<html><head/><body><p align=\"justify\">Use a custom background color for web pages. This color is used:</p><ul style=\"margin-top: 0px; margin-bottom: 0px; margin-left: 0px; margin-right: 0px; -qt-list-indent: 1;\"><li align=\"justify\" style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">when the background color isn't explicitly set by the page or by a custom stylesheet</li><li align=\"justify\" style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">before a web page is loaded</li></ul><p align=\"justify\">Setting a custom background color is mostly useful if you use a custom stylesheet which sets a background color for the page (especially a dark color), to avoid a white flash before the page is loaded</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        useCustomBackgroundColor->setText(tr2i18n("Use custom &background color", nullptr));
#if QT_CONFIG(tooltip)
        customBackgroundColor->setToolTip(tr2i18n("<html><head/><body><p>The custom background color to use for web pages</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        addCustomBackgroundToStyleSheet->setToolTip(tr2i18n("<html><head/><body><p align=\"justify\">Add to your custom stylesheet (including the accessibility stylesheet) a rule to set all background colors to the custom color you chose above. This avoids the need of setting the background color both in the stylesheet and in the configuration dialog.</p><p align=\"justify\"><span style=\" font-weight:600;\">Notes:</span></p><ul style=\"margin-top: 0px; margin-bottom: 0px; margin-left: 0px; margin-right: 0px; -qt-list-indent: 1;\"><li align=\"justify\" style=\" margin-top:12px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">the rule will be overridden by other rules for background colors in your custom stylesheet following the usual CSS rules</li><li align=\"justify\" style=\" margin-top:0px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">the rule isn't actually added to the file containing your custom stylesheet; it's only inserted in the copy Konqueror keeps in memory. This me"
                        "ans that if you use the stylesheet in other browsers, you'll need to manually add the rule to it.</li></ul></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        addCustomBackgroundToStyleSheet->setText(tr2i18n("Add custom background color to stylesheet", nullptr));
    } // retranslateUi

};

namespace Ui {
    class CSSConfigWidget: public Ui_CSSConfigWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CSSCONFIG_H

