/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kget.main.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef KGET_INTERFACE_H
#define KGET_INTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>

/*
 * Proxy class for interface org.kde.kget.main
 */
class OrgKdeKgetMainInterface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.kde.kget.main"; }

public:
    OrgKdeKgetMainInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OrgKdeKgetMainInterface();

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<QStringList> addTransfer(const QString &src, const QString &destDir, bool start)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(src) << QVariant::fromValue(destDir) << QVariant::fromValue(start);
        return asyncCallWithArgumentList(QStringLiteral("addTransfer"), argumentList);
    }

    inline QDBusPendingReply<bool> delTransfer(const QString &dbusObjectPath)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(dbusObjectPath);
        return asyncCallWithArgumentList(QStringLiteral("delTransfer"), argumentList);
    }

    inline QDBusPendingReply<bool> dropTargetVisible()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("dropTargetVisible"), argumentList);
    }

    inline QDBusPendingReply<> importLinks(const QStringList &links)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(links);
        return asyncCallWithArgumentList(QStringLiteral("importLinks"), argumentList);
    }

    inline QDBusPendingReply<bool> isSupported(const QString &url)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(url);
        return asyncCallWithArgumentList(QStringLiteral("isSupported"), argumentList);
    }

    inline QDBusPendingReply<bool> offlineMode()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("offlineMode"), argumentList);
    }

    inline QDBusPendingReply<> setDropTargetVisible(bool visible)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(visible);
        return asyncCallWithArgumentList(QStringLiteral("setDropTargetVisible"), argumentList);
    }

    inline QDBusPendingReply<> setOfflineMode(bool in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("setOfflineMode"), argumentList);
    }

    inline QDBusPendingReply<> showNewTransferDialog(const QStringList &urls)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(urls);
        return asyncCallWithArgumentList(QStringLiteral("showNewTransferDialog"), argumentList);
    }

    inline QDBusPendingReply<QVariantMap> transfers()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("transfers"), argumentList);
    }

    inline QDBusPendingReply<int> transfersSpeed()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("transfersSpeed"), argumentList);
    }

Q_SIGNALS: // SIGNALS
    void transfersAdded(const QStringList &urls, const QStringList &dBusObjectPaths);
    void transfersRemoved(const QStringList &urls, const QStringList &dBusObjectPaths);
};

namespace org {
  namespace kde {
    namespace kget {
      using main = ::OrgKdeKgetMainInterface;
    }
  }
}

#endif
