/****************************************************************************
** Meta object code from reading C++ file 'treemap.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../konqueror-26.04.0/plugins/fsview/treemap.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'treemap.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13TreeMapWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto TreeMapWidget::qt_create_metaobjectdata<qt_meta_tag_ZN13TreeMapWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TreeMapWidget",
        "selectionChanged",
        "",
        "TreeMapItem*",
        "currentChanged",
        "keyboard",
        "clicked",
        "returnPressed",
        "doubleClicked",
        "rightButtonPressed",
        "QPoint",
        "contextMenuRequested",
        "splitActivated",
        "QAction*",
        "selectionActivated",
        "fieldStopActivated",
        "areaStopActivated",
        "depthStopActivated",
        "visualizationActivated",
        "a"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'selectionChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'selectionChanged'
        QtMocHelpers::SignalData<void(TreeMapItem *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'currentChanged'
        QtMocHelpers::SignalData<void(TreeMapItem *, bool)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { QMetaType::Bool, 5 },
        }}),
        // Signal 'clicked'
        QtMocHelpers::SignalData<void(TreeMapItem *)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'returnPressed'
        QtMocHelpers::SignalData<void(TreeMapItem *)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'doubleClicked'
        QtMocHelpers::SignalData<void(TreeMapItem *)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'rightButtonPressed'
        QtMocHelpers::SignalData<void(TreeMapItem *, const QPoint &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { 0x80000000 | 10, 2 },
        }}),
        // Signal 'contextMenuRequested'
        QtMocHelpers::SignalData<void(TreeMapItem *, const QPoint &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { 0x80000000 | 10, 2 },
        }}),
        // Slot 'splitActivated'
        QtMocHelpers::SlotData<void(QAction *)>(12, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 13, 2 },
        }}),
        // Slot 'selectionActivated'
        QtMocHelpers::SlotData<void(QAction *)>(14, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 13, 2 },
        }}),
        // Slot 'fieldStopActivated'
        QtMocHelpers::SlotData<void(QAction *)>(15, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 13, 2 },
        }}),
        // Slot 'areaStopActivated'
        QtMocHelpers::SlotData<void(QAction *)>(16, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 13, 2 },
        }}),
        // Slot 'depthStopActivated'
        QtMocHelpers::SlotData<void(QAction *)>(17, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 13, 2 },
        }}),
        // Slot 'visualizationActivated'
        QtMocHelpers::SlotData<void(QAction *)>(18, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 13, 19 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TreeMapWidget, qt_meta_tag_ZN13TreeMapWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject TreeMapWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13TreeMapWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13TreeMapWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13TreeMapWidgetE_t>.metaTypes,
    nullptr
} };

void TreeMapWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TreeMapWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->selectionChanged(); break;
        case 1: _t->selectionChanged((*reinterpret_cast<std::add_pointer_t<TreeMapItem*>>(_a[1]))); break;
        case 2: _t->currentChanged((*reinterpret_cast<std::add_pointer_t<TreeMapItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 3: _t->clicked((*reinterpret_cast<std::add_pointer_t<TreeMapItem*>>(_a[1]))); break;
        case 4: _t->returnPressed((*reinterpret_cast<std::add_pointer_t<TreeMapItem*>>(_a[1]))); break;
        case 5: _t->doubleClicked((*reinterpret_cast<std::add_pointer_t<TreeMapItem*>>(_a[1]))); break;
        case 6: _t->rightButtonPressed((*reinterpret_cast<std::add_pointer_t<TreeMapItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[2]))); break;
        case 7: _t->contextMenuRequested((*reinterpret_cast<std::add_pointer_t<TreeMapItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[2]))); break;
        case 8: _t->splitActivated((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 9: _t->selectionActivated((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 10: _t->fieldStopActivated((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 11: _t->areaStopActivated((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 12: _t->depthStopActivated((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 13: _t->visualizationActivated((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TreeMapWidget::*)()>(_a, &TreeMapWidget::selectionChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TreeMapWidget::*)(TreeMapItem * )>(_a, &TreeMapWidget::selectionChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (TreeMapWidget::*)(TreeMapItem * , bool )>(_a, &TreeMapWidget::currentChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (TreeMapWidget::*)(TreeMapItem * )>(_a, &TreeMapWidget::clicked, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (TreeMapWidget::*)(TreeMapItem * )>(_a, &TreeMapWidget::returnPressed, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (TreeMapWidget::*)(TreeMapItem * )>(_a, &TreeMapWidget::doubleClicked, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (TreeMapWidget::*)(TreeMapItem * , const QPoint & )>(_a, &TreeMapWidget::rightButtonPressed, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (TreeMapWidget::*)(TreeMapItem * , const QPoint & )>(_a, &TreeMapWidget::contextMenuRequested, 7))
            return;
    }
}

const QMetaObject *TreeMapWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TreeMapWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13TreeMapWidgetE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int TreeMapWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    return _id;
}

// SIGNAL 0
void TreeMapWidget::selectionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void TreeMapWidget::selectionChanged(TreeMapItem * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void TreeMapWidget::currentChanged(TreeMapItem * _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void TreeMapWidget::clicked(TreeMapItem * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void TreeMapWidget::returnPressed(TreeMapItem * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void TreeMapWidget::doubleClicked(TreeMapItem * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void TreeMapWidget::rightButtonPressed(TreeMapItem * _t1, const QPoint & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
}

// SIGNAL 7
void TreeMapWidget::contextMenuRequested(TreeMapItem * _t1, const QPoint & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2);
}
QT_WARNING_POP
