/********************************************************************************
** Form generated from reading UI file 'history_dlg.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_HISTORY_DLG_H
#define UI_HISTORY_DLG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_KonqSidebarHistoryDlg
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *gbDefaultAction;
    QFormLayout *formLayout;
    QLabel *lDefault;
    QComboBox *comboDefaultAction;
    QGroupBox *gbLimits;
    QGridLayout *gridLayout;
    QSpinBox *spinEntries;
    QSpacerItem *Spacer1;
    QCheckBox *cbExpire;
    QSpinBox *spinExpire;
    QLabel *lEntries;
    QGroupBox *gbFonts;
    QGridLayout *gridLayout1;
    QSpinBox *spinNewer;
    QSpinBox *spinOlder;
    QComboBox *comboOlder;
    QLabel *lbNewer;
    QComboBox *comboNewer;
    QPushButton *btnFontOlder;
    QLabel *lbOlder;
    QPushButton *btnFontNewer;
    QGroupBox *gbDetails;
    QHBoxLayout *hboxLayout;
    QCheckBox *cbDetailedTips;
    QHBoxLayout *hboxLayout1;
    QPushButton *btnClearHistory;
    QSpacerItem *Spacer3;
    QSpacerItem *Spacer2;

    void setupUi(QWidget *KonqSidebarHistoryDlg)
    {
        if (KonqSidebarHistoryDlg->objectName().isEmpty())
            KonqSidebarHistoryDlg->setObjectName("KonqSidebarHistoryDlg");
        KonqSidebarHistoryDlg->resize(450, 444);
        verticalLayout = new QVBoxLayout(KonqSidebarHistoryDlg);
        verticalLayout->setObjectName("verticalLayout");
        gbDefaultAction = new QGroupBox(KonqSidebarHistoryDlg);
        gbDefaultAction->setObjectName("gbDefaultAction");
        formLayout = new QFormLayout(gbDefaultAction);
        formLayout->setObjectName("formLayout");
        lDefault = new QLabel(gbDefaultAction);
        lDefault->setObjectName("lDefault");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, lDefault);

        comboDefaultAction = new QComboBox(gbDefaultAction);
        comboDefaultAction->setObjectName("comboDefaultAction");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, comboDefaultAction);


        verticalLayout->addWidget(gbDefaultAction);

        gbLimits = new QGroupBox(KonqSidebarHistoryDlg);
        gbLimits->setObjectName("gbLimits");
        gridLayout = new QGridLayout(gbLimits);
        gridLayout->setObjectName("gridLayout");
        spinEntries = new QSpinBox(gbLimits);
        spinEntries->setObjectName("spinEntries");

        gridLayout->addWidget(spinEntries, 0, 1, 1, 1);

        Spacer1 = new QSpacerItem(240, 16, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(Spacer1, 1, 2, 1, 1);

        cbExpire = new QCheckBox(gbLimits);
        cbExpire->setObjectName("cbExpire");

        gridLayout->addWidget(cbExpire, 1, 0, 1, 1);

        spinExpire = new QSpinBox(gbLimits);
        spinExpire->setObjectName("spinExpire");

        gridLayout->addWidget(spinExpire, 1, 1, 1, 1);

        lEntries = new QLabel(gbLimits);
        lEntries->setObjectName("lEntries");
        lEntries->setWordWrap(false);

        gridLayout->addWidget(lEntries, 0, 0, 1, 1);


        verticalLayout->addWidget(gbLimits);

        gbFonts = new QGroupBox(KonqSidebarHistoryDlg);
        gbFonts->setObjectName("gbFonts");
        gridLayout1 = new QGridLayout(gbFonts);
        gridLayout1->setObjectName("gridLayout1");
        spinNewer = new QSpinBox(gbFonts);
        spinNewer->setObjectName("spinNewer");

        gridLayout1->addWidget(spinNewer, 0, 1, 1, 1);

        spinOlder = new QSpinBox(gbFonts);
        spinOlder->setObjectName("spinOlder");

        gridLayout1->addWidget(spinOlder, 1, 1, 1, 1);

        comboOlder = new QComboBox(gbFonts);
        comboOlder->setObjectName("comboOlder");

        gridLayout1->addWidget(comboOlder, 1, 2, 1, 1);

        lbNewer = new QLabel(gbFonts);
        lbNewer->setObjectName("lbNewer");
        lbNewer->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        lbNewer->setWordWrap(false);

        gridLayout1->addWidget(lbNewer, 0, 0, 1, 1);

        comboNewer = new QComboBox(gbFonts);
        comboNewer->setObjectName("comboNewer");

        gridLayout1->addWidget(comboNewer, 0, 2, 1, 1);

        btnFontOlder = new QPushButton(gbFonts);
        btnFontOlder->setObjectName("btnFontOlder");

        gridLayout1->addWidget(btnFontOlder, 1, 3, 1, 1);

        lbOlder = new QLabel(gbFonts);
        lbOlder->setObjectName("lbOlder");
        lbOlder->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        lbOlder->setWordWrap(false);

        gridLayout1->addWidget(lbOlder, 1, 0, 1, 1);

        btnFontNewer = new QPushButton(gbFonts);
        btnFontNewer->setObjectName("btnFontNewer");

        gridLayout1->addWidget(btnFontNewer, 0, 3, 1, 1);


        verticalLayout->addWidget(gbFonts);

        gbDetails = new QGroupBox(KonqSidebarHistoryDlg);
        gbDetails->setObjectName("gbDetails");
        hboxLayout = new QHBoxLayout(gbDetails);
        hboxLayout->setObjectName("hboxLayout");
        cbDetailedTips = new QCheckBox(gbDetails);
        cbDetailedTips->setObjectName("cbDetailedTips");

        hboxLayout->addWidget(cbDetailedTips);


        verticalLayout->addWidget(gbDetails);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setObjectName("hboxLayout1");
        btnClearHistory = new QPushButton(KonqSidebarHistoryDlg);
        btnClearHistory->setObjectName("btnClearHistory");

        hboxLayout1->addWidget(btnClearHistory);

        Spacer3 = new QSpacerItem(418, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout1->addItem(Spacer3);


        verticalLayout->addLayout(hboxLayout1);

        Spacer2 = new QSpacerItem(16, 30, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(Spacer2);

#if QT_CONFIG(shortcut)
        lEntries->setBuddy(spinEntries);
#endif // QT_CONFIG(shortcut)

        retranslateUi(KonqSidebarHistoryDlg);

        QMetaObject::connectSlotsByName(KonqSidebarHistoryDlg);
    } // setupUi

    void retranslateUi(QWidget *KonqSidebarHistoryDlg)
    {
        gbDefaultAction->setTitle(tr2i18n("Default action", nullptr));
        lDefault->setText(tr2i18n("Default action when double clicking an URL", nullptr));
        gbLimits->setTitle(tr2i18n("Limits", nullptr));
        cbExpire->setText(tr2i18n("URLs e&xpire after", nullptr));
        lEntries->setText(tr2i18n("Maximum &number of URLs:", nullptr));
        gbFonts->setTitle(tr2i18n("Custom Fonts For", nullptr));
        lbNewer->setText(tr2i18n("URLs newer than", nullptr));
        btnFontOlder->setText(tr2i18n("Choose Font...", nullptr));
        lbOlder->setText(tr2i18n("URLs older than", nullptr));
        btnFontNewer->setText(tr2i18n("Choose Font...", nullptr));
        gbDetails->setTitle(tr2i18n("Details", nullptr));
#if QT_CONFIG(tooltip)
        cbDetailedTips->setToolTip(tr2i18n("Shows the number of times visited and the dates of the first and last visits, in addition to the URL", nullptr));
#endif // QT_CONFIG(tooltip)
        cbDetailedTips->setText(tr2i18n("Detailed tooltips", nullptr));
        btnClearHistory->setText(tr2i18n("Clear History", nullptr));
        (void)KonqSidebarHistoryDlg;
    } // retranslateUi

};

namespace Ui {
    class KonqSidebarHistoryDlg: public Ui_KonqSidebarHistoryDlg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // HISTORY_DLG_H

