/****************************************************************************
** Meta object code from reading C++ file 'passwordbar.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../konqueror-26.04.0/webenginepart/src/ui/passwordbar.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'passwordbar.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11PasswordBarE_t {};
} // unnamed namespace

template <> constexpr inline auto PasswordBar::qt_create_metaobjectdata<qt_meta_tag_ZN11PasswordBarE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PasswordBar",
        "saveFormDataRejected",
        "",
        "key",
        "saveFormDataAccepted",
        "done",
        "toggleDetailsRequested",
        "QUrl",
        "url",
        "visible",
        "moved",
        "onNotNowButtonClicked",
        "onNeverButtonClicked",
        "onRememberButtonClicked",
        "onDetailsButtonClicked"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'saveFormDataRejected'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'saveFormDataAccepted'
        QtMocHelpers::SignalData<void(const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'done'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'toggleDetailsRequested'
        QtMocHelpers::SignalData<void(const QUrl &, bool)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { QMetaType::Bool, 9 },
        }}),
        // Signal 'moved'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onNotNowButtonClicked'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onNeverButtonClicked'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onRememberButtonClicked'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onDetailsButtonClicked'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PasswordBar, qt_meta_tag_ZN11PasswordBarE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PasswordBar::staticMetaObject = { {
    QMetaObject::SuperData::link<KMessageWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11PasswordBarE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11PasswordBarE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11PasswordBarE_t>.metaTypes,
    nullptr
} };

void PasswordBar::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PasswordBar *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->saveFormDataRejected((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->saveFormDataAccepted((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->done(); break;
        case 3: _t->toggleDetailsRequested((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 4: _t->moved(); break;
        case 5: _t->onNotNowButtonClicked(); break;
        case 6: _t->onNeverButtonClicked(); break;
        case 7: _t->onRememberButtonClicked(); break;
        case 8: _t->onDetailsButtonClicked(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PasswordBar::*)(const QString & )>(_a, &PasswordBar::saveFormDataRejected, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PasswordBar::*)(const QString & )>(_a, &PasswordBar::saveFormDataAccepted, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PasswordBar::*)()>(_a, &PasswordBar::done, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (PasswordBar::*)(const QUrl & , bool )>(_a, &PasswordBar::toggleDetailsRequested, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (PasswordBar::*)()>(_a, &PasswordBar::moved, 4))
            return;
    }
}

const QMetaObject *PasswordBar::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PasswordBar::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11PasswordBarE_t>.strings))
        return static_cast<void*>(this);
    return KMessageWidget::qt_metacast(_clname);
}

int PasswordBar::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KMessageWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void PasswordBar::saveFormDataRejected(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void PasswordBar::saveFormDataAccepted(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void PasswordBar::done()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void PasswordBar::toggleDetailsRequested(const QUrl & _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void PasswordBar::moved()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
