/********************************************************************************
** Form generated from reading UI file 'system_ui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SYSTEM_UI_H
#define UI_SYSTEM_UI_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_System_ui
{
public:
    QVBoxLayout *vboxLayout;
    QGroupBox *gb_;
    QVBoxLayout *vboxLayout1;
    QCheckBox *cb_disable_kbuildsycoca;
    QLabel *label_kbuildsycoca;
    QSpacerItem *spacerItem;

    void setupUi(QWidget *System_ui)
    {
        if (System_ui->objectName().isEmpty())
            System_ui->setObjectName("System_ui");
        vboxLayout = new QVBoxLayout(System_ui);
        vboxLayout->setObjectName("vboxLayout");
        gb_ = new QGroupBox(System_ui);
        gb_->setObjectName("gb_");
        vboxLayout1 = new QVBoxLayout(gb_);
        vboxLayout1->setObjectName("vboxLayout1");
        cb_disable_kbuildsycoca = new QCheckBox(gb_);
        cb_disable_kbuildsycoca->setObjectName("cb_disable_kbuildsycoca");

        vboxLayout1->addWidget(cb_disable_kbuildsycoca);

        label_kbuildsycoca = new QLabel(gb_);
        label_kbuildsycoca->setObjectName("label_kbuildsycoca");
        label_kbuildsycoca->setWordWrap(true);

        vboxLayout1->addWidget(label_kbuildsycoca);


        vboxLayout->addWidget(gb_);

        spacerItem = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(spacerItem);


        retranslateUi(System_ui);

        QMetaObject::connectSlotsByName(System_ui);
    } // setupUi

    void retranslateUi(QWidget *System_ui)
    {
        gb_->setTitle(tr2i18n("System Configuration", nullptr));
        cb_disable_kbuildsycoca->setText(tr2i18n("Disable &system configuration startup check", nullptr));
        label_kbuildsycoca->setText(tr2i18n("This option may in rare cases lead to various problems. Consult the What's This (Shift+F1) help for details.", nullptr));
        (void)System_ui;
    } // retranslateUi

};

namespace Ui {
    class System_ui: public Ui_System_ui {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SYSTEM_UI_H

