/********************************************************************************
** Form generated from reading UI file 'searchbar.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SEARCHBAR_H
#define UI_SEARCHBAR_H

#include <QtCore/QVariant>
#include <QtGui/QAction>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QWidget>
#include "kcombobox.h"
#include "khistorycombobox.h"

QT_BEGIN_NAMESPACE

class Ui_SearchBar
{
public:
    QAction *actionMatchCase;
    QAction *actionSearchAutomatically;
    QAction *actionHighlightMatch;
    QHBoxLayout *horizontalLayout;
    QToolButton *closeButton;
    KHistoryComboBox *searchComboBox;
    QToolButton *nextButton;
    QToolButton *previousButton;
    QPushButton *optionsButton;
    QSpacerItem *horizontalSpacer;

    void setupUi(QWidget *SearchBar)
    {
        if (SearchBar->objectName().isEmpty())
            SearchBar->setObjectName("SearchBar");
        SearchBar->resize(564, 34);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Maximum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(SearchBar->sizePolicy().hasHeightForWidth());
        SearchBar->setSizePolicy(sizePolicy);
        actionMatchCase = new QAction(SearchBar);
        actionMatchCase->setObjectName("actionMatchCase");
        actionMatchCase->setCheckable(true);
        actionSearchAutomatically = new QAction(SearchBar);
        actionSearchAutomatically->setObjectName("actionSearchAutomatically");
        actionSearchAutomatically->setCheckable(true);
        actionSearchAutomatically->setChecked(true);
        actionHighlightMatch = new QAction(SearchBar);
        actionHighlightMatch->setObjectName("actionHighlightMatch");
        actionHighlightMatch->setCheckable(true);
        horizontalLayout = new QHBoxLayout(SearchBar);
        horizontalLayout->setObjectName("horizontalLayout");
        closeButton = new QToolButton(SearchBar);
        closeButton->setObjectName("closeButton");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("dialog-close")));
        closeButton->setIcon(icon);
        closeButton->setAutoRaise(true);

        horizontalLayout->addWidget(closeButton);

        searchComboBox = new KHistoryComboBox(SearchBar);
        searchComboBox->setObjectName("searchComboBox");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(10);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(searchComboBox->sizePolicy().hasHeightForWidth());
        searchComboBox->setSizePolicy(sizePolicy1);

        horizontalLayout->addWidget(searchComboBox);

        nextButton = new QToolButton(SearchBar);
        nextButton->setObjectName("nextButton");
        nextButton->setEnabled(false);
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("go-down-search")));
        nextButton->setIcon(icon1);
        nextButton->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);

        horizontalLayout->addWidget(nextButton);

        previousButton = new QToolButton(SearchBar);
        previousButton->setObjectName("previousButton");
        previousButton->setEnabled(false);
        QIcon icon2(QIcon::fromTheme(QString::fromUtf8("go-up-search")));
        previousButton->setIcon(icon2);
        previousButton->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);

        horizontalLayout->addWidget(previousButton);

        optionsButton = new QPushButton(SearchBar);
        optionsButton->setObjectName("optionsButton");
        QIcon icon3(QIcon::fromTheme(QString::fromUtf8("settings-configure")));
        optionsButton->setIcon(icon3);

        horizontalLayout->addWidget(optionsButton);

        horizontalSpacer = new QSpacerItem(20, 20, QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        retranslateUi(SearchBar);
        QObject::connect(closeButton, &QToolButton::clicked, SearchBar, qOverload<>(&QWidget::close));

        QMetaObject::connectSlotsByName(SearchBar);
    } // setupUi

    void retranslateUi(QWidget *SearchBar)
    {
        actionMatchCase->setText(QCoreApplication::translate("SearchBar", "&Match Case", nullptr));
        actionSearchAutomatically->setText(QCoreApplication::translate("SearchBar", "&Search As You Type", nullptr));
        actionHighlightMatch->setText(QCoreApplication::translate("SearchBar", "&Highlight All Matches", nullptr));
#if QT_CONFIG(tooltip)
        actionHighlightMatch->setToolTip(QCoreApplication::translate("SearchBar", "Highlight Matches", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        closeButton->setToolTip(QCoreApplication::translate("SearchBar", "Close the search bar", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        nextButton->setToolTip(QCoreApplication::translate("SearchBar", "Find the next match for the current search phrase", nullptr));
#endif // QT_CONFIG(tooltip)
        nextButton->setText(QCoreApplication::translate("SearchBar", "&Next", nullptr));
#if QT_CONFIG(tooltip)
        previousButton->setToolTip(QCoreApplication::translate("SearchBar", "Find the previous match for the current search phrase", nullptr));
#endif // QT_CONFIG(tooltip)
        previousButton->setText(QCoreApplication::translate("SearchBar", "&Previous", nullptr));
#if QT_CONFIG(tooltip)
        optionsButton->setToolTip(QCoreApplication::translate("SearchBar", "Find the previous match for the current search phrase", nullptr));
#endif // QT_CONFIG(tooltip)
        optionsButton->setText(QCoreApplication::translate("SearchBar", "&Options", nullptr));
        (void)SearchBar;
    } // retranslateUi

};

namespace Ui {
    class SearchBar: public Ui_SearchBar {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_SEARCHBAR_H
