/****************************************************************************
** Meta object code from reading C++ file 'konqsidebarplugin.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../konqueror-26.04.0/sidebar/konqsidebarplugin.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'konqsidebarplugin.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17KonqSidebarModuleE_t {};
} // unnamed namespace

template <> constexpr inline auto KonqSidebarModule::qt_create_metaobjectdata<qt_meta_tag_ZN17KonqSidebarModuleE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KonqSidebarModule",
        "started",
        "",
        "KIO::Job*",
        "completed",
        "setIcon",
        "icon",
        "setCaption",
        "caption",
        "openUrlRequest",
        "QUrl",
        "url",
        "KParts::OpenUrlArguments",
        "args",
        "BrowserArguments",
        "browserArgs",
        "createNewWindow",
        "WindowArgs",
        "popupMenu",
        "KonqSidebarModule*",
        "module",
        "QPoint",
        "global",
        "KFileItemList",
        "items",
        "KParts::NavigationExtension::PopupFlags",
        "flags",
        "KParts::NavigationExtension::ActionGroupMap",
        "actionGroups",
        "submitFormRequest",
        "const char*",
        "enableAction",
        "name",
        "enabled",
        "openUrl",
        "openPreview",
        "openPreviewOnMouseOver",
        "KFileItem",
        "item",
        "slotCurViewUrlChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'started'
        QtMocHelpers::SignalData<void(KIO::Job *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'completed'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'setIcon'
        QtMocHelpers::SignalData<void(const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Signal 'setCaption'
        QtMocHelpers::SignalData<void(const QString &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 },
        }}),
        // Signal 'openUrlRequest'
        QtMocHelpers::SignalData<void(const QUrl &, const KParts::OpenUrlArguments &, const BrowserArguments &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 }, { 0x80000000 | 12, 13 }, { 0x80000000 | 14, 15 },
        }}),
        // Signal 'openUrlRequest'
        QtMocHelpers::SignalData<void(const QUrl &, const KParts::OpenUrlArguments &)>(9, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 10, 11 }, { 0x80000000 | 12, 13 },
        }}),
        // Signal 'openUrlRequest'
        QtMocHelpers::SignalData<void(const QUrl &)>(9, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Signal 'createNewWindow'
        QtMocHelpers::SignalData<void(const QUrl &, const KParts::OpenUrlArguments &, const BrowserArguments &, const WindowArgs &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 }, { 0x80000000 | 12, 13 }, { 0x80000000 | 14, 15 }, { 0x80000000 | 17, 2 },
        }}),
        // Signal 'createNewWindow'
        QtMocHelpers::SignalData<void(const QUrl &, const KParts::OpenUrlArguments &, const BrowserArguments &)>(16, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 10, 11 }, { 0x80000000 | 12, 13 }, { 0x80000000 | 14, 15 },
        }}),
        // Signal 'createNewWindow'
        QtMocHelpers::SignalData<void(const QUrl &, const KParts::OpenUrlArguments &)>(16, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 10, 11 }, { 0x80000000 | 12, 13 },
        }}),
        // Signal 'createNewWindow'
        QtMocHelpers::SignalData<void(const QUrl &)>(16, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Signal 'popupMenu'
        QtMocHelpers::SignalData<void(KonqSidebarModule *, const QPoint &, const KFileItemList &, const KParts::OpenUrlArguments &, const BrowserArguments &, KParts::NavigationExtension::PopupFlags, const KParts::NavigationExtension::ActionGroupMap &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 }, { 0x80000000 | 21, 22 }, { 0x80000000 | 23, 24 }, { 0x80000000 | 12, 13 },
            { 0x80000000 | 14, 15 }, { 0x80000000 | 25, 26 }, { 0x80000000 | 27, 28 },
        }}),
        // Signal 'popupMenu'
        QtMocHelpers::SignalData<void(KonqSidebarModule *, const QPoint &, const KFileItemList &, const KParts::OpenUrlArguments &, const BrowserArguments &, KParts::NavigationExtension::PopupFlags)>(18, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 19, 20 }, { 0x80000000 | 21, 22 }, { 0x80000000 | 23, 24 }, { 0x80000000 | 12, 13 },
            { 0x80000000 | 14, 15 }, { 0x80000000 | 25, 26 },
        }}),
        // Signal 'popupMenu'
        QtMocHelpers::SignalData<void(KonqSidebarModule *, const QPoint &, const KFileItemList &, const KParts::OpenUrlArguments &, const BrowserArguments &)>(18, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 19, 20 }, { 0x80000000 | 21, 22 }, { 0x80000000 | 23, 24 }, { 0x80000000 | 12, 13 },
            { 0x80000000 | 14, 15 },
        }}),
        // Signal 'popupMenu'
        QtMocHelpers::SignalData<void(KonqSidebarModule *, const QPoint &, const KFileItemList &, const KParts::OpenUrlArguments &)>(18, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 19, 20 }, { 0x80000000 | 21, 22 }, { 0x80000000 | 23, 24 }, { 0x80000000 | 12, 13 },
        }}),
        // Signal 'popupMenu'
        QtMocHelpers::SignalData<void(KonqSidebarModule *, const QPoint &, const KFileItemList &)>(18, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 19, 20 }, { 0x80000000 | 21, 22 }, { 0x80000000 | 23, 24 },
        }}),
        // Signal 'submitFormRequest'
        QtMocHelpers::SignalData<void(const char *, const QString &, const QByteArray &, const QString &, const QString &, const QString &)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 30, 2 }, { QMetaType::QString, 2 }, { QMetaType::QByteArray, 2 }, { QMetaType::QString, 2 },
            { QMetaType::QString, 2 }, { QMetaType::QString, 2 },
        }}),
        // Signal 'enableAction'
        QtMocHelpers::SignalData<void(KonqSidebarModule *, const char *, bool)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 }, { 0x80000000 | 30, 32 }, { QMetaType::Bool, 33 },
        }}),
        // Slot 'openUrl'
        QtMocHelpers::SlotData<void(const QUrl &)>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Slot 'openPreview'
        QtMocHelpers::SlotData<void(const KFileItemList &)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 23, 24 },
        }}),
        // Slot 'openPreviewOnMouseOver'
        QtMocHelpers::SlotData<void(const KFileItem &)>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 37, 38 },
        }}),
        // Slot 'slotCurViewUrlChanged'
        QtMocHelpers::SlotData<void(const QUrl &)>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KonqSidebarModule, qt_meta_tag_ZN17KonqSidebarModuleE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KonqSidebarModule::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17KonqSidebarModuleE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17KonqSidebarModuleE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17KonqSidebarModuleE_t>.metaTypes,
    nullptr
} };

void KonqSidebarModule::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KonqSidebarModule *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->started((*reinterpret_cast<std::add_pointer_t<KIO::Job*>>(_a[1]))); break;
        case 1: _t->completed(); break;
        case 2: _t->setIcon((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->setCaption((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->openUrlRequest((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KParts::OpenUrlArguments>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<BrowserArguments>>(_a[3]))); break;
        case 5: _t->openUrlRequest((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KParts::OpenUrlArguments>>(_a[2]))); break;
        case 6: _t->openUrlRequest((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 7: _t->createNewWindow((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KParts::OpenUrlArguments>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<BrowserArguments>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<WindowArgs>>(_a[4]))); break;
        case 8: _t->createNewWindow((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KParts::OpenUrlArguments>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<BrowserArguments>>(_a[3]))); break;
        case 9: _t->createNewWindow((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KParts::OpenUrlArguments>>(_a[2]))); break;
        case 10: _t->createNewWindow((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 11: _t->popupMenu((*reinterpret_cast<std::add_pointer_t<KonqSidebarModule*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<KFileItemList>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<KParts::OpenUrlArguments>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<BrowserArguments>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<KParts::NavigationExtension::PopupFlags>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<KParts::NavigationExtension::ActionGroupMap>>(_a[7]))); break;
        case 12: _t->popupMenu((*reinterpret_cast<std::add_pointer_t<KonqSidebarModule*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<KFileItemList>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<KParts::OpenUrlArguments>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<BrowserArguments>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<KParts::NavigationExtension::PopupFlags>>(_a[6]))); break;
        case 13: _t->popupMenu((*reinterpret_cast<std::add_pointer_t<KonqSidebarModule*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<KFileItemList>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<KParts::OpenUrlArguments>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<BrowserArguments>>(_a[5]))); break;
        case 14: _t->popupMenu((*reinterpret_cast<std::add_pointer_t<KonqSidebarModule*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<KFileItemList>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<KParts::OpenUrlArguments>>(_a[4]))); break;
        case 15: _t->popupMenu((*reinterpret_cast<std::add_pointer_t<KonqSidebarModule*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<KFileItemList>>(_a[3]))); break;
        case 16: _t->submitFormRequest((*reinterpret_cast<std::add_pointer_t<const char*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6]))); break;
        case 17: _t->enableAction((*reinterpret_cast<std::add_pointer_t<KonqSidebarModule*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<const char*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 18: _t->openUrl((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 19: _t->openPreview((*reinterpret_cast<std::add_pointer_t<KFileItemList>>(_a[1]))); break;
        case 20: _t->openPreviewOnMouseOver((*reinterpret_cast<std::add_pointer_t<KFileItem>>(_a[1]))); break;
        case 21: _t->slotCurViewUrlChanged((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KIO::Job* >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KonqSidebarModule* >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KonqSidebarModule* >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KonqSidebarModule* >(); break;
            }
            break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KonqSidebarModule* >(); break;
            }
            break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KonqSidebarModule* >(); break;
            }
            break;
        case 17:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KonqSidebarModule* >(); break;
            }
            break;
        case 20:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KFileItem >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KonqSidebarModule::*)(KIO::Job * )>(_a, &KonqSidebarModule::started, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KonqSidebarModule::*)()>(_a, &KonqSidebarModule::completed, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KonqSidebarModule::*)(const QString & )>(_a, &KonqSidebarModule::setIcon, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (KonqSidebarModule::*)(const QString & )>(_a, &KonqSidebarModule::setCaption, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (KonqSidebarModule::*)(const QUrl & , const KParts::OpenUrlArguments & , const BrowserArguments & )>(_a, &KonqSidebarModule::openUrlRequest, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (KonqSidebarModule::*)(const QUrl & , const KParts::OpenUrlArguments & , const BrowserArguments & , const WindowArgs & )>(_a, &KonqSidebarModule::createNewWindow, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (KonqSidebarModule::*)(KonqSidebarModule * , const QPoint & , const KFileItemList & , const KParts::OpenUrlArguments & , const BrowserArguments & , KParts::NavigationExtension::PopupFlags , const KParts::NavigationExtension::ActionGroupMap & )>(_a, &KonqSidebarModule::popupMenu, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (KonqSidebarModule::*)(const char * , const QString & , const QByteArray & , const QString & , const QString & , const QString & )>(_a, &KonqSidebarModule::submitFormRequest, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (KonqSidebarModule::*)(KonqSidebarModule * , const char * , bool )>(_a, &KonqSidebarModule::enableAction, 17))
            return;
    }
}

const QMetaObject *KonqSidebarModule::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KonqSidebarModule::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17KonqSidebarModuleE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KonqSidebarModule::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 22)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 22;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 22)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 22;
    }
    return _id;
}

// SIGNAL 0
void KonqSidebarModule::started(KIO::Job * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void KonqSidebarModule::completed()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KonqSidebarModule::setIcon(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void KonqSidebarModule::setCaption(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void KonqSidebarModule::openUrlRequest(const QUrl & _t1, const KParts::OpenUrlArguments & _t2, const BrowserArguments & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2, _t3);
}

// SIGNAL 7
void KonqSidebarModule::createNewWindow(const QUrl & _t1, const KParts::OpenUrlArguments & _t2, const BrowserArguments & _t3, const WindowArgs & _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 11
void KonqSidebarModule::popupMenu(KonqSidebarModule * _t1, const QPoint & _t2, const KFileItemList & _t3, const KParts::OpenUrlArguments & _t4, const BrowserArguments & _t5, KParts::NavigationExtension::PopupFlags _t6, const KParts::NavigationExtension::ActionGroupMap & _t7)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1, _t2, _t3, _t4, _t5, _t6, _t7);
}

// SIGNAL 16
void KonqSidebarModule::submitFormRequest(const char * _t1, const QString & _t2, const QByteArray & _t3, const QString & _t4, const QString & _t5, const QString & _t6)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1, _t2, _t3, _t4, _t5, _t6);
}

// SIGNAL 17
void KonqSidebarModule::enableAction(KonqSidebarModule * _t1, const char * _t2, bool _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1, _t2, _t3);
}
namespace {
struct qt_meta_tag_ZN17KonqSidebarPluginE_t {};
} // unnamed namespace

template <> constexpr inline auto KonqSidebarPlugin::qt_create_metaobjectdata<qt_meta_tag_ZN17KonqSidebarPluginE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KonqSidebarPlugin"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KonqSidebarPlugin, qt_meta_tag_ZN17KonqSidebarPluginE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KonqSidebarPlugin::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17KonqSidebarPluginE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17KonqSidebarPluginE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17KonqSidebarPluginE_t>.metaTypes,
    nullptr
} };

void KonqSidebarPlugin::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KonqSidebarPlugin *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *KonqSidebarPlugin::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KonqSidebarPlugin::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17KonqSidebarPluginE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KonqSidebarPlugin::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
