/********************************************************************************
** Form generated from reading UI file 'useragent.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_USERAGENT_H
#define UI_USERAGENT_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kmessagewidget.h"

QT_BEGIN_NAMESPACE

class Ui_UserAgent
{
public:
    QGridLayout *gridLayout;
    QGroupBox *customUABox;
    QVBoxLayout *verticalLayout_3;
    KMessageWidget *invalidTemplateNameWidget;
    QHBoxLayout *horizontalLayout_2;
    QVBoxLayout *verticalLayout;
    QTreeWidget *templates;
    QVBoxLayout *verticalLayout_2;
    QPushButton *newTemplateBtn;
    QPushButton *editTemplateBtn;
    QPushButton *renameTemplateBtn;
    QPushButton *duplicateTemplateBtn;
    QPushButton *deleteTemplateBtn;
    QPushButton *useTemplateBtn;
    QCheckBox *useDefaultUA;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QLineEdit *userAgentString;

    void setupUi(QWidget *UserAgent)
    {
        if (UserAgent->objectName().isEmpty())
            UserAgent->setObjectName("UserAgent");
        UserAgent->resize(536, 552);
        gridLayout = new QGridLayout(UserAgent);
        gridLayout->setObjectName("gridLayout");
        customUABox = new QGroupBox(UserAgent);
        customUABox->setObjectName("customUABox");
        customUABox->setEnabled(true);
        verticalLayout_3 = new QVBoxLayout(customUABox);
        verticalLayout_3->setObjectName("verticalLayout_3");
        invalidTemplateNameWidget = new KMessageWidget(customUABox);
        invalidTemplateNameWidget->setObjectName("invalidTemplateNameWidget");

        verticalLayout_3->addWidget(invalidTemplateNameWidget);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        templates = new QTreeWidget(customUABox);
        templates->setObjectName("templates");
        templates->setEditTriggers(QAbstractItemView::NoEditTriggers);
        templates->setProperty("showDropIndicator", QVariant(false));
        templates->setRootIsDecorated(false);
        templates->setUniformRowHeights(true);
        templates->setItemsExpandable(false);
        templates->setAllColumnsShowFocus(true);
        templates->setColumnCount(2);

        verticalLayout->addWidget(templates);


        horizontalLayout_2->addLayout(verticalLayout);

        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName("verticalLayout_2");
        newTemplateBtn = new QPushButton(customUABox);
        newTemplateBtn->setObjectName("newTemplateBtn");
        newTemplateBtn->setEnabled(true);

        verticalLayout_2->addWidget(newTemplateBtn);

        editTemplateBtn = new QPushButton(customUABox);
        editTemplateBtn->setObjectName("editTemplateBtn");
        editTemplateBtn->setEnabled(false);

        verticalLayout_2->addWidget(editTemplateBtn);

        renameTemplateBtn = new QPushButton(customUABox);
        renameTemplateBtn->setObjectName("renameTemplateBtn");
        renameTemplateBtn->setEnabled(false);

        verticalLayout_2->addWidget(renameTemplateBtn);

        duplicateTemplateBtn = new QPushButton(customUABox);
        duplicateTemplateBtn->setObjectName("duplicateTemplateBtn");
        duplicateTemplateBtn->setEnabled(false);

        verticalLayout_2->addWidget(duplicateTemplateBtn);

        deleteTemplateBtn = new QPushButton(customUABox);
        deleteTemplateBtn->setObjectName("deleteTemplateBtn");
        deleteTemplateBtn->setEnabled(false);

        verticalLayout_2->addWidget(deleteTemplateBtn);


        horizontalLayout_2->addLayout(verticalLayout_2);


        verticalLayout_3->addLayout(horizontalLayout_2);

        useTemplateBtn = new QPushButton(customUABox);
        useTemplateBtn->setObjectName("useTemplateBtn");
        useTemplateBtn->setEnabled(false);

        verticalLayout_3->addWidget(useTemplateBtn);


        gridLayout->addWidget(customUABox, 2, 0, 1, 1);

        useDefaultUA = new QCheckBox(UserAgent);
        useDefaultUA->setObjectName("useDefaultUA");
        useDefaultUA->setChecked(true);

        gridLayout->addWidget(useDefaultUA, 0, 0, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label = new QLabel(UserAgent);
        label->setObjectName("label");

        horizontalLayout->addWidget(label);

        userAgentString = new QLineEdit(UserAgent);
        userAgentString->setObjectName("userAgentString");

        horizontalLayout->addWidget(userAgentString);


        gridLayout->addLayout(horizontalLayout, 1, 0, 1, 1);

#if QT_CONFIG(shortcut)
        label->setBuddy(userAgentString);
#endif // QT_CONFIG(shortcut)

        retranslateUi(UserAgent);

        QMetaObject::connectSlotsByName(UserAgent);
    } // setupUi

    void retranslateUi(QWidget *UserAgent)
    {
        customUABox->setTitle(tr2i18n("Existing identifications", nullptr));
        QTreeWidgetItem *___qtreewidgetitem = templates->headerItem();
        ___qtreewidgetitem->setText(1, tr2i18n("Content", nullptr));
        ___qtreewidgetitem->setText(0, tr2i18n("Name", nullptr));
#if QT_CONFIG(tooltip)
        templates->setToolTip(tr2i18n("<html><head/><body><p><br/></p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        newTemplateBtn->setToolTip(tr2i18n("<html><head/><body><p><br/></p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        newTemplateBtn->setText(tr2i18n("&New...", nullptr));
#if QT_CONFIG(tooltip)
        editTemplateBtn->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        editTemplateBtn->setText(tr2i18n("&Edit...", nullptr));
#if QT_CONFIG(tooltip)
        renameTemplateBtn->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        renameTemplateBtn->setText(tr2i18n("&Rename...", nullptr));
#if QT_CONFIG(tooltip)
        duplicateTemplateBtn->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        duplicateTemplateBtn->setText(tr2i18n("Du&plicate...", nullptr));
#if QT_CONFIG(tooltip)
        deleteTemplateBtn->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        deleteTemplateBtn->setText(tr2i18n("&Delete", nullptr));
#if QT_CONFIG(tooltip)
        useTemplateBtn->setToolTip(tr2i18n("<html><head/><body><p><br/></p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        useTemplateBtn->setText(tr2i18n("Choose &selected identification", nullptr));
#if QT_CONFIG(tooltip)
        useDefaultUA->setToolTip(tr2i18n("<html><head/><body><p>If checked, disable choosing a custom identification and use the default one</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        useDefaultUA->setText(tr2i18n("Use &default identification", nullptr));
#if QT_CONFIG(tooltip)
        label->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        label->setText(tr2i18n("&Custom identification", nullptr));
#if QT_CONFIG(tooltip)
        userAgentString->setToolTip(tr2i18n("<html><head/><body><p>The browser identification to use when the default identification is disabled.</p><p>You can enter it manually or start from one in the list below and change it according to your needs.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        (void)UserAgent;
    } // retranslateUi

};

namespace Ui {
    class UserAgent: public Ui_UserAgent {};
} // namespace Ui

QT_END_NAMESPACE

#endif // USERAGENT_H

