/********************************************************************************
** Form generated from reading UI file 'webenginecustomizecacheablefieldsdlg.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_WEBENGINECUSTOMIZECACHEABLEFIELDSDLG_H
#define UI_WEBENGINECUSTOMIZECACHEABLEFIELDSDLG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>
#include "webfieldsdataview.h"

QT_BEGIN_NAMESPACE

class Ui_WebEngineCustomizeCacheableFieldsDlg
{
public:
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer;
    QCheckBox *showPasswords;
    QSpacerItem *horizontalSpacer_3;
    QCheckBox *showDetails;
    QSpacerItem *horizontalSpacer_2;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout;
    WebFieldsDataView *fields;
    QCheckBox *immediatelyCacheData;
    QDialogButtonBox *buttons;

    void setupUi(QDialog *WebEngineCustomizeCacheableFieldsDlg)
    {
        if (WebEngineCustomizeCacheableFieldsDlg->objectName().isEmpty())
            WebEngineCustomizeCacheableFieldsDlg->setObjectName("WebEngineCustomizeCacheableFieldsDlg");
        WebEngineCustomizeCacheableFieldsDlg->resize(650, 440);
        WebEngineCustomizeCacheableFieldsDlg->setSizeGripEnabled(true);
        WebEngineCustomizeCacheableFieldsDlg->setModal(true);
        verticalLayout_2 = new QVBoxLayout(WebEngineCustomizeCacheableFieldsDlg);
        verticalLayout_2->setObjectName("verticalLayout_2");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        showPasswords = new QCheckBox(WebEngineCustomizeCacheableFieldsDlg);
        showPasswords->setObjectName("showPasswords");

        horizontalLayout->addWidget(showPasswords);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_3);

        showDetails = new QCheckBox(WebEngineCustomizeCacheableFieldsDlg);
        showDetails->setObjectName("showDetails");

        horizontalLayout->addWidget(showDetails);

        horizontalSpacer_2 = new QSpacerItem(35, 19, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_2);


        verticalLayout_2->addLayout(horizontalLayout);

        groupBox = new QGroupBox(WebEngineCustomizeCacheableFieldsDlg);
        groupBox->setObjectName("groupBox");
        verticalLayout = new QVBoxLayout(groupBox);
        verticalLayout->setObjectName("verticalLayout");
        fields = new WebFieldsDataView(groupBox);
        fields->setObjectName("fields");

        verticalLayout->addWidget(fields);


        verticalLayout_2->addWidget(groupBox);

        immediatelyCacheData = new QCheckBox(WebEngineCustomizeCacheableFieldsDlg);
        immediatelyCacheData->setObjectName("immediatelyCacheData");

        verticalLayout_2->addWidget(immediatelyCacheData);

        buttons = new QDialogButtonBox(WebEngineCustomizeCacheableFieldsDlg);
        buttons->setObjectName("buttons");
        buttons->setOrientation(Qt::Orientation::Horizontal);
        buttons->setStandardButtons(QDialogButtonBox::StandardButton::Cancel|QDialogButtonBox::StandardButton::Ok);

        verticalLayout_2->addWidget(buttons);


        retranslateUi(WebEngineCustomizeCacheableFieldsDlg);
        QObject::connect(buttons, &QDialogButtonBox::accepted, WebEngineCustomizeCacheableFieldsDlg, qOverload<>(&QDialog::accept));
        QObject::connect(buttons, &QDialogButtonBox::rejected, WebEngineCustomizeCacheableFieldsDlg, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(WebEngineCustomizeCacheableFieldsDlg);
    } // setupUi

    void retranslateUi(QDialog *WebEngineCustomizeCacheableFieldsDlg)
    {
        WebEngineCustomizeCacheableFieldsDlg->setWindowTitle(tr2i18n("Customize Fields To Store", nullptr));
#if QT_CONFIG(tooltip)
        showPasswords->setToolTip(tr2i18n("Switch between displaying passwords or placeholders", nullptr));
#endif // QT_CONFIG(tooltip)
        showPasswords->setText(tr2i18n("Show &passwords", nullptr));
#if QT_CONFIG(tooltip)
        showDetails->setToolTip(tr2i18n("Show advanced information about the fields", nullptr));
#endif // QT_CONFIG(tooltip)
        showDetails->setText(tr2i18n("Show field &details", nullptr));
        groupBox->setTitle(tr2i18n("Available &fields", nullptr));
#if QT_CONFIG(tooltip)
        immediatelyCacheData->setToolTip(tr2i18n("Store form data in KWallet when closing the dialog", nullptr));
#endif // QT_CONFIG(tooltip)
        immediatelyCacheData->setText(tr2i18n("&Store the contents of selected fields when closing the dialog", nullptr));
    } // retranslateUi

};

namespace Ui {
    class WebEngineCustomizeCacheableFieldsDlg: public Ui_WebEngineCustomizeCacheableFieldsDlg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // WEBENGINECUSTOMIZECACHEABLEFIELDSDLG_H

