/********************************************************************************
** Form generated from reading UI file 'editspeeddialentrydlg.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_EDITSPEEDDIALENTRYDLG_H
#define UI_EDITSPEEDDIALENTRYDLG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kiconbutton.h"
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_EditSpeedDialEntryDlg
{
public:
    QVBoxLayout *verticalLayout;
    QFormLayout *formLayout;
    QLabel *label;
    QLineEdit *nameWidget;
    QLabel *label_2;
    KUrlRequester *urlWidget;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout_2;
    QRadioButton *useFaviconBtn;
    QSpacerItem *verticalSpacer;
    QHBoxLayout *horizontalLayout;
    QRadioButton *useLocalIconBtn;
    KIconButton *localIconBtn;
    QSpacerItem *horizontalSpacer;
    QSpacerItem *verticalSpacer_2;
    QHBoxLayout *horizontalLayout_2;
    QRadioButton *useRemoteIconBtn;
    QLineEdit *remoteIconWidget;
    QDialogButtonBox *buttons;

    void setupUi(QWidget *EditSpeedDialEntryDlg)
    {
        if (EditSpeedDialEntryDlg->objectName().isEmpty())
            EditSpeedDialEntryDlg->setObjectName("EditSpeedDialEntryDlg");
        EditSpeedDialEntryDlg->resize(420, 280);
        verticalLayout = new QVBoxLayout(EditSpeedDialEntryDlg);
        verticalLayout->setObjectName("verticalLayout");
        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        label = new QLabel(EditSpeedDialEntryDlg);
        label->setObjectName("label");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label);

        nameWidget = new QLineEdit(EditSpeedDialEntryDlg);
        nameWidget->setObjectName("nameWidget");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, nameWidget);

        label_2 = new QLabel(EditSpeedDialEntryDlg);
        label_2->setObjectName("label_2");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_2);

        urlWidget = new KUrlRequester(EditSpeedDialEntryDlg);
        urlWidget->setObjectName("urlWidget");
        urlWidget->setMode(KFile::Mode::Directory|KFile::Mode::ExistingOnly|KFile::Mode::File);

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, urlWidget);


        verticalLayout->addLayout(formLayout);

        groupBox = new QGroupBox(EditSpeedDialEntryDlg);
        groupBox->setObjectName("groupBox");
        verticalLayout_2 = new QVBoxLayout(groupBox);
        verticalLayout_2->setObjectName("verticalLayout_2");
        useFaviconBtn = new QRadioButton(groupBox);
        useFaviconBtn->setObjectName("useFaviconBtn");
        useFaviconBtn->setChecked(true);

        verticalLayout_2->addWidget(useFaviconBtn);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        useLocalIconBtn = new QRadioButton(groupBox);
        useLocalIconBtn->setObjectName("useLocalIconBtn");

        horizontalLayout->addWidget(useLocalIconBtn);

        localIconBtn = new KIconButton(groupBox);
        localIconBtn->setObjectName("localIconBtn");
        localIconBtn->setEnabled(false);
        localIconBtn->setIconSize(48);

        horizontalLayout->addWidget(localIconBtn);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        verticalLayout_2->addLayout(horizontalLayout);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer_2);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        useRemoteIconBtn = new QRadioButton(groupBox);
        useRemoteIconBtn->setObjectName("useRemoteIconBtn");

        horizontalLayout_2->addWidget(useRemoteIconBtn);

        remoteIconWidget = new QLineEdit(groupBox);
        remoteIconWidget->setObjectName("remoteIconWidget");
        remoteIconWidget->setEnabled(false);

        horizontalLayout_2->addWidget(remoteIconWidget);


        verticalLayout_2->addLayout(horizontalLayout_2);


        verticalLayout->addWidget(groupBox);

        buttons = new QDialogButtonBox(EditSpeedDialEntryDlg);
        buttons->setObjectName("buttons");
        buttons->setStandardButtons(QDialogButtonBox::StandardButton::Cancel|QDialogButtonBox::StandardButton::Ok);

        verticalLayout->addWidget(buttons);

#if QT_CONFIG(shortcut)
        label->setBuddy(nameWidget);
        label_2->setBuddy(urlWidget);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(nameWidget, urlWidget);
        QWidget::setTabOrder(urlWidget, useFaviconBtn);
        QWidget::setTabOrder(useFaviconBtn, useLocalIconBtn);
        QWidget::setTabOrder(useLocalIconBtn, localIconBtn);
        QWidget::setTabOrder(localIconBtn, useRemoteIconBtn);
        QWidget::setTabOrder(useRemoteIconBtn, remoteIconWidget);

        retranslateUi(EditSpeedDialEntryDlg);

        QMetaObject::connectSlotsByName(EditSpeedDialEntryDlg);
    } // setupUi

    void retranslateUi(QWidget *EditSpeedDialEntryDlg)
    {
        label->setText(tr2i18n("&Name", nullptr));
#if QT_CONFIG(tooltip)
        nameWidget->setToolTip(tr2i18n("The name you want displayed on the Speed Dial button", nullptr));
#endif // QT_CONFIG(tooltip)
        label_2->setText(tr2i18n("&Url", nullptr));
        groupBox->setTitle(tr2i18n("Icon", nullptr));
        useFaviconBtn->setText(tr2i18n("Use favicon", nullptr));
        useLocalIconBtn->setText(tr2i18n("Use local icon", nullptr));
        useRemoteIconBtn->setText(tr2i18n("Use remote icon", nullptr));
        (void)EditSpeedDialEntryDlg;
    } // retranslateUi

};

namespace Ui {
    class EditSpeedDialEntryDlg: public Ui_EditSpeedDialEntryDlg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // EDITSPEEDDIALENTRYDLG_H

