/****************************************************************************
** Meta object code from reading C++ file 'ktabwidget.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../konqueror-26.04.0/src/ktabwidget.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ktabwidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10KTabWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto KTabWidget::qt_create_metaobjectdata<qt_meta_tag_ZN10KTabWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KTabWidget",
        "testCanDecode",
        "",
        "const QDragMoveEvent*",
        "e",
        "bool&",
        "accept",
        "receivedDropEvent",
        "QDropEvent*",
        "QWidget*",
        "initiateDrag",
        "contextMenu",
        "QPoint",
        "mouseDoubleClick",
        "mouseMiddleClick",
        "removeTab",
        "index",
        "setAutomaticResizeTabs",
        "enable",
        "wheelDelta",
        "slotTabMoved",
        "automaticResizeTabs"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'testCanDecode'
        QtMocHelpers::SignalData<void(const QDragMoveEvent *, bool &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 6 },
        }}),
        // Signal 'receivedDropEvent'
        QtMocHelpers::SignalData<void(QDropEvent *)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 2 },
        }}),
        // Signal 'receivedDropEvent'
        QtMocHelpers::SignalData<void(QWidget *, QDropEvent *)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 2 }, { 0x80000000 | 8, 2 },
        }}),
        // Signal 'initiateDrag'
        QtMocHelpers::SignalData<void(QWidget *)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 2 },
        }}),
        // Signal 'contextMenu'
        QtMocHelpers::SignalData<void(const QPoint &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 2 },
        }}),
        // Signal 'contextMenu'
        QtMocHelpers::SignalData<void(QWidget *, const QPoint &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 2 }, { 0x80000000 | 12, 2 },
        }}),
        // Signal 'mouseDoubleClick'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'mouseDoubleClick'
        QtMocHelpers::SignalData<void(QWidget *)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 2 },
        }}),
        // Signal 'mouseMiddleClick'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'mouseMiddleClick'
        QtMocHelpers::SignalData<void(QWidget *)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 2 },
        }}),
        // Slot 'removeTab'
        QtMocHelpers::SlotData<void(int)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 16 },
        }}),
        // Slot 'setAutomaticResizeTabs'
        QtMocHelpers::SlotData<void(bool)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 18 },
        }}),
        // Slot 'receivedDropEvent'
        QtMocHelpers::SlotData<void(int, QDropEvent *)>(7, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Int, 2 }, { 0x80000000 | 8, 2 },
        }}),
        // Slot 'initiateDrag'
        QtMocHelpers::SlotData<void(int)>(10, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'contextMenu'
        QtMocHelpers::SlotData<void(int, const QPoint &)>(11, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Int, 2 }, { 0x80000000 | 12, 2 },
        }}),
        // Slot 'mouseDoubleClick'
        QtMocHelpers::SlotData<void(int)>(13, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'mouseMiddleClick'
        QtMocHelpers::SlotData<void(int)>(14, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'wheelDelta'
        QtMocHelpers::SlotData<void(int)>(19, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'slotTabMoved'
        QtMocHelpers::SlotData<void(int, int)>(20, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 }, { QMetaType::Int, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'automaticResizeTabs'
        QtMocHelpers::PropertyData<bool>(21, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KTabWidget, qt_meta_tag_ZN10KTabWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KTabWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QTabWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10KTabWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10KTabWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10KTabWidgetE_t>.metaTypes,
    nullptr
} };

void KTabWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KTabWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->testCanDecode((*reinterpret_cast<std::add_pointer_t<const QDragMoveEvent*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool&>>(_a[2]))); break;
        case 1: _t->receivedDropEvent((*reinterpret_cast<std::add_pointer_t<QDropEvent*>>(_a[1]))); break;
        case 2: _t->receivedDropEvent((*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDropEvent*>>(_a[2]))); break;
        case 3: _t->initiateDrag((*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[1]))); break;
        case 4: _t->contextMenu((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 5: _t->contextMenu((*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[2]))); break;
        case 6: _t->mouseDoubleClick(); break;
        case 7: _t->mouseDoubleClick((*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[1]))); break;
        case 8: _t->mouseMiddleClick(); break;
        case 9: _t->mouseMiddleClick((*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[1]))); break;
        case 10: _t->removeTab((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 11: _t->setAutomaticResizeTabs((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 12: _t->receivedDropEvent((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDropEvent*>>(_a[2]))); break;
        case 13: _t->initiateDrag((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 14: _t->contextMenu((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[2]))); break;
        case 15: _t->mouseDoubleClick((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 16: _t->mouseMiddleClick((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 17: _t->wheelDelta((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 18: _t->d->slotTabMoved((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWidget* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWidget* >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWidget* >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWidget* >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWidget* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KTabWidget::*)(const QDragMoveEvent * , bool & )>(_a, &KTabWidget::testCanDecode, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KTabWidget::*)(QDropEvent * )>(_a, &KTabWidget::receivedDropEvent, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KTabWidget::*)(QWidget * , QDropEvent * )>(_a, &KTabWidget::receivedDropEvent, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (KTabWidget::*)(QWidget * )>(_a, &KTabWidget::initiateDrag, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (KTabWidget::*)(const QPoint & )>(_a, &KTabWidget::contextMenu, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (KTabWidget::*)(QWidget * , const QPoint & )>(_a, &KTabWidget::contextMenu, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (KTabWidget::*)()>(_a, &KTabWidget::mouseDoubleClick, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (KTabWidget::*)(QWidget * )>(_a, &KTabWidget::mouseDoubleClick, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (KTabWidget::*)()>(_a, &KTabWidget::mouseMiddleClick, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (KTabWidget::*)(QWidget * )>(_a, &KTabWidget::mouseMiddleClick, 9))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->automaticResizeTabs(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setAutomaticResizeTabs(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *KTabWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KTabWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10KTabWidgetE_t>.strings))
        return static_cast<void*>(this);
    return QTabWidget::qt_metacast(_clname);
}

int KTabWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QTabWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void KTabWidget::testCanDecode(const QDragMoveEvent * _t1, bool & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void KTabWidget::receivedDropEvent(QDropEvent * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void KTabWidget::receivedDropEvent(QWidget * _t1, QDropEvent * _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void KTabWidget::initiateDrag(QWidget * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void KTabWidget::contextMenu(const QPoint & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void KTabWidget::contextMenu(QWidget * _t1, const QPoint & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}

// SIGNAL 6
void KTabWidget::mouseDoubleClick()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void KTabWidget::mouseDoubleClick(QWidget * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void KTabWidget::mouseMiddleClick()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void KTabWidget::mouseMiddleClick(QWidget * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}
QT_WARNING_POP
