/****************************************************************************
** Meta object code from reading C++ file 'konqview.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../konqueror-26.04.0/src/konqview.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'konqview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8KonqViewE_t {};
} // unnamed namespace

template <> constexpr inline auto KonqView::qt_create_metaobjectdata<qt_meta_tag_ZN8KonqViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KonqView",
        "sigPartChanged",
        "",
        "KonqView*",
        "childView",
        "KParts::ReadOnlyPart*",
        "oldPart",
        "newPart",
        "viewCompleted",
        "view",
        "urlChanged",
        "QUrl",
        "url",
        "captionChanged",
        "caption",
        "setLocationBarURL",
        "locationBarURL",
        "setIconURL",
        "iconURL",
        "setTabIcon",
        "setCaption",
        "setPageSecurity",
        "slotInfoMessage",
        "KJob*",
        "msg",
        "forceWebEnginePartFocus",
        "slotStarted",
        "KIO::Job*",
        "job",
        "slotCompleted",
        "slotCanceled",
        "errMsg",
        "slotPercent",
        "percent",
        "slotSpeed",
        "bytesPerSecond",
        "slotBrowserPopupMenuFiles",
        "QPoint",
        "global",
        "KFileItemList",
        "items",
        "KParts::OpenUrlArguments",
        "args",
        "BrowserArguments",
        "bargs",
        "KParts::NavigationExtension::PopupFlags",
        "flags",
        "KParts::NavigationExtension::ActionGroupMap",
        "actionGroups",
        "slotBrowserPopupMenuUrl",
        "mode_t",
        "mode",
        "arguments",
        "slotPopupMenuFiles",
        "slotPopupMenuUrl",
        "updateUrl",
        "newUrl",
        "slotSelectionInfo",
        "slotMouseOverInfo",
        "KFileItem",
        "item",
        "slotOpenURLNotify",
        "slotEnableAction",
        "const char*",
        "name",
        "enabled",
        "slotSetActionText",
        "text",
        "slotMoveTopLevelWidget",
        "x",
        "y",
        "slotResizeTopLevelWidget",
        "w",
        "h",
        "slotRequestFocus"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'sigPartChanged'
        QtMocHelpers::SignalData<void(KonqView *, KParts::ReadOnlyPart *, KParts::ReadOnlyPart *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 6 }, { 0x80000000 | 5, 7 },
        }}),
        // Signal 'viewCompleted'
        QtMocHelpers::SignalData<void(KonqView *)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 9 },
        }}),
        // Signal 'urlChanged'
        QtMocHelpers::SignalData<void(const QUrl &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Signal 'captionChanged'
        QtMocHelpers::SignalData<void(const QString &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Slot 'setLocationBarURL'
        QtMocHelpers::SlotData<void(const QString &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 16 },
        }}),
        // Slot 'setIconURL'
        QtMocHelpers::SlotData<void(const QUrl &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 18 },
        }}),
        // Slot 'setTabIcon'
        QtMocHelpers::SlotData<void(const QUrl &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Slot 'setCaption'
        QtMocHelpers::SlotData<void(const QString &)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Slot 'setPageSecurity'
        QtMocHelpers::SlotData<void(int)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'slotInfoMessage'
        QtMocHelpers::SlotData<void(KJob *, const QString &)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 23, 2 }, { QMetaType::QString, 24 },
        }}),
        // Slot 'forceWebEnginePartFocus'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotStarted'
        QtMocHelpers::SlotData<void(KIO::Job *)>(26, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 27, 28 },
        }}),
        // Slot 'slotCompleted'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotCompleted'
        QtMocHelpers::SlotData<void(bool)>(29, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'slotCanceled'
        QtMocHelpers::SlotData<void(const QString &)>(30, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 31 },
        }}),
        // Slot 'slotPercent'
        QtMocHelpers::SlotData<void(KJob *, unsigned long)>(32, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 23, 2 }, { QMetaType::ULong, 33 },
        }}),
        // Slot 'slotSpeed'
        QtMocHelpers::SlotData<void(KJob *, unsigned long)>(34, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 23, 2 }, { QMetaType::ULong, 35 },
        }}),
        // Slot 'slotBrowserPopupMenuFiles'
        QtMocHelpers::SlotData<void(const QPoint &, const KFileItemList &, const KParts::OpenUrlArguments &, const BrowserArguments &, KParts::NavigationExtension::PopupFlags, const KParts::NavigationExtension::ActionGroupMap &)>(36, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 37, 38 }, { 0x80000000 | 39, 40 }, { 0x80000000 | 41, 42 }, { 0x80000000 | 43, 44 },
            { 0x80000000 | 45, 46 }, { 0x80000000 | 47, 48 },
        }}),
        // Slot 'slotBrowserPopupMenuUrl'
        QtMocHelpers::SlotData<void(const QPoint &, const QUrl &, mode_t, const KParts::OpenUrlArguments &, const BrowserArguments &, KParts::NavigationExtension::PopupFlags, const KParts::NavigationExtension::ActionGroupMap &)>(49, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 37, 38 }, { 0x80000000 | 11, 12 }, { 0x80000000 | 50, 51 }, { 0x80000000 | 41, 52 },
            { 0x80000000 | 43, 44 }, { 0x80000000 | 45, 46 }, { 0x80000000 | 47, 48 },
        }}),
        // Slot 'slotPopupMenuFiles'
        QtMocHelpers::SlotData<void(const QPoint &, const KFileItemList &, const KParts::OpenUrlArguments &, KParts::NavigationExtension::PopupFlags, const KParts::NavigationExtension::ActionGroupMap &)>(53, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 37, 38 }, { 0x80000000 | 39, 40 }, { 0x80000000 | 41, 42 }, { 0x80000000 | 45, 46 },
            { 0x80000000 | 47, 48 },
        }}),
        // Slot 'slotPopupMenuUrl'
        QtMocHelpers::SlotData<void(const QPoint &, const QUrl &, mode_t, const KParts::OpenUrlArguments &, KParts::NavigationExtension::PopupFlags, const KParts::NavigationExtension::ActionGroupMap &)>(54, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 37, 38 }, { 0x80000000 | 11, 12 }, { 0x80000000 | 50, 51 }, { 0x80000000 | 41, 52 },
            { 0x80000000 | 45, 46 }, { 0x80000000 | 47, 48 },
        }}),
        // Slot 'updateUrl'
        QtMocHelpers::SlotData<void(const QUrl &)>(55, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 11, 56 },
        }}),
        // Slot 'slotSelectionInfo'
        QtMocHelpers::SlotData<void(const KFileItemList &)>(57, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 39, 40 },
        }}),
        // Slot 'slotMouseOverInfo'
        QtMocHelpers::SlotData<void(const KFileItem &)>(58, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 59, 60 },
        }}),
        // Slot 'slotOpenURLNotify'
        QtMocHelpers::SlotData<void()>(61, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotEnableAction'
        QtMocHelpers::SlotData<void(const char *, bool)>(62, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 63, 64 }, { QMetaType::Bool, 65 },
        }}),
        // Slot 'slotSetActionText'
        QtMocHelpers::SlotData<void(const char *, const QString &)>(66, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 63, 64 }, { QMetaType::QString, 67 },
        }}),
        // Slot 'slotMoveTopLevelWidget'
        QtMocHelpers::SlotData<void(int, int)>(68, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 69 }, { QMetaType::Int, 70 },
        }}),
        // Slot 'slotResizeTopLevelWidget'
        QtMocHelpers::SlotData<void(int, int)>(71, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 72 }, { QMetaType::Int, 73 },
        }}),
        // Slot 'slotRequestFocus'
        QtMocHelpers::SlotData<void(KParts::ReadOnlyPart *)>(74, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 5, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KonqView, qt_meta_tag_ZN8KonqViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KonqView::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KonqViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KonqViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8KonqViewE_t>.metaTypes,
    nullptr
} };

void KonqView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KonqView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sigPartChanged((*reinterpret_cast<std::add_pointer_t<KonqView*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KParts::ReadOnlyPart*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<KParts::ReadOnlyPart*>>(_a[3]))); break;
        case 1: _t->viewCompleted((*reinterpret_cast<std::add_pointer_t<KonqView*>>(_a[1]))); break;
        case 2: _t->urlChanged((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 3: _t->captionChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->setLocationBarURL((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->setIconURL((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 6: _t->setTabIcon((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 7: _t->setCaption((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->setPageSecurity((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 9: _t->slotInfoMessage((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 10: _t->forceWebEnginePartFocus(); break;
        case 11: _t->slotStarted((*reinterpret_cast<std::add_pointer_t<KIO::Job*>>(_a[1]))); break;
        case 12: _t->slotCompleted(); break;
        case 13: _t->slotCompleted((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 14: _t->slotCanceled((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 15: _t->slotPercent((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ulong>>(_a[2]))); break;
        case 16: _t->slotSpeed((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ulong>>(_a[2]))); break;
        case 17: _t->slotBrowserPopupMenuFiles((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KFileItemList>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<KParts::OpenUrlArguments>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<BrowserArguments>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<KParts::NavigationExtension::PopupFlags>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<KParts::NavigationExtension::ActionGroupMap>>(_a[6]))); break;
        case 18: _t->slotBrowserPopupMenuUrl((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<mode_t>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<KParts::OpenUrlArguments>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<BrowserArguments>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<KParts::NavigationExtension::PopupFlags>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<KParts::NavigationExtension::ActionGroupMap>>(_a[7]))); break;
        case 19: _t->slotPopupMenuFiles((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KFileItemList>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<KParts::OpenUrlArguments>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<KParts::NavigationExtension::PopupFlags>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<KParts::NavigationExtension::ActionGroupMap>>(_a[5]))); break;
        case 20: _t->slotPopupMenuUrl((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<mode_t>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<KParts::OpenUrlArguments>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<KParts::NavigationExtension::PopupFlags>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<KParts::NavigationExtension::ActionGroupMap>>(_a[6]))); break;
        case 21: _t->updateUrl((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 22: _t->slotSelectionInfo((*reinterpret_cast<std::add_pointer_t<KFileItemList>>(_a[1]))); break;
        case 23: _t->slotMouseOverInfo((*reinterpret_cast<std::add_pointer_t<KFileItem>>(_a[1]))); break;
        case 24: _t->slotOpenURLNotify(); break;
        case 25: _t->slotEnableAction((*reinterpret_cast<std::add_pointer_t<const char*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 26: _t->slotSetActionText((*reinterpret_cast<std::add_pointer_t<const char*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 27: _t->slotMoveTopLevelWidget((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 28: _t->slotResizeTopLevelWidget((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 29: _t->slotRequestFocus((*reinterpret_cast<std::add_pointer_t<KParts::ReadOnlyPart*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KParts::ReadOnlyPart* >(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KonqView* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KonqView* >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 16:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 23:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KFileItem >(); break;
            }
            break;
        case 29:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KParts::ReadOnlyPart* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KonqView::*)(KonqView * , KParts::ReadOnlyPart * , KParts::ReadOnlyPart * )>(_a, &KonqView::sigPartChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KonqView::*)(KonqView * )>(_a, &KonqView::viewCompleted, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KonqView::*)(const QUrl & )>(_a, &KonqView::urlChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (KonqView::*)(const QString & )>(_a, &KonqView::captionChanged, 3))
            return;
    }
}

const QMetaObject *KonqView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KonqView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KonqViewE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KonqView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 30)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 30;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 30)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 30;
    }
    return _id;
}

// SIGNAL 0
void KonqView::sigPartChanged(KonqView * _t1, KParts::ReadOnlyPart * _t2, KParts::ReadOnlyPart * _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3);
}

// SIGNAL 1
void KonqView::viewCompleted(KonqView * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void KonqView::urlChanged(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void KonqView::captionChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}
QT_WARNING_POP
