/****************************************************************************
** Meta object code from reading C++ file 'fsview_part.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../konqueror-26.04.0/plugins/fsview/fsview_part.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'fsview_part.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN25FSViewNavigationExtensionE_t {};
} // unnamed namespace

template <> constexpr inline auto FSViewNavigationExtension::qt_create_metaobjectdata<qt_meta_tag_ZN25FSViewNavigationExtensionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "FSViewNavigationExtension",
        "selected",
        "",
        "TreeMapItem*",
        "itemSingleClicked",
        "i",
        "itemDoubleClicked",
        "trash",
        "del",
        "editMimeType",
        "refresh",
        "copy",
        "cut"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'selected'
        QtMocHelpers::SlotData<void(TreeMapItem *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Slot 'itemSingleClicked'
        QtMocHelpers::SlotData<void(TreeMapItem *)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 5 },
        }}),
        // Slot 'itemDoubleClicked'
        QtMocHelpers::SlotData<void(TreeMapItem *)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 5 },
        }}),
        // Slot 'trash'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'del'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'editMimeType'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'refresh'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'copy'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'cut'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<FSViewNavigationExtension, qt_meta_tag_ZN25FSViewNavigationExtensionE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject FSViewNavigationExtension::staticMetaObject = { {
    QMetaObject::SuperData::link<BrowserExtension::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25FSViewNavigationExtensionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25FSViewNavigationExtensionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN25FSViewNavigationExtensionE_t>.metaTypes,
    nullptr
} };

void FSViewNavigationExtension::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FSViewNavigationExtension *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->selected((*reinterpret_cast<std::add_pointer_t<TreeMapItem*>>(_a[1]))); break;
        case 1: _t->itemSingleClicked((*reinterpret_cast<std::add_pointer_t<TreeMapItem*>>(_a[1]))); break;
        case 2: _t->itemDoubleClicked((*reinterpret_cast<std::add_pointer_t<TreeMapItem*>>(_a[1]))); break;
        case 3: _t->trash(); break;
        case 4: _t->del(); break;
        case 5: _t->editMimeType(); break;
        case 6: _t->refresh(); break;
        case 7: _t->copy(); break;
        case 8: _t->cut(); break;
        default: ;
        }
    }
}

const QMetaObject *FSViewNavigationExtension::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *FSViewNavigationExtension::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25FSViewNavigationExtensionE_t>.strings))
        return static_cast<void*>(this);
    return BrowserExtension::qt_metacast(_clname);
}

int FSViewNavigationExtension::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = BrowserExtension::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN5FSJobE_t {};
} // unnamed namespace

template <> constexpr inline auto FSJob::qt_create_metaobjectdata<qt_meta_tag_ZN5FSJobE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "FSJob",
        "progressSlot",
        "",
        "percent",
        "dirs",
        "lastDir"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'progressSlot'
        QtMocHelpers::SlotData<void(int, int, const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { QMetaType::Int, 4 }, { QMetaType::QString, 5 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<FSJob, qt_meta_tag_ZN5FSJobE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject FSJob::staticMetaObject = { {
    QMetaObject::SuperData::link<KIO::Job::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5FSJobE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5FSJobE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5FSJobE_t>.metaTypes,
    nullptr
} };

void FSJob::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FSJob *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->progressSlot((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        default: ;
        }
    }
}

const QMetaObject *FSJob::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *FSJob::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5FSJobE_t>.strings))
        return static_cast<void*>(this);
    return KIO::Job::qt_metacast(_clname);
}

int FSJob::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KIO::Job::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN10FSViewPartE_t {};
} // unnamed namespace

template <> constexpr inline auto FSViewPart::qt_create_metaobjectdata<qt_meta_tag_ZN10FSViewPartE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "FSViewPart",
        "updateActions",
        "",
        "contextMenu",
        "TreeMapItem*",
        "QPoint",
        "showInfo",
        "showHelp",
        "startedSlot",
        "completedSlot",
        "dirs",
        "slotShowVisMenu",
        "slotShowAreaMenu",
        "slotShowDepthMenu",
        "slotShowColorMenu",
        "slotProperties",
        "supportsUndo"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'updateActions'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'contextMenu'
        QtMocHelpers::SlotData<void(TreeMapItem *, const QPoint &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 2 }, { 0x80000000 | 5, 2 },
        }}),
        // Slot 'showInfo'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showHelp'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'startedSlot'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'completedSlot'
        QtMocHelpers::SlotData<void(int)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 10 },
        }}),
        // Slot 'slotShowVisMenu'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotShowAreaMenu'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotShowDepthMenu'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotShowColorMenu'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotProperties'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'supportsUndo'
        QtMocHelpers::PropertyData<bool>(16, QMetaType::Bool, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<FSViewPart, qt_meta_tag_ZN10FSViewPartE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject FSViewPart::staticMetaObject = { {
    QMetaObject::SuperData::link<KParts::ReadOnlyPart::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10FSViewPartE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10FSViewPartE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10FSViewPartE_t>.metaTypes,
    nullptr
} };

void FSViewPart::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FSViewPart *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->updateActions(); break;
        case 1: _t->contextMenu((*reinterpret_cast<std::add_pointer_t<TreeMapItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[2]))); break;
        case 2: _t->showInfo(); break;
        case 3: _t->showHelp(); break;
        case 4: _t->startedSlot(); break;
        case 5: _t->completedSlot((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->slotShowVisMenu(); break;
        case 7: _t->slotShowAreaMenu(); break;
        case 8: _t->slotShowDepthMenu(); break;
        case 9: _t->slotShowColorMenu(); break;
        case 10: _t->slotProperties(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->supportsUndo(); break;
        default: break;
        }
    }
}

const QMetaObject *FSViewPart::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *FSViewPart::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10FSViewPartE_t>.strings))
        return static_cast<void*>(this);
    return KParts::ReadOnlyPart::qt_metacast(_clname);
}

int FSViewPart::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KParts::ReadOnlyPart::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}
QT_WARNING_POP
