/****************************************************************************
** Meta object code from reading C++ file 'webenginepage.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../konqueror-26.04.0/webenginepart/src/webenginepage.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'webenginepage.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13WebEnginePageE_t {};
} // unnamed namespace

template <> constexpr inline auto WebEnginePage::qt_create_metaobjectdata<qt_meta_tag_ZN13WebEnginePageE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "WebEnginePage",
        "loadAborted",
        "",
        "QUrl",
        "url",
        "mainFrameNavigationRequested",
        "WebEnginePage*",
        "page",
        "slotLoadFinished",
        "ok",
        "slotGeometryChangeRequested",
        "QRect",
        "rect",
        "slotFeaturePermissionRequested",
        "QWebEnginePage::Feature",
        "feature",
        "slotAuthenticationRequired",
        "requestUrl",
        "QAuthenticator*",
        "auth",
        "changeFullScreenMode",
        "QWebEngineFullScreenRequest",
        "req",
        "changeLifecycleState",
        "QWebEnginePage::LifecycleState",
        "recommendedState",
        "chooseDesktopMedia",
        "QWebEngineDesktopMediaRequest",
        "request",
        "createNewWindow",
        "QWebEngineNewWindowRequest&",
        "print",
        "printFrame",
        "QWebEngineFrame",
        "frame",
        "handleCertificateError",
        "QWebEngineCertificateError",
        "ce",
        "handleNavigationRequest",
        "QWebEngineNavigationRequest&",
        "updateUserStyleSheet",
        "script"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'loadAborted'
        QtMocHelpers::SignalData<void(const QUrl &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'mainFrameNavigationRequested'
        QtMocHelpers::SignalData<void(WebEnginePage *, const QUrl)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 }, { 0x80000000 | 3, 2 },
        }}),
        // Slot 'slotLoadFinished'
        QtMocHelpers::SlotData<void(bool)>(8, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 9 },
        }}),
        // Slot 'slotGeometryChangeRequested'
        QtMocHelpers::SlotData<void(const QRect &)>(10, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Slot 'slotFeaturePermissionRequested'
        QtMocHelpers::SlotData<void(const QUrl &, QWebEnginePage::Feature)>(13, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 14, 15 },
        }}),
        // Slot 'slotAuthenticationRequired'
        QtMocHelpers::SlotData<void(const QUrl &, QAuthenticator *)>(16, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 3, 17 }, { 0x80000000 | 18, 19 },
        }}),
        // Slot 'changeFullScreenMode'
        QtMocHelpers::SlotData<void(QWebEngineFullScreenRequest)>(20, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 21, 22 },
        }}),
        // Slot 'changeLifecycleState'
        QtMocHelpers::SlotData<void(QWebEnginePage::LifecycleState)>(23, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 24, 25 },
        }}),
        // Slot 'chooseDesktopMedia'
        QtMocHelpers::SlotData<void(const QWebEngineDesktopMediaRequest &)>(26, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 27, 28 },
        }}),
        // Slot 'createNewWindow'
        QtMocHelpers::SlotData<void(QWebEngineNewWindowRequest &)>(29, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 30, 22 },
        }}),
        // Slot 'print'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'printFrame'
        QtMocHelpers::SlotData<void(QWebEngineFrame)>(32, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 33, 34 },
        }}),
        // Slot 'handleCertificateError'
        QtMocHelpers::SlotData<void(const QWebEngineCertificateError &)>(35, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 36, 37 },
        }}),
        // Slot 'handleNavigationRequest'
        QtMocHelpers::SlotData<void(QWebEngineNavigationRequest &)>(38, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 39, 22 },
        }}),
        // Slot 'updateUserStyleSheet'
        QtMocHelpers::SlotData<void(const QString &)>(40, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 41 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<WebEnginePage, qt_meta_tag_ZN13WebEnginePageE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject WebEnginePage::staticMetaObject = { {
    QMetaObject::SuperData::link<QWebEnginePage::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13WebEnginePageE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13WebEnginePageE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13WebEnginePageE_t>.metaTypes,
    nullptr
} };

void WebEnginePage::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<WebEnginePage *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->loadAborted((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 1: _t->mainFrameNavigationRequested((*reinterpret_cast<std::add_pointer_t<WebEnginePage*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        case 2: _t->slotLoadFinished((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->slotGeometryChangeRequested((*reinterpret_cast<std::add_pointer_t<QRect>>(_a[1]))); break;
        case 4: _t->slotFeaturePermissionRequested((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QWebEnginePage::Feature>>(_a[2]))); break;
        case 5: _t->slotAuthenticationRequired((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QAuthenticator*>>(_a[2]))); break;
        case 6: _t->changeFullScreenMode((*reinterpret_cast<std::add_pointer_t<QWebEngineFullScreenRequest>>(_a[1]))); break;
        case 7: _t->changeLifecycleState((*reinterpret_cast<std::add_pointer_t<QWebEnginePage::LifecycleState>>(_a[1]))); break;
        case 8: _t->chooseDesktopMedia((*reinterpret_cast<std::add_pointer_t<QWebEngineDesktopMediaRequest>>(_a[1]))); break;
        case 9: _t->createNewWindow((*reinterpret_cast<std::add_pointer_t<QWebEngineNewWindowRequest&>>(_a[1]))); break;
        case 10: _t->print(); break;
        case 11: _t->printFrame((*reinterpret_cast<std::add_pointer_t<QWebEngineFrame>>(_a[1]))); break;
        case 12: _t->handleCertificateError((*reinterpret_cast<std::add_pointer_t<QWebEngineCertificateError>>(_a[1]))); break;
        case 13: _t->handleNavigationRequest((*reinterpret_cast<std::add_pointer_t<QWebEngineNavigationRequest&>>(_a[1]))); break;
        case 14: _t->updateUserStyleSheet((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< WebEnginePage* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (WebEnginePage::*)(const QUrl & )>(_a, &WebEnginePage::loadAborted, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (WebEnginePage::*)(WebEnginePage * , const QUrl )>(_a, &WebEnginePage::mainFrameNavigationRequested, 1))
            return;
    }
}

const QMetaObject *WebEnginePage::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *WebEnginePage::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13WebEnginePageE_t>.strings))
        return static_cast<void*>(this);
    return QWebEnginePage::qt_metacast(_clname);
}

int WebEnginePage::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWebEnginePage::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    return _id;
}

// SIGNAL 0
void WebEnginePage::loadAborted(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void WebEnginePage::mainFrameNavigationRequested(WebEnginePage * _t1, const QUrl _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}
QT_WARNING_POP
