/********************************************************************************
** Form generated from reading UI file 'cookiealertdlg.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_COOKIEALERTDLG_H
#define UI_COOKIEALERTDLG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_CookieAlertDlg
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *header;
    QGroupBox *groupBox;
    QFormLayout *formLayout;
    QLabel *label_2;
    QLineEdit *name;
    QLabel *label_3;
    QLineEdit *value;
    QLabel *label_4;
    QLineEdit *expires;
    QLabel *label_5;
    QLineEdit *path;
    QLineEdit *domain;
    QLabel *label_7;
    QLineEdit *security;
    QLabel *label_6;
    QGroupBox *groupBox_2;
    QVBoxLayout *verticalLayout_2;
    QRadioButton *applyToThis;
    QRadioButton *applyToDomain;
    QRadioButton *applyToAll;
    QDialogButtonBox *buttons;

    void setupUi(QDialog *CookieAlertDlg)
    {
        if (CookieAlertDlg->objectName().isEmpty())
            CookieAlertDlg->setObjectName("CookieAlertDlg");
        CookieAlertDlg->resize(520, 538);
        verticalLayout = new QVBoxLayout(CookieAlertDlg);
        verticalLayout->setObjectName("verticalLayout");
        header = new QLabel(CookieAlertDlg);
        header->setObjectName("header");
        header->setAlignment(Qt::AlignCenter);

        verticalLayout->addWidget(header);

        groupBox = new QGroupBox(CookieAlertDlg);
        groupBox->setObjectName("groupBox");
        formLayout = new QFormLayout(groupBox);
        formLayout->setObjectName("formLayout");
        label_2 = new QLabel(groupBox);
        label_2->setObjectName("label_2");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label_2);

        name = new QLineEdit(groupBox);
        name->setObjectName("name");
        name->setReadOnly(true);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, name);

        label_3 = new QLabel(groupBox);
        label_3->setObjectName("label_3");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, label_3);

        value = new QLineEdit(groupBox);
        value->setObjectName("value");
        value->setReadOnly(true);

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, value);

        label_4 = new QLabel(groupBox);
        label_4->setObjectName("label_4");

        formLayout->setWidget(4, QFormLayout::ItemRole::LabelRole, label_4);

        expires = new QLineEdit(groupBox);
        expires->setObjectName("expires");
        expires->setReadOnly(true);

        formLayout->setWidget(4, QFormLayout::ItemRole::FieldRole, expires);

        label_5 = new QLabel(groupBox);
        label_5->setObjectName("label_5");

        formLayout->setWidget(6, QFormLayout::ItemRole::LabelRole, label_5);

        path = new QLineEdit(groupBox);
        path->setObjectName("path");
        path->setReadOnly(true);

        formLayout->setWidget(6, QFormLayout::ItemRole::FieldRole, path);

        domain = new QLineEdit(groupBox);
        domain->setObjectName("domain");
        domain->setReadOnly(true);

        formLayout->setWidget(9, QFormLayout::ItemRole::FieldRole, domain);

        label_7 = new QLabel(groupBox);
        label_7->setObjectName("label_7");

        formLayout->setWidget(12, QFormLayout::ItemRole::LabelRole, label_7);

        security = new QLineEdit(groupBox);
        security->setObjectName("security");
        security->setReadOnly(true);

        formLayout->setWidget(12, QFormLayout::ItemRole::FieldRole, security);

        label_6 = new QLabel(groupBox);
        label_6->setObjectName("label_6");

        formLayout->setWidget(9, QFormLayout::ItemRole::LabelRole, label_6);


        verticalLayout->addWidget(groupBox);

        groupBox_2 = new QGroupBox(CookieAlertDlg);
        groupBox_2->setObjectName("groupBox_2");
        verticalLayout_2 = new QVBoxLayout(groupBox_2);
        verticalLayout_2->setObjectName("verticalLayout_2");
        applyToThis = new QRadioButton(groupBox_2);
        applyToThis->setObjectName("applyToThis");

        verticalLayout_2->addWidget(applyToThis);

        applyToDomain = new QRadioButton(groupBox_2);
        applyToDomain->setObjectName("applyToDomain");

        verticalLayout_2->addWidget(applyToDomain);

        applyToAll = new QRadioButton(groupBox_2);
        applyToAll->setObjectName("applyToAll");

        verticalLayout_2->addWidget(applyToAll);


        verticalLayout->addWidget(groupBox_2);

        buttons = new QDialogButtonBox(CookieAlertDlg);
        buttons->setObjectName("buttons");
        buttons->setOrientation(Qt::Horizontal);
        buttons->setStandardButtons(QDialogButtonBox::Cancel);

        verticalLayout->addWidget(buttons);


        retranslateUi(CookieAlertDlg);
        QObject::connect(buttons, &QDialogButtonBox::accepted, CookieAlertDlg, qOverload<>(&QDialog::accept));
        QObject::connect(buttons, &QDialogButtonBox::rejected, CookieAlertDlg, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(CookieAlertDlg);
    } // setupUi

    void retranslateUi(QDialog *CookieAlertDlg)
    {
        CookieAlertDlg->setWindowTitle(tr2i18n("CookieAlertDlg", nullptr));
        header->setText(tr2i18n("<html><head/><body><p>You received a cookie from %1</p><p>Do you want to accept or reject this cookie?</p></body></html>", nullptr));
        groupBox->setTitle(tr2i18n("Cookie details", nullptr));
        label_2->setText(tr2i18n("Name", nullptr));
        label_3->setText(tr2i18n("Value", nullptr));
        label_4->setText(tr2i18n("Expires", nullptr));
        label_5->setText(tr2i18n("Path", nullptr));
        label_7->setText(tr2i18n("Exposure", nullptr));
        label_6->setText(tr2i18n("Domain", nullptr));
        groupBox_2->setTitle(tr2i18n("Apply choice to", nullptr));
        applyToThis->setText(tr2i18n("Only this cookie", nullptr));
        applyToDomain->setText(tr2i18n("All cookies from this domain", nullptr));
        applyToAll->setText(tr2i18n("All cookies", nullptr));
    } // retranslateUi

};

namespace Ui {
    class CookieAlertDlg: public Ui_CookieAlertDlg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // COOKIEALERTDLG_H

