/********************************************************************************
** Form generated from reading UI file 'konqnewsessiondlg_base.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_KONQNEWSESSIONDLG_BASE_H
#define UI_KONQNEWSESSIONDLG_BASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "klineedit.h"

QT_BEGIN_NAMESPACE

class Ui_KonqNewSessionDlgBase
{
public:
    QGridLayout *gridLayout;
    QVBoxLayout *verticalLayout;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout_2;
    QRadioButton *m_pAllWindows;
    QRadioButton *m_pCurrentWindow;
    QHBoxLayout *horizontalLayout;
    QLabel *lblSessionName;
    KLineEdit *m_pSessionName;

    void setupUi(QWidget *KonqNewSessionDlgBase)
    {
        if (KonqNewSessionDlgBase->objectName().isEmpty())
            KonqNewSessionDlgBase->setObjectName("KonqNewSessionDlgBase");
        KonqNewSessionDlgBase->resize(371, 163);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(KonqNewSessionDlgBase->sizePolicy().hasHeightForWidth());
        KonqNewSessionDlgBase->setSizePolicy(sizePolicy);
        gridLayout = new QGridLayout(KonqNewSessionDlgBase);
        gridLayout->setObjectName("gridLayout");
        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setSizeConstraint(QLayout::SetFixedSize);
        groupBox = new QGroupBox(KonqNewSessionDlgBase);
        groupBox->setObjectName("groupBox");
        verticalLayout_2 = new QVBoxLayout(groupBox);
        verticalLayout_2->setObjectName("verticalLayout_2");
        m_pAllWindows = new QRadioButton(groupBox);
        m_pAllWindows->setObjectName("m_pAllWindows");
        m_pAllWindows->setChecked(true);

        verticalLayout_2->addWidget(m_pAllWindows);

        m_pCurrentWindow = new QRadioButton(groupBox);
        m_pCurrentWindow->setObjectName("m_pCurrentWindow");

        verticalLayout_2->addWidget(m_pCurrentWindow);


        verticalLayout->addWidget(groupBox);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        lblSessionName = new QLabel(KonqNewSessionDlgBase);
        lblSessionName->setObjectName("lblSessionName");

        horizontalLayout->addWidget(lblSessionName);

        m_pSessionName = new KLineEdit(KonqNewSessionDlgBase);
        m_pSessionName->setObjectName("m_pSessionName");

        horizontalLayout->addWidget(m_pSessionName);


        verticalLayout->addLayout(horizontalLayout);


        gridLayout->addLayout(verticalLayout, 0, 0, 1, 1);

#if QT_CONFIG(shortcut)
        lblSessionName->setBuddy(m_pSessionName);
#endif // QT_CONFIG(shortcut)

        retranslateUi(KonqNewSessionDlgBase);

        QMetaObject::connectSlotsByName(KonqNewSessionDlgBase);
    } // setupUi

    void retranslateUi(QWidget *KonqNewSessionDlgBase)
    {
        groupBox->setTitle(tr2i18n("Save open &tabs and windows for easy retrieval", nullptr));
        m_pAllWindows->setText(tr2i18n("A&ll open windows", nullptr));
        m_pCurrentWindow->setText(tr2i18n("Onl&y current window", nullptr));
        lblSessionName->setText(tr2i18n("Session n&ame:", nullptr));
        (void)KonqNewSessionDlgBase;
    } // retranslateUi

};

namespace Ui {
    class KonqNewSessionDlgBase: public Ui_KonqNewSessionDlgBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // KONQNEWSESSIONDLG_BASE_H

