/****************************************************************************
** Meta object code from reading C++ file 'webenginewallet.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../konqueror-26.04.0/webenginepart/src/wallet/webenginewallet.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'webenginewallet.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15WebEngineWalletE_t {};
} // unnamed namespace

template <> constexpr inline auto WebEngineWallet::qt_create_metaobjectdata<qt_meta_tag_ZN15WebEngineWalletE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "WebEngineWallet",
        "saveFormDataRequested",
        "",
        "key",
        "QUrl",
        "url",
        "saveFormDataCompleted",
        "ok",
        "fillFormRequestCompleted",
        "formDetectionDone",
        "found",
        "autoFillableFound",
        "walletClosed",
        "walletOpened",
        "acceptSaveFormDataRequest",
        "rejectSaveFormDataRequest",
        "detectAndFillPageForms",
        "WebEnginePage*",
        "page",
        "saveFormsInPage",
        "customizeFieldsToCache",
        "QWidget*",
        "widget",
        "removeCustomizationForPage",
        "savePageDataNow",
        "_k_openWalletDone",
        "_k_walletClosed"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'saveFormDataRequested'
        QtMocHelpers::SignalData<void(const QString &, const QUrl &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { 0x80000000 | 4, 5 },
        }}),
        // Signal 'saveFormDataCompleted'
        QtMocHelpers::SignalData<void(const QUrl &, bool)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 }, { QMetaType::Bool, 7 },
        }}),
        // Signal 'fillFormRequestCompleted'
        QtMocHelpers::SignalData<void(bool)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 7 },
        }}),
        // Signal 'formDetectionDone'
        QtMocHelpers::SignalData<void(const QUrl &, bool, bool)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 }, { QMetaType::Bool, 10 }, { QMetaType::Bool, 11 },
        }}),
        // Signal 'walletClosed'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'walletOpened'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'acceptSaveFormDataRequest'
        QtMocHelpers::SlotData<void(const QString &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'rejectSaveFormDataRequest'
        QtMocHelpers::SlotData<void(const QString &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'detectAndFillPageForms'
        QtMocHelpers::SlotData<void(WebEnginePage *)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Slot 'detectAndFillPageForms'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'saveFormsInPage'
        QtMocHelpers::SlotData<void(WebEnginePage *)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Slot 'customizeFieldsToCache'
        QtMocHelpers::SlotData<void(WebEnginePage *, QWidget *)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 }, { 0x80000000 | 21, 22 },
        }}),
        // Slot 'customizeFieldsToCache'
        QtMocHelpers::SlotData<void(WebEnginePage *)>(20, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Slot 'removeCustomizationForPage'
        QtMocHelpers::SlotData<void(const QUrl &)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Slot 'savePageDataNow'
        QtMocHelpers::SlotData<void(WebEnginePage *)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Slot '_k_openWalletDone'
        QtMocHelpers::SlotData<void(bool)>(25, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot '_k_walletClosed'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<WebEngineWallet, qt_meta_tag_ZN15WebEngineWalletE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject WebEngineWallet::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15WebEngineWalletE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15WebEngineWalletE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15WebEngineWalletE_t>.metaTypes,
    nullptr
} };

void WebEngineWallet::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<WebEngineWallet *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->saveFormDataRequested((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        case 1: _t->saveFormDataCompleted((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 2: _t->fillFormRequestCompleted((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->formDetectionDone((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 4: _t->walletClosed(); break;
        case 5: _t->walletOpened(); break;
        case 6: _t->acceptSaveFormDataRequest((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->rejectSaveFormDataRequest((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->detectAndFillPageForms((*reinterpret_cast<std::add_pointer_t<WebEnginePage*>>(_a[1]))); break;
        case 9: _t->detectAndFillPageForms(); break;
        case 10: _t->saveFormsInPage((*reinterpret_cast<std::add_pointer_t<WebEnginePage*>>(_a[1]))); break;
        case 11: _t->customizeFieldsToCache((*reinterpret_cast<std::add_pointer_t<WebEnginePage*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[2]))); break;
        case 12: _t->customizeFieldsToCache((*reinterpret_cast<std::add_pointer_t<WebEnginePage*>>(_a[1]))); break;
        case 13: _t->removeCustomizationForPage((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 14: _t->savePageDataNow((*reinterpret_cast<std::add_pointer_t<WebEnginePage*>>(_a[1]))); break;
        case 15: _t->d->_k_openWalletDone((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 16: _t->d->_k_walletClosed(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWidget* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (WebEngineWallet::*)(const QString & , const QUrl & )>(_a, &WebEngineWallet::saveFormDataRequested, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (WebEngineWallet::*)(const QUrl & , bool )>(_a, &WebEngineWallet::saveFormDataCompleted, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (WebEngineWallet::*)(bool )>(_a, &WebEngineWallet::fillFormRequestCompleted, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (WebEngineWallet::*)(const QUrl & , bool , bool )>(_a, &WebEngineWallet::formDetectionDone, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (WebEngineWallet::*)()>(_a, &WebEngineWallet::walletClosed, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (WebEngineWallet::*)()>(_a, &WebEngineWallet::walletOpened, 5))
            return;
    }
}

const QMetaObject *WebEngineWallet::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *WebEngineWallet::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15WebEngineWalletE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int WebEngineWallet::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    return _id;
}

// SIGNAL 0
void WebEngineWallet::saveFormDataRequested(const QString & _t1, const QUrl & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void WebEngineWallet::saveFormDataCompleted(const QUrl & _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void WebEngineWallet::fillFormRequestCompleted(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void WebEngineWallet::formDetectionDone(const QUrl & _t1, bool _t2, bool _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2, _t3);
}

// SIGNAL 4
void WebEngineWallet::walletClosed()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void WebEngineWallet::walletOpened()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
QT_WARNING_POP
