/****************************************************************************
** Meta object code from reading C++ file 'webenginepart.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../konqueror-26.04.0/webenginepart/src/webenginepart.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'webenginepart.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13WebEnginePartE_t {};
} // unnamed namespace

template <> constexpr inline auto WebEnginePart::qt_create_metaobjectdata<qt_meta_tag_ZN13WebEnginePartE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "WebEnginePart",
        "exitFullScreen",
        "",
        "setInspectedPart",
        "KParts::ReadOnlyPart*",
        "part",
        "displayActOnDownloadedFileBar",
        "KonqInterfaces::DownloadJob*",
        "job",
        "displayPrintPreview",
        "slotShowSecurity",
        "slotShowSearchBar",
        "slotLoadStarted",
        "slotLoadAborted",
        "QUrl",
        "slotLoadFinished",
        "slotSearchForText",
        "text",
        "backward",
        "slotLinkHovered",
        "slotLinkMiddleOrCtrlClicked",
        "slotSelectionClipboardUrlPasted",
        "slotUrlChanged",
        "url",
        "resetWallet",
        "slotShowWalletMenu",
        "slotLaunchWalletManager",
        "togglePasswordStorableState",
        "on",
        "slotRemoveCachedPasswords",
        "slotSetTextEncoding",
        "codecName",
        "slotSetStatusBarText",
        "slotWindowCloseRequested",
        "slotSaveFormDataRequested",
        "slotSaveFormDataDone",
        "slotWalletSavedForms",
        "success",
        "slotFillFormRequestCompleted",
        "slotFeaturePolicyChosen",
        "FeaturePermissionBar*",
        "bar",
        "QWebEnginePage::Feature",
        "feature",
        "QWebEnginePage::PermissionPolicy",
        "policy",
        "deleteFeaturePermissionBar",
        "updateWalletStatusBarIcon",
        "walletFinishedFormDetection",
        "found",
        "autoFillableFound",
        "updateWalletActions",
        "reloadAfterUAChange",
        "recordNavigationAccepted",
        "WebEnginePage*",
        "page",
        "modified",
        "isWebEnginePart"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'exitFullScreen'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setInspectedPart'
        QtMocHelpers::SlotData<void(KParts::ReadOnlyPart *)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Slot 'displayActOnDownloadedFileBar'
        QtMocHelpers::SlotData<void(KonqInterfaces::DownloadJob *)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Slot 'displayPrintPreview'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotShowSecurity'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotShowSearchBar'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotLoadStarted'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotLoadAborted'
        QtMocHelpers::SlotData<void(const QUrl &)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 14, 2 },
        }}),
        // Slot 'slotLoadFinished'
        QtMocHelpers::SlotData<void(bool)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'slotSearchForText'
        QtMocHelpers::SlotData<void(const QString &, bool)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 17 }, { QMetaType::Bool, 18 },
        }}),
        // Slot 'slotLinkHovered'
        QtMocHelpers::SlotData<void(const QString &)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'slotLinkMiddleOrCtrlClicked'
        QtMocHelpers::SlotData<void(const QUrl &)>(20, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 14, 2 },
        }}),
        // Slot 'slotSelectionClipboardUrlPasted'
        QtMocHelpers::SlotData<void(const QUrl &, const QString &)>(21, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 14, 2 }, { QMetaType::QString, 2 },
        }}),
        // Slot 'slotUrlChanged'
        QtMocHelpers::SlotData<void(const QUrl &)>(22, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 14, 23 },
        }}),
        // Slot 'resetWallet'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotShowWalletMenu'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotLaunchWalletManager'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'togglePasswordStorableState'
        QtMocHelpers::SlotData<void(bool)>(27, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 28 },
        }}),
        // Slot 'slotRemoveCachedPasswords'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSetTextEncoding'
        QtMocHelpers::SlotData<void(const QString &)>(30, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 31 },
        }}),
        // Slot 'slotSetStatusBarText'
        QtMocHelpers::SlotData<void(const QString &)>(32, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 17 },
        }}),
        // Slot 'slotWindowCloseRequested'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSaveFormDataRequested'
        QtMocHelpers::SlotData<void(const QString &, const QUrl &)>(34, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 2 }, { 0x80000000 | 14, 2 },
        }}),
        // Slot 'slotSaveFormDataDone'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotWalletSavedForms'
        QtMocHelpers::SlotData<void(const QUrl &, bool)>(36, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 14, 23 }, { QMetaType::Bool, 37 },
        }}),
        // Slot 'slotFillFormRequestCompleted'
        QtMocHelpers::SlotData<void(bool)>(38, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'slotFeaturePolicyChosen'
        QtMocHelpers::SlotData<void(FeaturePermissionBar *, QWebEnginePage::Feature, QWebEnginePage::PermissionPolicy)>(39, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 40, 41 }, { 0x80000000 | 42, 43 }, { 0x80000000 | 44, 45 },
        }}),
        // Slot 'deleteFeaturePermissionBar'
        QtMocHelpers::SlotData<void(FeaturePermissionBar *)>(46, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 40, 41 },
        }}),
        // Slot 'updateWalletStatusBarIcon'
        QtMocHelpers::SlotData<void()>(47, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'walletFinishedFormDetection'
        QtMocHelpers::SlotData<void(const QUrl &, bool, bool)>(48, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 14, 23 }, { QMetaType::Bool, 49 }, { QMetaType::Bool, 50 },
        }}),
        // Slot 'updateWalletActions'
        QtMocHelpers::SlotData<void()>(51, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'reloadAfterUAChange'
        QtMocHelpers::SlotData<void(const QString &)>(52, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'recordNavigationAccepted'
        QtMocHelpers::SlotData<void(WebEnginePage *, const QUrl &)>(53, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 54, 55 }, { 0x80000000 | 14, 23 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'modified'
        QtMocHelpers::PropertyData<bool>(56, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'isWebEnginePart'
        QtMocHelpers::PropertyData<bool>(57, QMetaType::Bool, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<WebEnginePart, qt_meta_tag_ZN13WebEnginePartE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject WebEnginePart::staticMetaObject = { {
    QMetaObject::SuperData::link<KParts::ReadOnlyPart::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13WebEnginePartE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13WebEnginePartE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13WebEnginePartE_t>.metaTypes,
    nullptr
} };

void WebEnginePart::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<WebEnginePart *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->exitFullScreen(); break;
        case 1: _t->setInspectedPart((*reinterpret_cast<std::add_pointer_t<KParts::ReadOnlyPart*>>(_a[1]))); break;
        case 2: _t->displayActOnDownloadedFileBar((*reinterpret_cast<std::add_pointer_t<KonqInterfaces::DownloadJob*>>(_a[1]))); break;
        case 3: _t->displayPrintPreview(); break;
        case 4: _t->slotShowSecurity(); break;
        case 5: _t->slotShowSearchBar(); break;
        case 6: _t->slotLoadStarted(); break;
        case 7: _t->slotLoadAborted((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 8: _t->slotLoadFinished((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->slotSearchForText((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 10: _t->slotLinkHovered((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: _t->slotLinkMiddleOrCtrlClicked((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 12: _t->slotSelectionClipboardUrlPasted((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 13: _t->slotUrlChanged((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 14: _t->resetWallet(); break;
        case 15: _t->slotShowWalletMenu(); break;
        case 16: _t->slotLaunchWalletManager(); break;
        case 17: _t->togglePasswordStorableState((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 18: _t->slotRemoveCachedPasswords(); break;
        case 19: _t->slotSetTextEncoding((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 20: _t->slotSetStatusBarText((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 21: _t->slotWindowCloseRequested(); break;
        case 22: _t->slotSaveFormDataRequested((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        case 23: _t->slotSaveFormDataDone(); break;
        case 24: _t->slotWalletSavedForms((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 25: _t->slotFillFormRequestCompleted((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 26: _t->slotFeaturePolicyChosen((*reinterpret_cast<std::add_pointer_t<FeaturePermissionBar*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QWebEnginePage::Feature>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QWebEnginePage::PermissionPolicy>>(_a[3]))); break;
        case 27: _t->deleteFeaturePermissionBar((*reinterpret_cast<std::add_pointer_t<FeaturePermissionBar*>>(_a[1]))); break;
        case 28: _t->updateWalletStatusBarIcon(); break;
        case 29: _t->walletFinishedFormDetection((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 30: _t->updateWalletActions(); break;
        case 31: _t->reloadAfterUAChange((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 32: _t->recordNavigationAccepted((*reinterpret_cast<std::add_pointer_t<WebEnginePage*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KParts::ReadOnlyPart* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->isModified(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isWebEnginePart(); break;
        default: break;
        }
    }
}

const QMetaObject *WebEnginePart::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *WebEnginePart::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13WebEnginePartE_t>.strings))
        return static_cast<void*>(this);
    return KParts::ReadOnlyPart::qt_metacast(_clname);
}

int WebEnginePart::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KParts::ReadOnlyPart::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 33)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 33;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 33)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 33;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}
QT_WARNING_POP
