/********************************************************************************
** Form generated from reading UI file 'cache.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CACHE_H
#define UI_CACHE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_Cache
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *cacheEnabled;
    QVBoxLayout *verticalLayout_2;
    QCheckBox *memoryCache;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QSpinBox *cacheSize;
    QSpacerItem *horizontalSpacer;
    QGroupBox *useCustomCacheDir;
    QHBoxLayout *horizontalLayout_3;
    QLabel *customCachePathLabel;
    KUrlRequester *customCacheDir;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *Cache)
    {
        if (Cache->objectName().isEmpty())
            Cache->setObjectName("Cache");
        Cache->resize(575, 206);
        verticalLayout = new QVBoxLayout(Cache);
        verticalLayout->setObjectName("verticalLayout");
        cacheEnabled = new QGroupBox(Cache);
        cacheEnabled->setObjectName("cacheEnabled");
        cacheEnabled->setCheckable(true);
        verticalLayout_2 = new QVBoxLayout(cacheEnabled);
        verticalLayout_2->setObjectName("verticalLayout_2");
        memoryCache = new QCheckBox(cacheEnabled);
        memoryCache->setObjectName("memoryCache");
        memoryCache->setEnabled(true);

        verticalLayout_2->addWidget(memoryCache);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label = new QLabel(cacheEnabled);
        label->setObjectName("label");

        horizontalLayout->addWidget(label);

        cacheSize = new QSpinBox(cacheEnabled);
        cacheSize->setObjectName("cacheSize");
        cacheSize->setMaximum(1000);

        horizontalLayout->addWidget(cacheSize);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        verticalLayout_2->addLayout(horizontalLayout);

        useCustomCacheDir = new QGroupBox(cacheEnabled);
        useCustomCacheDir->setObjectName("useCustomCacheDir");
        useCustomCacheDir->setCheckable(true);
        horizontalLayout_3 = new QHBoxLayout(useCustomCacheDir);
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        customCachePathLabel = new QLabel(useCustomCacheDir);
        customCachePathLabel->setObjectName("customCachePathLabel");
        customCachePathLabel->setEnabled(true);

        horizontalLayout_3->addWidget(customCachePathLabel);

        customCacheDir = new KUrlRequester(useCustomCacheDir);
        customCacheDir->setObjectName("customCacheDir");
        customCacheDir->setEnabled(true);
        customCacheDir->setMode(KFile::Directory|KFile::ExistingOnly|KFile::LocalOnly);

        horizontalLayout_3->addWidget(customCacheDir);


        verticalLayout_2->addWidget(useCustomCacheDir);


        verticalLayout->addWidget(cacheEnabled);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

#if QT_CONFIG(shortcut)
        label->setBuddy(cacheSize);
        customCachePathLabel->setBuddy(customCacheDir);
#endif // QT_CONFIG(shortcut)

        retranslateUi(Cache);

        QMetaObject::connectSlotsByName(Cache);
    } // setupUi

    void retranslateUi(QWidget *Cache)
    {
        cacheEnabled->setTitle(tr2i18n("&Enable cache", nullptr));
#if QT_CONFIG(tooltip)
        memoryCache->setToolTip(tr2i18n("<html><head/><body><p>Don't store the cache on disk but only in memory.</p><p>Turning this on means that the cache will be cleared when exiting Konqueror</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        memoryCache->setText(tr2i18n("Keep cache in &memory", nullptr));
        label->setText(tr2i18n("&Cache size", nullptr));
#if QT_CONFIG(tooltip)
        cacheSize->setToolTip(tr2i18n("The maximum space on disk or memory the cache can use. When this threshold is reached, old pages will be removed to make space for new ones", nullptr));
#endif // QT_CONFIG(tooltip)
        cacheSize->setSpecialValueText(tr2i18n("Auto", nullptr));
        cacheSize->setSuffix(tr2i18n(" MB", nullptr));
        cacheSize->setPrefix(QString());
#if QT_CONFIG(tooltip)
        useCustomCacheDir->setToolTip(tr2i18n("Use a custom directory to keep the cache", nullptr));
#endif // QT_CONFIG(tooltip)
        useCustomCacheDir->setTitle(tr2i18n("&Custom cache directory", nullptr));
        customCachePathLabel->setText(tr2i18n("Cache &Directory", nullptr));
#if QT_CONFIG(tooltip)
        customCacheDir->setToolTip(tr2i18n("The custom directory to store cache", nullptr));
#endif // QT_CONFIG(tooltip)
        (void)Cache;
    } // retranslateUi

};

namespace Ui {
    class Cache: public Ui_Cache {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CACHE_H

