/****************************************************************************
** Meta object code from reading C++ file 'ktabbar.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../konqueror-26.04.0/src/ktabbar.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ktabbar.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7KTabBarE_t {};
} // unnamed namespace

template <> constexpr inline auto KTabBar::qt_create_metaobjectdata<qt_meta_tag_ZN7KTabBarE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KTabBar",
        "contextMenu",
        "",
        "index",
        "QPoint",
        "globalPos",
        "emptyAreaContextMenu",
        "tabDoubleClicked",
        "newTabRequest",
        "mouseMiddleClick",
        "initiateDrag",
        "testCanDecode",
        "const QDragMoveEvent*",
        "bool&",
        "receivedDropEvent",
        "QDropEvent*",
        "moveTab",
        "wheelDelta",
        "activateDragSwitchTab"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'contextMenu'
        QtMocHelpers::SignalData<void(int, const QPoint &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { 0x80000000 | 4, 5 },
        }}),
        // Signal 'emptyAreaContextMenu'
        QtMocHelpers::SignalData<void(const QPoint &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Signal 'tabDoubleClicked'
        QtMocHelpers::SignalData<void(int)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'newTabRequest'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'mouseMiddleClick'
        QtMocHelpers::SignalData<void(int)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'initiateDrag'
        QtMocHelpers::SignalData<void(int)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'testCanDecode'
        QtMocHelpers::SignalData<void(const QDragMoveEvent *, bool &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 2 }, { 0x80000000 | 13, 2 },
        }}),
        // Signal 'receivedDropEvent'
        QtMocHelpers::SignalData<void(int, QDropEvent *)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 }, { 0x80000000 | 15, 2 },
        }}),
        // Signal 'moveTab'
        QtMocHelpers::SignalData<void(int, int)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 }, { QMetaType::Int, 2 },
        }}),
        // Signal 'wheelDelta'
        QtMocHelpers::SignalData<void(int)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'activateDragSwitchTab'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KTabBar, qt_meta_tag_ZN7KTabBarE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KTabBar::staticMetaObject = { {
    QMetaObject::SuperData::link<QTabBar::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7KTabBarE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7KTabBarE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7KTabBarE_t>.metaTypes,
    nullptr
} };

void KTabBar::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KTabBar *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->contextMenu((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[2]))); break;
        case 1: _t->emptyAreaContextMenu((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 2: _t->tabDoubleClicked((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->newTabRequest(); break;
        case 4: _t->mouseMiddleClick((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->initiateDrag((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->testCanDecode((*reinterpret_cast<std::add_pointer_t<const QDragMoveEvent*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool&>>(_a[2]))); break;
        case 7: _t->receivedDropEvent((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDropEvent*>>(_a[2]))); break;
        case 8: _t->moveTab((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 9: _t->wheelDelta((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 10: _t->activateDragSwitchTab(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KTabBar::*)(int , const QPoint & )>(_a, &KTabBar::contextMenu, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KTabBar::*)(const QPoint & )>(_a, &KTabBar::emptyAreaContextMenu, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KTabBar::*)(int )>(_a, &KTabBar::tabDoubleClicked, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (KTabBar::*)()>(_a, &KTabBar::newTabRequest, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (KTabBar::*)(int )>(_a, &KTabBar::mouseMiddleClick, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (KTabBar::*)(int )>(_a, &KTabBar::initiateDrag, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (KTabBar::*)(const QDragMoveEvent * , bool & )>(_a, &KTabBar::testCanDecode, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (KTabBar::*)(int , QDropEvent * )>(_a, &KTabBar::receivedDropEvent, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (KTabBar::*)(int , int )>(_a, &KTabBar::moveTab, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (KTabBar::*)(int )>(_a, &KTabBar::wheelDelta, 9))
            return;
    }
}

const QMetaObject *KTabBar::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KTabBar::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7KTabBarE_t>.strings))
        return static_cast<void*>(this);
    return QTabBar::qt_metacast(_clname);
}

int KTabBar::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QTabBar::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void KTabBar::contextMenu(int _t1, const QPoint & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void KTabBar::emptyAreaContextMenu(const QPoint & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void KTabBar::tabDoubleClicked(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void KTabBar::newTabRequest()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void KTabBar::mouseMiddleClick(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void KTabBar::initiateDrag(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void KTabBar::testCanDecode(const QDragMoveEvent * _t1, bool & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
}

// SIGNAL 7
void KTabBar::receivedDropEvent(int _t1, QDropEvent * _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2);
}

// SIGNAL 8
void KTabBar::moveTab(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1, _t2);
}

// SIGNAL 9
void KTabBar::wheelDelta(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}
QT_WARNING_POP
