/****************************************************************************
** Meta object code from reading C++ file 'konqclosedwindowsmanageradaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "konqclosedwindowsmanageradaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'konqclosedwindowsmanageradaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN31KonqClosedWindowsManagerAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto KonqClosedWindowsManagerAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN31KonqClosedWindowsManagerAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KonqClosedWindowsManagerAdaptor",
        "D-Bus Interface",
        "org.kde.Konqueror.UndoManager",
        "D-Bus Introspection",
        "  <interface name=\"org.kde.Konqueror.UndoManager\">\n    <signal "
        "name=\"notifyClosedWindowItem\">\n      <arg direction=\"out\" typ"
        "e=\"s\" name=\"title\"/>\n      <arg direction=\"out\" type=\"i\" "
        "name=\"numTabs\"/>\n      <arg direction=\"out\" type=\"s\" name=\""
        "configFileName\"/>\n      <arg direction=\"out\" type=\"s\" name=\""
        "configGroup\"/>\n    </signal>\n    <signal name=\"notifyRemove\">"
        "\n      <arg direction=\"out\" type=\"s\" name=\"configFileName\"/"
        ">\n      <arg direction=\"out\" type=\"s\" name=\"configGroup\"/>\n"
        "    </signal>\n  </interface>\n",
        "notifyClosedWindowItem",
        "",
        "title",
        "numTabs",
        "configFileName",
        "configGroup",
        "notifyRemove"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'notifyClosedWindowItem'
        QtMocHelpers::SignalData<void(const QString &, int, const QString &, const QString &)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::Int, 8 }, { QMetaType::QString, 9 }, { QMetaType::QString, 10 },
        }}),
        // Signal 'notifyRemove'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(11, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 }, { QMetaType::QString, 10 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<KonqClosedWindowsManagerAdaptor, qt_meta_tag_ZN31KonqClosedWindowsManagerAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject KonqClosedWindowsManagerAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN31KonqClosedWindowsManagerAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN31KonqClosedWindowsManagerAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN31KonqClosedWindowsManagerAdaptorE_t>.metaTypes,
    nullptr
} };

void KonqClosedWindowsManagerAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KonqClosedWindowsManagerAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->notifyClosedWindowItem((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4]))); break;
        case 1: _t->notifyRemove((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KonqClosedWindowsManagerAdaptor::*)(const QString & , int , const QString & , const QString & )>(_a, &KonqClosedWindowsManagerAdaptor::notifyClosedWindowItem, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KonqClosedWindowsManagerAdaptor::*)(const QString & , const QString & )>(_a, &KonqClosedWindowsManagerAdaptor::notifyRemove, 1))
            return;
    }
}

const QMetaObject *KonqClosedWindowsManagerAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KonqClosedWindowsManagerAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN31KonqClosedWindowsManagerAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int KonqClosedWindowsManagerAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void KonqClosedWindowsManagerAdaptor::notifyClosedWindowItem(const QString & _t1, int _t2, const QString & _t3, const QString & _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 1
void KonqClosedWindowsManagerAdaptor::notifyRemove(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}
QT_WARNING_POP
