/****************************************************************************
** Meta object code from reading C++ file 'searchbar.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../konqueror-26.04.0/plugins/searchbar/searchbar.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'searchbar.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14SearchBarComboE_t {};
} // unnamed namespace

template <> constexpr inline auto SearchBarCombo::qt_create_metaobjectdata<qt_meta_tag_ZN14SearchBarComboE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SearchBarCombo",
        "iconClicked",
        "",
        "historyCleared"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'iconClicked'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'historyCleared'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SearchBarCombo, qt_meta_tag_ZN14SearchBarComboE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject SearchBarCombo::staticMetaObject = { {
    QMetaObject::SuperData::link<KHistoryComboBox::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14SearchBarComboE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14SearchBarComboE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14SearchBarComboE_t>.metaTypes,
    nullptr
} };

void SearchBarCombo::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SearchBarCombo *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->iconClicked(); break;
        case 1: _t->historyCleared(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SearchBarCombo::*)()>(_a, &SearchBarCombo::iconClicked, 0))
            return;
    }
}

const QMetaObject *SearchBarCombo::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SearchBarCombo::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14SearchBarComboE_t>.strings))
        return static_cast<void*>(this);
    return KHistoryComboBox::qt_metacast(_clname);
}

int SearchBarCombo::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KHistoryComboBox::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void SearchBarCombo::iconClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
namespace {
struct qt_meta_tag_ZN15SearchBarPluginE_t {};
} // unnamed namespace

template <> constexpr inline auto SearchBarPlugin::qt_create_metaobjectdata<qt_meta_tag_ZN15SearchBarPluginE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SearchBarPlugin",
        "startSearch",
        "",
        "search",
        "setIcon",
        "showSelectionMenu",
        "useFindInThisPage",
        "menuActionTriggered",
        "QAction*",
        "selectSearchEngines",
        "configurationChanged",
        "reloadConfiguration",
        "updateComboVisibility",
        "focusSearchbar",
        "searchTextChanged",
        "text",
        "addSearchSuggestion",
        "suggestion",
        "HTMLLoadingStarted",
        "HTMLDocLoaded",
        "insertOpenSearchEntries",
        "QList<KonqInterfaces::SelectorInterface::Element>",
        "elements",
        "openSearchEngineAdded",
        "name",
        "searchUrl",
        "fileName",
        "webShortcutSet",
        "webShortcut"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'startSearch'
        QtMocHelpers::SlotData<void(const QString &)>(1, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'setIcon'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'showSelectionMenu'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'useFindInThisPage'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'menuActionTriggered'
        QtMocHelpers::SlotData<void(QAction *)>(7, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 8, 2 },
        }}),
        // Slot 'selectSearchEngines'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'configurationChanged'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'reloadConfiguration'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateComboVisibility'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'focusSearchbar'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'searchTextChanged'
        QtMocHelpers::SlotData<void(const QString &)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 15 },
        }}),
        // Slot 'addSearchSuggestion'
        QtMocHelpers::SlotData<void(const QStringList &)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QStringList, 17 },
        }}),
        // Slot 'HTMLLoadingStarted'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'HTMLDocLoaded'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'insertOpenSearchEntries'
        QtMocHelpers::SlotData<void(const QList<KonqInterfaces::SelectorInterface::Element> &)>(20, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 21, 22 },
        }}),
        // Slot 'openSearchEngineAdded'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QString &)>(23, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 25 }, { QMetaType::QString, 26 },
        }}),
        // Slot 'webShortcutSet'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QString &)>(27, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 28 }, { QMetaType::QString, 26 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SearchBarPlugin, qt_meta_tag_ZN15SearchBarPluginE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject SearchBarPlugin::staticMetaObject = { {
    QMetaObject::SuperData::link<KonqParts::Plugin::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15SearchBarPluginE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15SearchBarPluginE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15SearchBarPluginE_t>.metaTypes,
    nullptr
} };

void SearchBarPlugin::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SearchBarPlugin *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->startSearch((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->setIcon(); break;
        case 2: _t->showSelectionMenu(); break;
        case 3: _t->useFindInThisPage(); break;
        case 4: _t->menuActionTriggered((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 5: _t->selectSearchEngines(); break;
        case 6: _t->configurationChanged(); break;
        case 7: _t->reloadConfiguration(); break;
        case 8: _t->updateComboVisibility(); break;
        case 9: _t->focusSearchbar(); break;
        case 10: _t->searchTextChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: _t->addSearchSuggestion((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 12: _t->HTMLLoadingStarted(); break;
        case 13: _t->HTMLDocLoaded(); break;
        case 14: _t->insertOpenSearchEntries((*reinterpret_cast<std::add_pointer_t<QList<KonqInterfaces::SelectorInterface::Element>>>(_a[1]))); break;
        case 15: _t->openSearchEngineAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 16: _t->webShortcutSet((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        }
    }
}

const QMetaObject *SearchBarPlugin::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SearchBarPlugin::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15SearchBarPluginE_t>.strings))
        return static_cast<void*>(this);
    return KonqParts::Plugin::qt_metacast(_clname);
}

int SearchBarPlugin::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KonqParts::Plugin::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    return _id;
}
QT_WARNING_POP
