/********************************************************************************
** Form generated from reading UI file 'csscustom.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CSSCUSTOM_H
#define UI_CSSCUSTOM_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFontComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <kcolorbutton.h>
#include <klocalizedstring.h>
#include "kcolorbutton.h"

QT_BEGIN_NAMESPACE

class Ui_CSSCustomDialog
{
public:
    QVBoxLayout *vboxLayout;
    QGridLayout *gridLayout;
    QGroupBox *GroupBox7;
    QGridLayout *gridLayout1;
    QLabel *txtBaseFontFamily;
    QFontComboBox *fontFamily;
    QCheckBox *sameFamily;
    QGroupBox *GroupBox3;
    QGridLayout *gridLayout2;
    QLabel *txtFontsize;
    QComboBox *basefontsize;
    QCheckBox *dontScale;
    QGroupBox *ButtonGroup2;
    QGridLayout *gridLayout3;
    QSpacerItem *spacerItem;
    QRadioButton *blackOnWhite;
    QRadioButton *whiteOnBlack;
    QRadioButton *customColor;
    QLabel *txtBackground;
    KColorButton *backgroundColorButton;
    QCheckBox *sameColor;
    QLabel *txtForeground;
    KColorButton *foregroundColorButton;
    QGroupBox *GroupBox3_2;
    QGridLayout *gridLayout4;
    QCheckBox *hideImages;
    QCheckBox *hideBackground;
    QSpacerItem *verticalSpacer;
    QGroupBox *previewBox;
    QHBoxLayout *hboxLayout;
    QHBoxLayout *hboxLayout1;

    void setupUi(QWidget *CSSCustomDialog)
    {
        if (CSSCustomDialog->objectName().isEmpty())
            CSSCustomDialog->setObjectName("CSSCustomDialog");
        CSSCustomDialog->resize(633, 526);
        vboxLayout = new QVBoxLayout(CSSCustomDialog);
        vboxLayout->setObjectName("vboxLayout");
        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        GroupBox7 = new QGroupBox(CSSCustomDialog);
        GroupBox7->setObjectName("GroupBox7");
        gridLayout1 = new QGridLayout(GroupBox7);
        gridLayout1->setObjectName("gridLayout1");
        txtBaseFontFamily = new QLabel(GroupBox7);
        txtBaseFontFamily->setObjectName("txtBaseFontFamily");

        gridLayout1->addWidget(txtBaseFontFamily, 0, 0, 1, 1);

        fontFamily = new QFontComboBox(GroupBox7);
        fontFamily->setObjectName("fontFamily");

        gridLayout1->addWidget(fontFamily, 0, 1, 1, 1);

        sameFamily = new QCheckBox(GroupBox7);
        sameFamily->setObjectName("sameFamily");

        gridLayout1->addWidget(sameFamily, 1, 0, 1, 2);


        gridLayout->addWidget(GroupBox7, 3, 0, 1, 1);

        GroupBox3 = new QGroupBox(CSSCustomDialog);
        GroupBox3->setObjectName("GroupBox3");
        gridLayout2 = new QGridLayout(GroupBox3);
        gridLayout2->setObjectName("gridLayout2");
        txtFontsize = new QLabel(GroupBox3);
        txtFontsize->setObjectName("txtFontsize");
        txtFontsize->setWordWrap(false);

        gridLayout2->addWidget(txtFontsize, 0, 0, 1, 1);

        basefontsize = new QComboBox(GroupBox3);
        basefontsize->addItem(QString());
        basefontsize->addItem(QString());
        basefontsize->addItem(QString());
        basefontsize->addItem(QString());
        basefontsize->addItem(QString());
        basefontsize->addItem(QString());
        basefontsize->addItem(QString());
        basefontsize->addItem(QString());
        basefontsize->addItem(QString());
        basefontsize->addItem(QString());
        basefontsize->addItem(QString());
        basefontsize->addItem(QString());
        basefontsize->addItem(QString());
        basefontsize->setObjectName("basefontsize");
        basefontsize->setEditable(true);

        gridLayout2->addWidget(basefontsize, 0, 1, 1, 1);

        dontScale = new QCheckBox(GroupBox3);
        dontScale->setObjectName("dontScale");

        gridLayout2->addWidget(dontScale, 1, 0, 1, 2);


        gridLayout->addWidget(GroupBox3, 3, 1, 1, 1);

        ButtonGroup2 = new QGroupBox(CSSCustomDialog);
        ButtonGroup2->setObjectName("ButtonGroup2");
        gridLayout3 = new QGridLayout(ButtonGroup2);
        gridLayout3->setObjectName("gridLayout3");
        spacerItem = new QSpacerItem(20, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout3->addItem(spacerItem, 3, 0, 1, 1);

        blackOnWhite = new QRadioButton(ButtonGroup2);
        blackOnWhite->setObjectName("blackOnWhite");
        blackOnWhite->setChecked(true);

        gridLayout3->addWidget(blackOnWhite, 0, 0, 1, 5);

        whiteOnBlack = new QRadioButton(ButtonGroup2);
        whiteOnBlack->setObjectName("whiteOnBlack");

        gridLayout3->addWidget(whiteOnBlack, 1, 0, 1, 5);

        customColor = new QRadioButton(ButtonGroup2);
        customColor->setObjectName("customColor");

        gridLayout3->addWidget(customColor, 2, 0, 1, 5);

        txtBackground = new QLabel(ButtonGroup2);
        txtBackground->setObjectName("txtBackground");
        txtBackground->setEnabled(false);
        txtBackground->setWordWrap(false);

        gridLayout3->addWidget(txtBackground, 3, 1, 1, 1);

        backgroundColorButton = new KColorButton(ButtonGroup2);
        backgroundColorButton->setObjectName("backgroundColorButton");
        backgroundColorButton->setEnabled(false);

        gridLayout3->addWidget(backgroundColorButton, 3, 2, 1, 1);

        sameColor = new QCheckBox(ButtonGroup2);
        sameColor->setObjectName("sameColor");

        gridLayout3->addWidget(sameColor, 4, 0, 1, 5);

        txtForeground = new QLabel(ButtonGroup2);
        txtForeground->setObjectName("txtForeground");
        txtForeground->setEnabled(false);
        txtForeground->setWordWrap(false);

        gridLayout3->addWidget(txtForeground, 3, 3, 1, 1);

        foregroundColorButton = new KColorButton(ButtonGroup2);
        foregroundColorButton->setObjectName("foregroundColorButton");
        foregroundColorButton->setEnabled(false);

        gridLayout3->addWidget(foregroundColorButton, 3, 4, 1, 1);


        gridLayout->addWidget(ButtonGroup2, 4, 1, 1, 1);

        GroupBox3_2 = new QGroupBox(CSSCustomDialog);
        GroupBox3_2->setObjectName("GroupBox3_2");
        gridLayout4 = new QGridLayout(GroupBox3_2);
        gridLayout4->setObjectName("gridLayout4");
        hideImages = new QCheckBox(GroupBox3_2);
        hideImages->setObjectName("hideImages");

        gridLayout4->addWidget(hideImages, 0, 0, 1, 1);

        hideBackground = new QCheckBox(GroupBox3_2);
        hideBackground->setObjectName("hideBackground");
        hideBackground->setChecked(true);

        gridLayout4->addWidget(hideBackground, 1, 0, 1, 1);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout4->addItem(verticalSpacer, 2, 0, 1, 1);


        gridLayout->addWidget(GroupBox3_2, 4, 0, 1, 1);

        previewBox = new QGroupBox(CSSCustomDialog);
        previewBox->setObjectName("previewBox");
        previewBox->setMinimumSize(QSize(0, 200));

        gridLayout->addWidget(previewBox, 5, 0, 1, 2);


        vboxLayout->addLayout(gridLayout);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");

        vboxLayout->addLayout(hboxLayout);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setObjectName("hboxLayout1");

        vboxLayout->addLayout(hboxLayout1);

#if QT_CONFIG(shortcut)
        txtFontsize->setBuddy(basefontsize);
        txtBackground->setBuddy(backgroundColorButton);
        txtForeground->setBuddy(foregroundColorButton);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(sameFamily, basefontsize);
        QWidget::setTabOrder(basefontsize, dontScale);
        QWidget::setTabOrder(dontScale, blackOnWhite);
        QWidget::setTabOrder(blackOnWhite, backgroundColorButton);
        QWidget::setTabOrder(backgroundColorButton, sameColor);
        QWidget::setTabOrder(sameColor, hideImages);
        QWidget::setTabOrder(hideImages, hideBackground);

        retranslateUi(CSSCustomDialog);
        QObject::connect(customColor, SIGNAL(toggled(bool)), backgroundColorButton, SLOT(setEnabled(bool)));
        QObject::connect(customColor, SIGNAL(toggled(bool)), foregroundColorButton, SLOT(setEnabled(bool)));
        QObject::connect(customColor, &QRadioButton::toggled, txtBackground, &QLabel::setEnabled);
        QObject::connect(customColor, &QRadioButton::toggled, txtForeground, &QLabel::setEnabled);

        QMetaObject::connectSlotsByName(CSSCustomDialog);
    } // setupUi

    void retranslateUi(QWidget *CSSCustomDialog)
    {
#if QT_CONFIG(whatsthis)
        CSSCustomDialog->setWhatsThis(tr2i18n("<b>Stylesheets</b><p>See http://www.w3.org/Style/CSS for further information on cascading style sheets.</p>", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(whatsthis)
        GroupBox7->setWhatsThis(tr2i18n("<b>Font family</b><p>A font family is a group of fonts that resemble one another, with family members that are e.g. bold, italic, or any number of the above.</p>", nullptr));
#endif // QT_CONFIG(whatsthis)
        GroupBox7->setTitle(tr2i18n("Font Family", nullptr));
        txtBaseFontFamily->setText(tr2i18n("Base family:", nullptr));
#if QT_CONFIG(whatsthis)
        fontFamily->setWhatsThis(tr2i18n("<p>This is the currently selected font family</p>", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(whatsthis)
        sameFamily->setWhatsThis(tr2i18n("<b>Use same family for all text</b><p>Select this option to override custom fonts everywhere in favor of the base font.</p>", nullptr));
#endif // QT_CONFIG(whatsthis)
        sameFamily->setText(tr2i18n("Use same family for all text", nullptr));
        GroupBox3->setTitle(tr2i18n("Font Size", nullptr));
        txtFontsize->setText(tr2i18n("Base font si&ze:", nullptr));
        basefontsize->setItemText(0, tr2i18n("7", nullptr));
        basefontsize->setItemText(1, tr2i18n("8", nullptr));
        basefontsize->setItemText(2, tr2i18n("9", nullptr));
        basefontsize->setItemText(3, tr2i18n("10", nullptr));
        basefontsize->setItemText(4, tr2i18n("11", nullptr));
        basefontsize->setItemText(5, tr2i18n("12", nullptr));
        basefontsize->setItemText(6, tr2i18n("14", nullptr));
        basefontsize->setItemText(7, tr2i18n("16", nullptr));
        basefontsize->setItemText(8, tr2i18n("20", nullptr));
        basefontsize->setItemText(9, tr2i18n("24", nullptr));
        basefontsize->setItemText(10, tr2i18n("32", nullptr));
        basefontsize->setItemText(11, tr2i18n("48", nullptr));
        basefontsize->setItemText(12, tr2i18n("64", nullptr));

#if QT_CONFIG(whatsthis)
        dontScale->setWhatsThis(tr2i18n("<b>Use same size for all elements</b><p>Select this option to override custom font sizes in favor of the base font size. All fonts will be displayed in the same size.</p>", nullptr));
#endif // QT_CONFIG(whatsthis)
        dontScale->setText(tr2i18n("&Use same size for all elements", nullptr));
        ButtonGroup2->setTitle(tr2i18n("Colors", nullptr));
#if QT_CONFIG(whatsthis)
        blackOnWhite->setWhatsThis(tr2i18n("<b>Black on White</b><p>This is what you normally see.</p>", nullptr));
#endif // QT_CONFIG(whatsthis)
        blackOnWhite->setText(tr2i18n("&Black on white", nullptr));
#if QT_CONFIG(whatsthis)
        whiteOnBlack->setWhatsThis(tr2i18n("<b>White on Black</b><p>This is your classic inverse color scheme.</p>", nullptr));
#endif // QT_CONFIG(whatsthis)
        whiteOnBlack->setText(tr2i18n("&White on black", nullptr));
#if QT_CONFIG(whatsthis)
        customColor->setWhatsThis(tr2i18n("<b>Custom</b><p>Select this option to define a custom color for the default font.</p>", nullptr));
#endif // QT_CONFIG(whatsthis)
        customColor->setText(tr2i18n("Cus&tom", nullptr));
#if QT_CONFIG(whatsthis)
        txtBackground->setWhatsThis(tr2i18n("<b>Background</b><p>This background color is the one displayed behind the text by default. A background image will override this.</p>", nullptr));
#endif // QT_CONFIG(whatsthis)
        txtBackground->setText(tr2i18n("Bac&kground:", nullptr));
#if QT_CONFIG(whatsthis)
        backgroundColorButton->setWhatsThis(tr2i18n("<b>Background</b><p>Behind this door lays the ability to choose a custom default background.</p>", nullptr));
#endif // QT_CONFIG(whatsthis)
        backgroundColorButton->setText(QString());
#if QT_CONFIG(whatsthis)
        sameColor->setWhatsThis(tr2i18n("<b>Use same color for all text</b><p>Select this option to apply your chosen color to the default font as well as any custom fonts as specified in a stylesheet.</p>", nullptr));
#endif // QT_CONFIG(whatsthis)
        sameColor->setText(tr2i18n("Use same color for all text", nullptr));
#if QT_CONFIG(whatsthis)
        txtForeground->setWhatsThis(tr2i18n("<b>Foreground color</b><p>The foreground color is the color that the text is drawn in.</p>", nullptr));
#endif // QT_CONFIG(whatsthis)
        txtForeground->setText(tr2i18n("&Foreground:", nullptr));
#if QT_CONFIG(whatsthis)
        foregroundColorButton->setWhatsThis(tr2i18n("<b>Foreground color</b><p>The foreground color is the color that the text is drawn in.</p>", nullptr));
#endif // QT_CONFIG(whatsthis)
        foregroundColorButton->setText(QString());
#if QT_CONFIG(whatsthis)
        GroupBox3_2->setWhatsThis(tr2i18n("<b>Images</b>", nullptr));
#endif // QT_CONFIG(whatsthis)
        GroupBox3_2->setTitle(tr2i18n("Images", nullptr));
#if QT_CONFIG(whatsthis)
        hideImages->setWhatsThis(tr2i18n("<b>Suppress images</b><p>Selecting this will prevent Konqueror from loading images.</p>", nullptr));
#endif // QT_CONFIG(whatsthis)
        hideImages->setText(tr2i18n("&Suppress images", nullptr));
#if QT_CONFIG(whatsthis)
        hideBackground->setWhatsThis(tr2i18n("<b>Suppress background images</b><p>Selecting this option will prevent Konqueror from loading background images.</p>", nullptr));
#endif // QT_CONFIG(whatsthis)
        hideBackground->setText(tr2i18n("Suppress background images", nullptr));
        previewBox->setTitle(tr2i18n("Preview", nullptr));
    } // retranslateUi

};

namespace Ui {
    class CSSCustomDialog: public Ui_CSSCustomDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CSSCUSTOM_H

